@@ -31,8 +31,7 @@ use OCA\Activity\BackgroundJob\RemoteActivity;
 use OCA\Activity\Extension\Files;
 use OCA\Activity\Extension\Files_Sharing;
 use OCP\Activity\IManager;
-use OCP\Files\Config\ICachedMountFileInfo;
-use OCP\Files\Config\ICachedMountInfo;
+use OCP\Constants;
 use OCP\Files\Config\IUserMountCache;
 use OCP\Files\IRootFolder;
 use OCP\Files\Mount\IMountPoint;
@@ -46,7 +45,6 @@ use OCP\ILogger;
 use OCP\ITagManager;
 use OCP\IURLGenerator;
 use OCP\IUser;
-use OCP\Share;
 use OCP\Share\IShare;
 use OCP\Share\IShareHelper;
 
@@ -54,7 +52,7 @@ use OCP\Share\IShareHelper;
  * The class to handle the filesystem hooks
  */
 class FilesHooks {
-	const USER_BATCH_SIZE = 50;
+	public const USER_BATCH_SIZE = 50;
 
 	/** @var \OCP\Activity\IManager */
 	protected $manager;
@@ -86,6 +84,13 @@ class FilesHooks {
 	/** @var ILogger */
 	protected $logger;
 
+	/**
+	 * @psalm-suppress UndefinedClass
+	 * @var ITagManager|TagManager
+	 */
+	protected $tagManager;
+
+
 	/** @var CurrentUser */
 	protected $currentUser;
 	/** @var IUserMountCache */
@@ -105,8 +110,6 @@ class FilesHooks {
 	protected $oldParentId;
 	/** @var NotificationGenerator */
 	protected $notificationGenerator;
-	/** @var ITagManager|TagManager */
-	protected $tagManager;
 
 	public function __construct(
 		IManager $manager,
@@ -190,6 +193,7 @@ class FilesHooks {
 		$filteredEmailUsers = $this->userSettings->filterUsersBySetting($users, 'email', Files::TYPE_FILE_CHANGED);
 		$filteredNotificationUsers = $this->userSettings->filterUsersBySetting($users, 'notification', Files::TYPE_FILE_CHANGED);
 
+		/** @psalm-suppress UndefinedMethod */
 		$favoriteUsers = $this->tagManager->getUsersFavoritingObject('files', $fileId);
 		if (!empty($favoriteUsers)) {
 			$favoriteUsers = array_intersect($users, $favoriteUsers);
@@ -224,22 +228,19 @@ class FilesHooks {
 
 		$accessList = $this->getUserPathsFromPath($filePath, $uidOwner);
 
-		$this->generateRemoteActivity($accessList['remotes'], $activityType, time(), $this->currentUser->getCloudId(), $accessList['ownerPath']);
-
-		if ($this->config->getSystemValueBool('activity_use_cached_mountpoints', false)) {
-			$mountsForFile = $this->userMountCache->getMountsForFileId($fileId);
-			$affectedUserIds = array_map(function (ICachedMountInfo $mount) {
-				return $mount->getUser()->getUID();
-			}, $mountsForFile);
-			$affectedPaths = array_map(function (ICachedMountFileInfo $mount) {
-				return $this->getVisiblePath($mount->getPath());
-			}, $mountsForFile);
-			$affectedUsers = array_combine($affectedUserIds, $affectedPaths);
-		} else {
-			$affectedUsers = $accessList['users'];
+		if (!empty($accessList['remotes'])) {
+			$this->generateRemoteActivity($accessList['remotes'], $activityType, time(), $this->currentUser->getCloudId(), $accessList['ownerPath']);
 		}
 
-		[$filteredEmailUsers, $filteredNotificationUsers] = $this->getFileChangeActivitySettings($fileId, array_keys($affectedUsers));
+		$affectedUsers = $accessList['users'];
+
+		// file can be shared using GroupFolders, including ACL check
+		if ($this->config->getSystemValueBool('activity_use_cached_mountpoints', false)) {
+			$affectedUsers = array_merge($affectedUsers, $this->getAffectedUsersFromCachedMounts($fileId));
+		}
+
+		[$filteredEmailUsers, $filteredNotificationUsers] =
+			$this->getFileChangeActivitySettings($fileId, array_keys($affectedUsers));
 
 		foreach ($affectedUsers as $user => $path) {
 			$user = (string)$user;
@@ -324,7 +325,7 @@ class FilesHooks {
 			 * - a/ shared: move/rename
 			 */
 			$this->moveCase = 'moveUp';
-		} else if (strpos($newDir, $oldDir) === 0) {
+		} elseif (strpos($newDir, $oldDir) === 0) {
 			/**
 			 * a/b moved to a/c/b
 			 *
@@ -417,7 +418,6 @@ class FilesHooks {
 		[$filteredEmailUsers, $filteredNotificationUsers] = $this->getFileChangeActivitySettings($fileId, array_keys($affectedUsers));
 
 		foreach ($affectedUsers as $user => $path) {
-
 			if ($user === $this->currentUser->getUID()) {
 				$userSubject = 'renamed_self';
 				$userParams = [
@@ -517,6 +517,7 @@ class FilesHooks {
 
 		[$filteredEmailUsers, $filteredNotificationUsers] = $this->getFileChangeActivitySettings($fileId, $users);
 
+		$shouldFlush = $this->startActivityTransaction();
 		foreach ($users as $user) {
 			$path = $pathMap[$user];
 
@@ -536,6 +537,7 @@ class FilesHooks {
 				Files::TYPE_SHARE_DELETED
 			);
 		}
+		$this->commitActivityTransaction($shouldFlush);
 	}
 
 	/**
@@ -551,8 +553,8 @@ class FilesHooks {
 
 		[$filteredEmailUsers, $filteredNotificationUsers] = $this->getFileChangeActivitySettings($fileId, $users);
 
+		$shouldFlush = $this->startActivityTransaction();
 		foreach ($users as $user) {
-
 			$path = $pathMap[$user];
 
 			if ($user === $this->currentUser->getUID()) {
@@ -571,6 +573,7 @@ class FilesHooks {
 				Files::TYPE_FILE_CHANGED
 			);
 		}
+		$this->commitActivityTransaction($shouldFlush);
 	}
 
 	/**
@@ -589,6 +592,7 @@ class FilesHooks {
 
 		[$filteredEmailUsers, $filteredNotificationUsers] = $this->getFileChangeActivitySettings($fileId, $users);
 
+		$shouldFlush = $this->startActivityTransaction();
 		foreach ($users as $user) {
 			if ($oldFileName === $fileName) {
 				$userParams = [[$newParentId => $afterPathMap[$user] . '/']];
@@ -612,6 +616,7 @@ class FilesHooks {
 				Files::TYPE_FILE_CHANGED
 			);
 		}
+		$this->commitActivityTransaction($shouldFlush);
 	}
 
 	/**
@@ -702,11 +707,11 @@ class FilesHooks {
 	 */
 	public function share($params) {
 		if ($params['itemType'] === 'file' || $params['itemType'] === 'folder') {
-			if ((int)$params['shareType'] === Share::SHARE_TYPE_USER) {
+			if ((int)$params['shareType'] === IShare::TYPE_USER) {
 				$this->shareWithUser($params['shareWith'], (int)$params['fileSource'], $params['itemType'], $params['fileTarget']);
-			} else if ((int)$params['shareType'] === Share::SHARE_TYPE_GROUP) {
+			} elseif ((int)$params['shareType'] === IShare::TYPE_GROUP) {
 				$this->shareWithGroup($params['shareWith'], (int)$params['fileSource'], $params['itemType'], $params['fileTarget'], (int)$params['id']);
-			} else if ((int)$params['shareType'] === Share::SHARE_TYPE_LINK) {
+			} elseif ((int)$params['shareType'] === IShare::TYPE_LINK) {
 				$this->shareByLink((int)$params['fileSource'], $params['itemType'], $params['uidOwner']);
 			}
 		}
@@ -732,7 +737,7 @@ class FilesHooks {
 			$shareWith, 'shared_with_by', [[$fileSource => $fileTarget], $this->currentUser->getUserIdentifier()],
 			(int)$fileSource, $fileTarget, $itemType === 'file',
 			$this->userSettings->getUserSetting($shareWith, 'email', Files_Sharing::TYPE_SHARED) ? $this->userSettings->getUserSetting($shareWith, 'setting', 'batchtime') : false,
-			$this->userSettings->getUserSetting($shareWith, 'notification', Files_Sharing::TYPE_SHARED)
+			(bool) $this->userSettings->getUserSetting($shareWith, 'notification', Files_Sharing::TYPE_SHARED)
 		);
 	}
 
@@ -789,7 +794,7 @@ class FilesHooks {
 			$linkOwner, 'shared_link_self', [[$fileSource => $path]],
 			(int)$fileSource, $path, $itemType === 'file',
 			$this->userSettings->getUserSetting($linkOwner, 'email', Files_Sharing::TYPE_SHARED) ? $this->userSettings->getUserSetting($linkOwner, 'setting', 'batchtime') : false,
-			$this->userSettings->getUserSetting($linkOwner, 'notification', Files_Sharing::TYPE_SHARED)
+			(bool) $this->userSettings->getUserSetting($linkOwner, 'notification', Files_Sharing::TYPE_SHARED)
 		);
 	}
 
@@ -801,11 +806,11 @@ class FilesHooks {
 	 */
 	public function unShare(IShare $share) {
 		if (in_array($share->getNodeType(), ['file', 'folder'], true)) {
-			if ($share->getShareType() === Share::SHARE_TYPE_USER) {
+			if ($share->getShareType() === IShare::TYPE_USER) {
 				$this->unshareFromUser($share);
-			} else if ($share->getShareType() === Share::SHARE_TYPE_GROUP) {
+			} elseif ($share->getShareType() === IShare::TYPE_GROUP) {
 				$this->unshareFromGroup($share);
-			} else if ($share->getShareType() === Share::SHARE_TYPE_LINK) {
+			} elseif ($share->getShareType() === IShare::TYPE_LINK) {
 				$this->unshareLink($share);
 			}
 		}
@@ -819,7 +824,7 @@ class FilesHooks {
 	 */
 	public function unShareSelf(IShare $share) {
 		if (in_array($share->getNodeType(), ['file', 'folder'], true)) {
-			if ($share->getShareType() === Share::SHARE_TYPE_GROUP) {
+			if ($share->getShareType() === IShare::TYPE_GROUP) {
 				$this->unshareFromSelfGroup($share);
 			} else {
 				$this->unShare($share);
@@ -862,7 +867,7 @@ class FilesHooks {
 			$share->getSharedWith(), $actionUser, [[$share->getNodeId() => $share->getTarget()], $this->currentUser->getUserIdentifier()],
 			$share->getNodeId(), $share->getTarget(), $share->getNodeType() === 'file',
 			$this->userSettings->getUserSetting($share->getSharedWith(), 'email', Files_Sharing::TYPE_SHARED) ? $this->userSettings->getUserSetting($share->getSharedWith(), 'setting', 'batchtime') : false,
-			$this->userSettings->getUserSetting($share->getSharedWith(), 'notification', Files_Sharing::TYPE_SHARED)
+			(bool) $this->userSettings->getUserSetting($share->getSharedWith(), 'notification', Files_Sharing::TYPE_SHARED)
 		);
 	}
 
@@ -913,11 +918,13 @@ class FilesHooks {
 
 		$offset = 0;
 		$users = $group->searchUsers('', self::USER_BATCH_SIZE, $offset);
+		$shouldFlush = $this->startActivityTransaction();
 		while (!empty($users)) {
-			$this->addNotificationsForGroupUsers($users, $actionUser, $share->getNodeId(), $share->getNodeType(), $share->getTarget(), $share->getId());
+			$this->addNotificationsForGroupUsers($users, $actionUser, $share->getNodeId(), $share->getNodeType(), $share->getTarget(), (int) $share->getId());
 			$offset += self::USER_BATCH_SIZE;
 			$users = $group->searchUsers('', self::USER_BATCH_SIZE, $offset);
 		}
+		$this->commitActivityTransaction($shouldFlush);
 	}
 
 	/**
@@ -958,7 +965,7 @@ class FilesHooks {
 			$owner, $actionSharer, [[$share->getNodeId() => $share->getTarget()]],
 			$share->getNodeId(), $share->getTarget(), $share->getNodeType() === 'file',
 			$this->userSettings->getUserSetting($owner, 'email', Files_Sharing::TYPE_SHARED) ? $this->userSettings->getUserSetting($owner, 'setting', 'batchtime') : false,
-			$this->userSettings->getUserSetting($owner, 'notification', Files_Sharing::TYPE_SHARED)
+			(bool) $this->userSettings->getUserSetting($owner, 'notification', Files_Sharing::TYPE_SHARED)
 		);
 
 		if ($share->getSharedBy() !== $share->getShareOwner()) {
@@ -967,7 +974,7 @@ class FilesHooks {
 				$owner, $actionOwner, [[$share->getNodeId() => $share->getTarget()], $share->getSharedBy()],
 				$share->getNodeId(), $share->getTarget(), $share->getNodeType() === 'file',
 				$this->userSettings->getUserSetting($owner, 'email', Files_Sharing::TYPE_SHARED) ? $this->userSettings->getUserSetting($owner, 'setting', 'batchtime') : false,
-				$this->userSettings->getUserSetting($owner, 'notification', Files_Sharing::TYPE_SHARED)
+				(bool) $this->userSettings->getUserSetting($owner, 'notification', Files_Sharing::TYPE_SHARED)
 			);
 		}
 	}
@@ -999,8 +1006,8 @@ class FilesHooks {
 		$filteredNotificationUsers = $this->userSettings->filterUsersBySetting($userIds, 'notification', Files_Sharing::TYPE_SHARED);
 
 		$affectedUsers = $this->fixPathsForShareExceptions($affectedUsers, $shareId);
+		$shouldFlush = $this->startActivityTransaction();
 		foreach ($affectedUsers as $user => $path) {
-
 			$this->addNotificationsForUser(
 				$user, $actionUser, [[$fileSource => $path], $this->currentUser->getUserIdentifier()],
 				$fileSource, $path, ($itemType === 'file'),
@@ -1008,6 +1015,7 @@ class FilesHooks {
 				$filteredNotificationUsers[$user] ?? false
 			);
 		}
+		$this->commitActivityTransaction($shouldFlush);
 	}
 
 	/**
@@ -1059,7 +1067,7 @@ class FilesHooks {
 			$sharer, $subject, [[$fileSource => $path], $shareWith],
 			$fileSource, $path, ($itemType === 'file'),
 			$this->userSettings->getUserSetting($sharer, 'email', Files_Sharing::TYPE_SHARED) ? $this->userSettings->getUserSetting($sharer, 'setting', 'batchtime') : false,
-			$this->userSettings->getUserSetting($sharer, 'notification', Files_Sharing::TYPE_SHARED)
+			(bool) $this->userSettings->getUserSetting($sharer, 'notification', Files_Sharing::TYPE_SHARED)
 		);
 	}
 
@@ -1085,7 +1093,7 @@ class FilesHooks {
 			$owner, $subject, [[$fileSource => $path], $this->currentUser->getUserIdentifier(), $shareWith],
 			$fileSource, $path, ($itemType === 'file'),
 			$this->userSettings->getUserSetting($owner, 'email', Files_Sharing::TYPE_SHARED) ? $this->userSettings->getUserSetting($owner, 'setting', 'batchtime') : false,
-			$this->userSettings->getUserSetting($owner, 'notification', Files_Sharing::TYPE_SHARED)
+			(bool) $this->userSettings->getUserSetting($owner, 'notification', Files_Sharing::TYPE_SHARED)
 		);
 	}
 
@@ -1148,7 +1156,7 @@ class FilesHooks {
 	 * @param int $fileId
 	 * @param string $path
 	 * @param bool $isFile If the item is a file, we link to the parent directory
-	 * @param int $emailSetting
+	 * @param int|false $emailSetting
 	 * @param bool $notificationSetting
 	 * @param string $type
 	 */
@@ -1188,9 +1196,184 @@ class FilesHooks {
 		}
 
 		// Add activity to mail queue
-		if ($emailSetting !== false && (!$selfAction || $this->userSettings->getUserSetting($this->currentUser->getUID(), 'setting', 'selfemail'))) {
+		if ($emailSetting !== false && !$selfAction) {
 			$latestSend = time() + $emailSetting;
 			$this->activityData->storeMail($event, $latestSend);
 		}
 	}
+
+	protected function startActivityTransaction(): bool {
+		$this->connection->beginTransaction();
+		return $this->notificationGenerator->deferNotifications();
+	}
+
+	protected function commitActivityTransaction(bool $shouldFlush): void {
+		if ($shouldFlush) {
+			$this->notificationGenerator->flushNotifications();
+		}
+		$this->connection->commit();
+	}
+
+
+	/**
+	 * @param int $fileId
+	 *
+	 * @return array
+	 */
+	private function getAffectedUsersFromCachedMounts(int $fileId): array {
+		$affectedUsers = $cachedMounts = [];
+		$mountsForFile = $this->userMountCache->getMountsForFileId($fileId);
+		foreach ($mountsForFile as $mount) {
+			$affectedUsers[$mount->getUser()->getUID()] = $this->getVisiblePath($mount->getPath());
+			$cachedMounts[] = [
+				'userId' => $mount->getUser()->getUID(),
+				'provider' => str_replace('\\\\', '\\', $mount->getMountProvider()),
+				'path' => $mount->getPath(),
+				'visiblePath' => $this->getVisiblePath($mount->getPath()),
+				'storageId' => $mount->getStorageId()
+			];
+		}
+
+		$unrelatedUsers = $this->getUnrelatedUsers($fileId, $cachedMounts);
+
+		return array_filter($affectedUsers, function ($userId) use ($unrelatedUsers): bool {
+			return !in_array($userId, $unrelatedUsers);
+		}, ARRAY_FILTER_USE_KEY);
+	}
+
+
+	/**
+	 * returns an array of users that have confirmed no access to fileId
+	 *
+	 * @param int $fileId
+	 * @param array $cachedMounts
+	 *
+	 * @return string[] list of unrelated userIds
+	 */
+	private function getUnrelatedUsers(int $fileId, array $cachedMounts): array {
+		/** @var \OCA\GroupFolders\ACL\RuleManager $ruleManager */
+		/** @var \OCA\GroupFolders\Folder\FolderManager $folderManager */
+		try {
+			$ruleManager = \OC::$server->get(\OCA\GroupFolders\ACL\RuleManager::class);
+			$folderManager = \OC::$server->get(\OCA\GroupFolders\Folder\FolderManager::class);
+		} catch (\Exception $e) {
+			return []; // if we have no access to RuleManager, we cannot filter unrelated users
+		}
+
+		/** @var \OCA\GroupFolders\ACL\Rule[] $rules */
+		$rules = $knownRules = $knownGroupRules = $usersToCheck = $cachedPath = [];
+		foreach ($cachedMounts as $cachedMount) {
+			// we are only interested in filtering GroupFolders ACL
+			if ($cachedMount['provider'] !== 'OCA\GroupFolders\Mount\MountProvider') {
+				continue;
+			}
+
+			// caching rules based on storage id
+			$storageId = $cachedMount['storageId'];
+			if (!array_key_exists($storageId, $knownRules)) {
+				$knownRules[$storageId] = [];
+			}
+
+			$cachedPath[$cachedMount['userId']] = $fullPath = $cachedMount['path'];
+
+			// caching rules based on storage+path to file
+			if (!array_key_exists($cachedMount['visiblePath'], $knownRules[$storageId])) {
+				// we need mountPoint and folderId to generate the correct path
+				try {
+					$node = $this->rootFolder->get($fullPath);
+					$mountPoint = $node->getMountPoint();
+
+					if (!$mountPoint instanceof \OCA\GroupFolders\Mount\GroupMountPoint
+						|| !$folderManager->getFolderAclEnabled($mountPoint->getFolderId())) {
+						continue; // acl are disable
+					}
+
+					$folderPath = $mountPoint->getSourcePath();
+					$path = substr($fullPath, strlen($mountPoint->getMountPoint()));
+				} catch (\Exception $e) {
+					// in case of issue during the process, we can imagine the user have no access to the file
+					$usersToCheck[] = $cachedMount['userId'];
+					continue; // we'll catch rules on next user with access to the file
+				}
+
+				// we generate a list of path from top level of group folder to the file itself to get all rules
+				$paths = [$folderPath];
+				while ($path !== '') {
+					$paths[] = $folderPath . '/' . $path;
+					$path = dirname($path);
+					if ($path === '.' || $path === '/') {
+						$path = '';
+					}
+				}
+
+				// we might already know the rules for some path of the list
+				$paths = array_filter($paths, function (string $path) use ($knownRules, $storageId): bool {
+					if (array_key_exists($path, $knownRules[$storageId])) {
+						return false;
+					}
+
+					return true;
+				});
+
+				// we get and store the rules for each path from the list
+				$rulesPerPath = $ruleManager->getAllRulesForPaths($storageId, $paths);
+				foreach (array_keys($rulesPerPath) as $path) {
+					$rules = array_merge($rules, $rulesPerPath[$path]);
+				}
+
+				$knownRules[$storageId][$cachedMount['visiblePath']] = true;
+			}
+		}
+
+		// using each rules that disable read permission to generate a list of users
+		// that might not have access to fileId
+		foreach ($rules as $rule) {
+			if (($rule->getMask() & Constants::PERMISSION_READ) === 0
+				|| ($rule->getPermissions() & Constants::PERMISSION_READ) !== 0) {
+				continue; // not interested of rules with 'mask' not including read capability (1), or if 'permission' does
+			}
+
+			$mapping = $rule->getUserMapping();
+			$id = $mapping->getId();
+
+			// if mapping is about user
+			if ($mapping->getType() === 'user' && !in_array($id, $usersToCheck)) {
+				$usersToCheck[] = $id;
+			}
+
+			// if mapping is about group
+			if ($mapping->getType() === 'group'
+				&& !in_array($mapping->getId(), $knownGroupRules)) {
+				$knownGroupRules[] = $mapping->getId();
+
+				$group = $this->groupManager->get($id);
+				if ($group === null) {
+					continue;
+				}
+				$userIds = array_map(function (IUser $user): string {
+					return $user->getUID();
+				}, $group->getUsers());
+
+				// merge current user list with members of the group
+				$usersToCheck = array_values(array_unique(array_merge($usersToCheck, $userIds)));
+			}
+		}
+
+
+		// now that we have a list of eventuals filtered users, we confirm they have no access to the file
+		$filteredUsers = [];
+		foreach ($usersToCheck as $userId) {
+			try {
+				$node = $this->rootFolder->get($cachedPath[$userId]);
+				if ($node->isReadable()) {
+					continue; // overkill ? as rootFolder->get() would throw an exception if file is not available
+				}
+			} catch (\Exception $e) {
+			}
+
+			$filteredUsers[] = $userId;
+		}
+
+		return $filteredUsers;
+	}
 }
