@@ -92,8 +92,9 @@ OC.L10N.register(
     "Circle Invite" : "Inviter dans un cercle",
     "Federated" : "Fédéré",
     "Mount point" : "Point de montage",
+    "Nextcloud Account" : "Compte Nextcloud",
     "Nextcloud Group" : "Groupe Nextcloud",
-    "Email Address" : "Courriel",
+    "Email Address" : "Adresse e-mail",
     "Contact" : "Contact",
     "Circle" : "Cercle",
     "Nextcloud App" : "App Nextcloud",
@@ -104,32 +105,31 @@ OC.L10N.register(
     "%s shared »%s« with you." : "%s a partagé «%s» avec vous.",
     "%s shared »%s« with \"%s\"." : "%s a partagé »%s« avec \"%s\".",
     "%s on %s" : "%s sur %s",
-    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé »%2$s« avec vous.\nVous devriez déjà avoir reçu un courriel avec un lien pour y accéder.\n",
-    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partagé »%2$s« avec vous. Vous devriez déjà avoir reçu un courriel avec un lien pour y accéder.",
+    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé »%2$s« avec vous.\nVous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.\n",
+    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partagé »%2$s« avec vous. Vous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.",
     "Password to access »%1$s« shared to you by %2$s" : "Mot de passe pour accéder à «%1$s» partagé avec vous par %2$s",
     "Password to access »%s«" : "Mot de passe pour accéder à «%s»",
     "It is protected with the following password:" : "Protégé par le mot de passe suivant :",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir.",
     "Open »%s«" : "Ouvrir «%s»",
-    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partagé plusieurs fichiers avec vous.\nVous devriez déjà avoir reçu un courriel avec un lien pour y accéder.\n",
+    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partagé plusieurs fichiers avec vous.\nVous devriez déjà avoir reçu un e-mail avec un lien pour y accéder.\n",
     "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sa partagé plusieurs fichiers avec vous. Vous devriez déjà avoir reçu un courrier avec un lien pour y accéder.",
     "Password to access files shared to you by %1$s" : "Mot de passe pour accéder aux fichiers partagés avec vous par %1$s",
     "Password to access files" : "Mot de passe pour accéder aux fichiers",
     "%s shared multiple files with \"%s\"." : "%s a partagé plusieurs fichiers avec \"%s\".",
     "%s shared multiple files with you." : "%s a partagé plusieurs fichiers avec vous.",
     "Boot up" : "Démarrage",
-    "Initialisation Nextcloud" : "Initialisation de Nextcloud",
-    "Initialisation Circles App" : "Initialisation de l'application Cercles",
+    "Nextcloud Initialization" : "Initialisation de Nexctcloud",
+    "Circles App Initialization" : "Initialisation de l'application Cercles",
     "Fresh installation status" : "Statut de l'installation",
     "Building Local Database" : "Construction de la base de données locale",
     "Testing Basic Circle Creation" : "Test de création d'un cercle basique",
     "Adding local users and moderators" : "Ajout d'utilisateurs locaux et de modérateurs",
     "Circle not found" : "Cercle non trouvé",
     "Circle not found " : "Cercle non trouvé",
-    "A circle with that name exists" : "Ce nom de cercle existe",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Vous ne pouvez pas utiliser l'application Cercles à moins que votre administrateur ait autorisé au moins un type de cercles",
     "This member does not exist" : "Ce membre n'existe pas",
+    "This account is already a member of the circle" : "Ce compte est déjà membre du cercle",
     "Federated link not found" : "Lien fédéré non trouvé",
     "This feature is not available for personal circles" : "Cette fonctionnalité n'est pas disponible pour les cercles personnels",
     "The circle is not federated" : "Le cercle n'est pas fédéré",
@@ -140,6 +140,8 @@ OC.L10N.register(
     "Level cannot be changed for this type of member" : "Le niveau ne peut pas être modifié pour ce type de membre",
     "You are already a member of this circle" : "Vous êtes déjà membre du cercle",
     "You have been blocked from this circle" : "Vous avez été bloqué de ce cercle",
+    "The account is already a member of this circle" : "Le compte est déjà membre de ce cercle",
+    "The account has already been invited into this circle" : "Le compte a déjà été invité à participer à ce cercle",
     "%s (Circle owned by %s)" : "%s (Cercle appartenant à %s)",
     "You are now a member of the Circle \"%2$s\"" : "Vous êtes maintenant membre du cercle \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Vous avez été invité par %1$s dans le cercle \"%2$s\"",
@@ -151,6 +153,7 @@ OC.L10N.register(
     "Personal Circle" : "Cercle personnel",
     "%s owned by %s" : "%s appartenant à %s",
     "You need a specify a type of circle" : "Vous devez spécifier un type de cercle",
+    "A circle with that name exists" : "Ce nom de cercle existe",
     "This member is not the owner of the circle" : "Ce membre n'est pas propriétaire du cercle",
     "This member is not an admin of the circle" : "Ce membre n'est pas un administrateur du cercle",
     "Group contains too many members" : "Le groupe contient trop de membres",
@@ -159,28 +162,33 @@ OC.L10N.register(
     "You cannot edit level in a personal circle" : "Vous ne pouvez pas modifier dans ce cercle personnel",
     "Group cannot be set as owner of a circle" : "Le groupe ne peut pas être défini comme propriétaire d'un cercle",
     "now" : "A l'instant",
-    "Email format is not valid" : "Le format d'Email est invalide",
+    "This account does not exist" : "Ce compte n'existe pas",
+    "Email format is not valid" : "Le format d'e-mail est invalide",
     "This contact is not available" : "Ce contact n'est pas disponible",
     "You have no permission to create a new circle" : "Vous n'avez pas l'autorisation de créer un nouveau cercle",
     "%s shared a file with \"%s\"." : "%s a partagé un fichier avec \"%s\".",
     "%s shared a file with you." : "%sa partagé un fichier avec vous.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé quelque chose avec vous\nVous devriez avoir déjà reçu un courriel séparé avec un lien pour y accéder\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$sa partagé quelque chose avec vous\nVous devriez avoir déjà reçu un courriel séparé avec un lien pour y accéder",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partagé quelque chose avec vous\nVous devriez avoir déjà reçu un e-mail séparé avec un lien pour y accéder\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$sa partagé quelque chose avec vous\nVous devriez avoir déjà reçu un e-mail séparé avec un lien pour y accéder",
     "Password to access content shared with you by %1$s" : "Mot de passe pour accéder au contenu partagé avec vous par %1$s",
     "Password to access content" : "Mot de passe pour accéder au contenu",
     "This item is already shared with this circle" : "Cet item est déjà partagé avec ce cercle",
-    "Could not find share" : "Impossible de trouver le partage",
     "Bring cloud-users closer together." : "Permet de rapprocher les utilisateur du cloud ensemble ",
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "L'application \"Cercles\" permet aux utilisateurs de créer leurs propres groupes de personnes/collègues/amis\nCes groupes de gens (ou \"cercles\" peuvent alors être utilisés par toutes les autres applications à des fins de partage.",
     "No files in here" : "Aucun fichier",
     "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
     "Name" : "Nom",
     "Size" : "Taille",
     "Modified" : "Modifié",
     "Nextcloud User" : "Utilisateur Nextcloud",
+    "Initialisation Nextcloud" : "Initialisation de Nextcloud",
+    "Initialisation Circles App" : "Initialisation de l'application Cercles",
+    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Vous ne pouvez pas utiliser l'application Cercles à moins que votre administrateur ait autorisé au moins un type de cercles",
     "This user is already a member of the circle" : "Cet utilisateur est déjà membre du cercle",
     "The user is already a member of this circle" : "L'utilisateur est déjà membre de ce cercle",
     "The user has already been invited into this circle" : "L'utilisateur a déjà été invité dans ce cercle",
     "This user does not exist" : "Cet utilisateur n'existe pas",
+    "Could not find share" : "Impossible de trouver le partage",
     "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "L'applications Cercles permet aux utilisateurs de créer leurs propres groupes d'utilisateurs/collègues/amis.\nCes groupes d'utilisateurs (ou \"cercles\") peuvent alors être utilisés par toutes les autres applications pour partager des éléments."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
