@@ -3,11 +3,9 @@ OC.L10N.register(
     {
     "Dashboard" : "Cruscotto",
     "Dashboard app" : "Cruscotto",
-    "Show something" : "Mostra qualcosa",
     "Customize" : "Personalizza",
     "Edit widgets" : "Modifica widget",
-    "Get more widgets from the app store" : "Ottieni altri widget dal negozio di applicazioni",
-    "Change background image" : "Cambia l'immagine di sfondo",
+    "Get more widgets from the App Store" : "Ottieni altri widget dal negozio delle applicazioni",
     "Weather service" : "Servizio meteo",
     "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Per la tua riservatezza, i dati meteorologici sono richiesti dal tuo server Nextcloud per tuo conto, per cui il servizio meteo non riceve informazioni personali.",
     "Weather data from Met.no" : "Dati meteo da Met.no",
@@ -23,12 +21,10 @@ OC.L10N.register(
     "Good evening, {name}" : "Buona sera, {name}",
     "Hello" : "Ciao",
     "Hello, {name}" : "Ciao {name}",
+    "Change background image" : "Cambia l'immagine di sfondo",
     "Pick from Files" : "Scegli da File",
     "Default images" : "Immagini predefinite",
     "Plain background" : "Sfondo semplice",
-    "Insert from {productName}" : "Inserisci da {productName}",
-    "Good night, {name}" : "Buona notte, {name}",
-    "Good night" : "Buona notte",
-    "Pick from files" : "Scegli da file"
+    "Insert from {productName}" : "Inserisci da {productName}"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
