@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Kalender",
-    "Todos" : "Aufgaben",
+    "To-dos" : "Aufgaben",
     "Personal" : "Persönlich",
     "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
     "You created calendar {calendar}" : "Du hast den Kalender {calendar} erstellt",
@@ -14,10 +14,10 @@ OC.L10N.register(
     "You restored calendar {calendar}" : "Du hast den Kalender {calendar} wiederhergestellt",
     "You shared calendar {calendar} as public link" : "Du hast den Kalender {calendar} als öffentlichen Link geteilt",
     "You removed public link for calendar {calendar}" : "Du hast den öffentlichen Link für Kalender {calendar} entfernt",
-    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit Dir geteilt",
+    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit dir geteilt",
     "You shared calendar {calendar} with {user}" : "Du hast den Kalender {calendar} mit {user} geteilt",
     "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
-    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit Dir",
+    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit dir",
     "You unshared calendar {calendar} from {user}" : "Du teilst den Kalender {calendar} nicht mehr mit {user}",
     "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
     "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
@@ -25,36 +25,41 @@ OC.L10N.register(
     "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
     "You unshared calendar {calendar} from group {group}" : "Du teilst den Kalender {calendar} nicht mehr mit der Gruppe {group}",
     "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
+    "Untitled event" : "Unbenannter Termin",
     "{actor} created event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} erstellt",
     "You created event {event} in calendar {calendar}" : "Du hast den Termin {event} im Kalender {calendar} erstellt",
     "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} gelöscht",
     "You deleted event {event} from calendar {calendar}" : "Du hast den Termin {event} im Kalender {calendar} gelöscht",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} aktualisiert",
     "You updated event {event} in calendar {calendar}" : "Du hast den Termin {event} im Kalender {calendar} aktualisiert",
-    "{actor} restored event {event} of calendar {calendar}" : "{actor} hat das Adressbuch {addressbook} mit Dir geteilt",
+    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} hat das Ereignis {event} vom Kalender {sourceCalendar} in den Kalender {targetCalendar} verschoben",
+    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Du hast das Ereignis {event} vom Kalender {sourceCalendar} in den Kalender {targetCalendar} verschoben",
+    "{actor} restored event {event} of calendar {calendar}" : "{actor} hat das Adressbuch {addressbook} mit dir geteilt",
     "You restored event {event} of calendar {calendar}" : "Du hast den Termin {event} im Kalender {calendar} wiederhergestellt",
     "Busy" : "Beschäftigt",
-    "{actor} created todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
-    "You created todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erstellt",
-    "{actor} deleted todo {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} gelöscht",
-    "You deleted todo {todo} from list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} gelöscht",
-    "{actor} updated todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
-    "You updated todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} aktualisiert",
-    "{actor} solved todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
-    "You solved todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erledigt",
-    "{actor} reopened todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
-    "You reopened todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
+    "{actor} created to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
+    "You created to-do {todo} in list {calendar}" : "Du hast eine Aufgabe {todo} in der Liste {calendar} erstellt",
+    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} aus der Liste {calendar} gelöscht",
+    "You deleted to-do {todo} from list {calendar}" : "Du hast die Aufgabe {todo} aus der Liste {calendar} gelöscht",
+    "{actor} updated to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
+    "You updated to-do {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} aktualisiert",
+    "{actor} solved to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
+    "You solved to-do {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erledigt",
+    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
+    "You reopened to-do {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
+    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} hat die Aufgabe {todo} von der Liste {sourceCalendar} in die Liste {targetCalendar} verschoben",
+    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Du hast die Aufgabe {todo} von der Liste {sourceCalendar} in die Liste {targetCalendar} verschoben",
     "Calendar, contacts and tasks" : "Kalender, Kontakte und Aufgaben",
     "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
     "A calendar <strong>event</strong> was modified" : "Ein Kalender-<strong>Termin</strong> wurde bearbeitet",
-    "A calendar <strong>todo</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde bearbeitet",
+    "A calendar <strong>to-do</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde geändert",
     "Contact birthdays" : "Geburtstage von Kontakten",
     "Death of %s" : "Todestag von %s",
+    "Untitled calendar" : "Unbenannter Kalender",
     "Calendar:" : "Kalender:",
     "Date:" : "Datum:",
     "Where:" : "Wo:",
     "Description:" : "Beschreibung:",
-    "Untitled event" : "Termin ohne Titel",
     "_%n year_::_%n years_" : ["%n Jahr","%n Jahre"],
     "_%n month_::_%n months_" : ["%n Monat","%n Monate"],
     "_%n day_::_%n days_" : ["%n Tag","%n Tage"],
@@ -68,17 +73,22 @@ OC.L10N.register(
     "Where: %s" : "Ort: %s",
     "%1$s via %2$s" : "%1$s über %2$s",
     "Cancelled: %1$s" : "Abgesagt: %1$s",
-    "Invitation canceled" : "Einladung abgebrochen",
+    "\"%1$s\" has been canceled" : "\"%1$s\" wurde abgebrochen.",
     "Re: %1$s" : "Re: %1$s",
-    "Invitation updated" : "Einladung aktualisiert",
+    "%1$s has accepted your invitation" : "%1$s hat deine Einladung angenommen.",
+    "%1$s has tentatively accepted your invitation" : "%1$s hat deine Einladung vorläufig angenommen.",
+    "%1$s has declined your invitation" : "%1$s hat deine Einladung abgelehnt.",
+    "%1$s has responded to your invitation" : "%1$s hat auf deine Einladung geantwortet.",
+    "Invitation updated: %1$s" : "Einladung aktualisiert: %1$s",
+    "%1$s updated the event \"%2$s\"" : "%1$s hat die Veranstaltung \"%2$s\" aktualisiert",
     "Invitation: %1$s" : "Einladung: %1$s",
-    "Invitation" : "Einladung",
+    "%1$s would like to invite you to \"%2$s\"" : "%1$s möchte dich zu \"%2$s\" einladen.",
+    "Organizer:" : "Organisator:",
+    "Attendees:" : "Teilnehmer:",
     "Title:" : "Titel:",
     "Time:" : "Zeit:",
     "Location:" : "Ort:",
     "Link:" : "Link:",
-    "Organizer:" : "Organisator:",
-    "Attendees:" : "Teilnehmer:",
     "Accept" : "Akzeptieren",
     "Decline" : "Ablehnen",
     "More options …" : "Weitere Optionen …",
@@ -90,13 +100,13 @@ OC.L10N.register(
     "You deleted address book {addressbook}" : "Du hast das Adressbuch {addressbook} gelöscht",
     "{actor} updated address book {addressbook}" : "{actor} hat das Adressbuch {addressbook} aktualisiert",
     "You updated address book {addressbook}" : "Du hast das Adressbuch {addressbook} aktualisiert",
-    "{actor} shared address book {addressbook} with you" : "{actor} hat das Adressbuch {addressbook} mit Dir geteilt",
+    "{actor} shared address book {addressbook} with you" : "{actor} hat das Adressbuch {addressbook} mit dir geteilt",
     "You shared address book {addressbook} with {user}" : "Du hast das Adressbuch {addressbook} geteilt",
     "{actor} shared address book {addressbook} with {user}" : "{actor} hat das Adressbuch {addressbook} mit {user} geteilt",
-    "{actor} unshared address book {addressbook} from you" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit Dir",
+    "{actor} unshared address book {addressbook} from you" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit dir.",
     "You unshared address book {addressbook} from {user}" : "Du teilst das Adressbuch {addressbook} nicht mehr mit {user}",
     "{actor} unshared address book {addressbook} from {user}" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit {user}",
-    "{actor} unshared address book {addressbook} from themselves" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit Dir",
+    "{actor} unshared address book {addressbook} from themselves" : "{actor} teilt das Adressbuch {addressbook} nicht mehr mit dir.",
     "You shared address book {addressbook} with group {group}" : "Du hast das Adressbuch {addressbook} mit der Gruppe {group} geteilt",
     "{actor} shared address book {addressbook} with group {group}" : "{actor} hat das Adressbuch {addressbook} mit der Gruppe {group} geteilt",
     "You unshared address book {addressbook} from group {group}" : "Du teilst das Adressbuch {addressbook} nicht mehr mit der Gruppe {group}",
@@ -108,6 +118,25 @@ OC.L10N.register(
     "{actor} updated contact {card} in address book {addressbook}" : "{actor} hat den Kontakt {card} im Adressbuch {addressbook} aktualisiert",
     "You updated contact {card} in address book {addressbook}" : "Du hast den Kontakt {card} im Adressbuch {addressbook} aktualisiert",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Ein <strong>Kontakt</strong> oder ein <strong>Adressbuch</strong> wurde geändert",
+    "Accounts" : "Konten",
+    "System address book which holds all accounts" : "Systemadressbuch, das alle Konten enthält",
+    "File is not updatable: %1$s" : "Datei kann nicht aktualisiert werden: %1$s",
+    "Could not write to final file, canceled by hook" : "In die endgültige Datei konnte nicht geschrieben werden, wurde durch einen Hook abgebrochen",
+    "Could not write file contents" : "Dateiinhalt konnte nicht  geschrieben werden",
+    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
+    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Fehler beim Kopieren der Datei in den Zielspeicherort (kopiert: %1$s, erwartete Dateigröße: %2$s)",
+    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Erwartete Dateigröße von %1$s, aber %2$s gelesen (vom Nextcloud-Client) und geschrieben (in den Nextcloud-Speicher). Dies kann entweder ein Netzwerkproblem auf der sendenden Seite oder ein Problem beim Schreiben in den Speicher auf der Serverseite sein.",
+    "Could not rename part file to final file, canceled by hook" : "Konnte temporäre Datei nicht in die endgültige Datei umbenennen, wurde durch einen Hook abgebrochen",
+    "Could not rename part file to final file" : "Konnte temporäre Datei nicht in die endgültige Datei umbenennen",
+    "Failed to check file size: %1$s" : "Dateigröße konnte nicht überprüft werden: %1$s",
+    "Could not open file" : "Datei konnte nicht geöffnet werden",
+    "Encryption not ready: %1$s" : "Verschlüsselung nicht bereit: %1$s",
+    "Failed to open file: %1$s" : "Datei konnte nicht geöffnet werden: %1$s",
+    "Failed to unlink: %1$s" : "Fehler beim Aufheben der Verknüpfung: %1$s",
+    "Invalid chunk name" : "Ungültiger Chunk-Name",
+    "Could not rename part file assembled from chunks" : "Aus Chunks zusammengesetzte temporäre Datei konnte nicht umbenannt werden",
+    "Failed to write file contents: %1$s" : "Fehler beim Schreiben des Dateiinhaltes: %1$s",
+    "File not found: %1$s" : "Datei nicht gefunden: %1$s",
     "System is in maintenance mode." : "Das System befindet sich im Wartungsmodus.",
     "Upgrade needed" : "Aktualisierung erforderlich",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Dein %s muss konfiguriert werden, um HTTPS zusammen mit CalDAV und CardDAV unter iOS/macOS nutzen zu können.",
@@ -119,13 +148,18 @@ OC.L10N.register(
     "Completed on %s" : "Erledigt am %s",
     "Due on %s by %s" : "Fällig am %s von %s",
     "Due on %s" : "Fällig am %s",
+    "Migrated calendar (%1$s)" : "Migrierter Kalender (%1$s)",
+    "Calendars including events, details and attendees" : "Kalender mit Terminen, Details und Teilnehmern",
+    "Contacts and groups" : "Kontakte und Gruppen",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAV-Endpunkt",
     "Availability" : "Verfügbarkeit",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Wenn Du Deine Arbeitszeiten konfigurierst, können andere Benutzer sehen, wann Du nicht im Büro bist, wenn sie eine Besprechung buchen.",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Wenn du deine Arbeitszeiten konfigurierst, können andere Benutzer sehen, wann du nicht im Büro bist, wenn sie eine Besprechung buchen.",
+    "Time zone:" : "Zeitzone:",
+    "to" : "an",
     "Delete slot" : "Slot löschen",
+    "No working hours set" : "Keine Arbeitszeiten konfiguriert",
     "Add slot" : "Slot hinzufügen",
-    "Save" : "Speichern",
     "Monday" : "Montag",
     "Tuesday" : "Dienstag",
     "Wednesday" : "Mittwoch",
@@ -133,23 +167,42 @@ OC.L10N.register(
     "Friday" : "Freitag",
     "Saturday" : "Samstag",
     "Sunday" : "Sonntag",
+    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Setze den Benutzerstatus automatisch auf „Nicht stören“, wenn du nicht erreichbar bist, um alle Benachrichtigungen stumm zu schalten.",
+    "Save" : "Speichern",
+    "Failed to load availability" : "Fehler beim Laden der Verfügbarkeit",
+    "Saved availability" : "Verfügbarkeit gespeichert",
+    "Failed to save availability" : "Fehler beim Speichern der Verfügbarkeit",
     "Calendar server" : "Kalender-Server",
-    "Send invitations to attendees" : "Einladungen an die Teilnehmer versenden",
+    "Send invitations to attendees" : "Einladungen an die Teilnehmer senden",
     "Automatically generate a birthday calendar" : "Automatisch einen Kalender für Geburtstage erstellen",
     "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einem Hintergrund-Auftrag erstellt",
-    "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es ein wenig dauern bis zur Anzeige.",
+    "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es bis zur Anzeige ein wenig dauern.",
     "Send notifications for events" : "Sende Benachrichtigungen für Termine",
-    "Notifications are sent via background jobs, so these must occur often enough." : "Benachrichtigungen werden von Hintergrundjobs versendet, so dass diese häufig genug ausgeführt werden müssen.",
+    "Notifications are sent via background jobs, so these must occur often enough." : "Benachrichtigungen werden von Hintergrundjobs gesendet, so dass diese häufig genug ausgeführt werden.",
+    "Send reminder notifications to calendar sharees as well" : "Erinnerungsbenachrichtigungen auch an die freigegebenen Kalender senden",
+    "Reminders are always sent to organizers and attendees." : "Erinnerungen werden immer an Organisatoren und Teilnehmer gesendet.",
     "Enable notifications for events via push" : "Benachrichtigungen für Termine per Push aktivieren",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installiere außerdem die {calendarappstoreopen}Kalender-App{linkclose} oder {calendardocopen}verbinde Deinen Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stelle sicher, dass Du {emailopen}den E-Mail Server{linkclose} ordnungsgemäß einrichtest.",
-    "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren Deines Teilnehmerstatus aufgetreten.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installiere außerdem die {calendarappstoreopen}Kalender-App{linkclose} oder {calendardocopen}verbinde deinen Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stelle sicher, dass du {emailopen}den E-Mail Server{linkclose} ordnungsgemäß einrichtest.",
+    "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren deines Teilnehmerstatus aufgetreten.",
     "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
     "Are you accepting the invitation?" : "Die Einladung annehmen?",
     "Tentative" : "Vorläufig",
-    "Number of guests" : "Anzahl Gäste",
-    "Comment" : "Kommentar",
     "Your attendance was updated successfully." : "Dein Teilnehmerstatus wurde aktualisiert.",
-    "Calendar and tasks" : "Kalender und Aufgaben"
+    "Todos" : "Aufgaben",
+    "{actor} created todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
+    "You created todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erstellt",
+    "{actor} deleted todo {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} gelöscht",
+    "You deleted todo {todo} from list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} gelöscht",
+    "{actor} updated todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
+    "You updated todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} aktualisiert",
+    "{actor} solved todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
+    "You solved todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} erledigt",
+    "{actor} reopened todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
+    "You reopened todo {todo} in list {calendar}" : "Du hast die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
+    "A calendar <strong>todo</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde bearbeitet",
+    "Invitation canceled" : "Einladung abgebrochen",
+    "Invitation updated" : "Einladung aktualisiert",
+    "Invitation" : "Einladung"
 },
 "nplurals=2; plural=(n != 1);");
