@@ -2,6 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Agenda",
+    "To-dos" : "Pense-bêtes",
     "Personal" : "Personnel",
     "{actor} created calendar {calendar}" : "{actor} a créé l'agenda {calendar}",
     "You created calendar {calendar}" : "Vous avez créé l'agenda {calendar}",
@@ -31,14 +32,30 @@ OC.L10N.register(
     "You deleted event {event} from calendar {calendar}" : "Vous avez supprimé l'évènement {event} de l'agenda {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} a mis à jour l'évènement {event} dans l'agenda {calendar}",
     "You updated event {event} in calendar {calendar}" : "Vous avez mis à jour l'évènement {event} dans l'agenda {calendar}",
+    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} a déplacé l'événement {event} du calendrier {sourceCalendar} au calendrier {targetCalendar}",
+    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Vous avez déplacé l'événement {event} du calendrier {sourceCalendar} au calendrier {targetCalendar}",
     "{actor} restored event {event} of calendar {calendar}" : "{actor} a restauré l'événement {event} dans l'agenda {calendar}",
     "You restored event {event} of calendar {calendar}" : "Vous avez restauré l'événement {event} dans l'agenda {calendar}",
     "Busy" : "Occupé",
+    "{actor} created to-do {todo} in list {calendar}" : "{actor} a créé la tâche {todo} dans la liste {calendar}",
+    "You created to-do {todo} in list {calendar}" : "Vous avez créé un pense-bête {todo} dans la liste {calendar}",
+    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} a supprimé un pense-bête {todo} de la liste {calendar}",
+    "You deleted to-do {todo} from list {calendar}" : "Vous avez supprimé le pense-bête {todo} de la liste {calendar}",
+    "{actor} updated to-do {todo} in list {calendar}" : "{actor} a mis à jour le pense-bête {todo} dans la liste {calendar}",
+    "You updated to-do {todo} in list {calendar}" : "Vous avez mis à jour le pense-bête {todo} dans la liste {calendar}",
+    "{actor} solved to-do {todo} in list {calendar}" : "{actor} a résolu le pense-bête {todo} dans la liste {calendar}",
+    "You solved to-do {todo} in list {calendar}" : "Vous avez résolu le pense-bête {todo} dans la liste {calendar}",
+    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} a réouvert le pense-bête {todo} dans la liste {calendar}",
+    "You reopened to-do {todo} in list {calendar}" : "Vous avez réouvert le pense-bête {todo} dans la liste {calendar}",
+    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} a déplacé le pense-bête {todo} de la liste {sourceCalendar} à la liste {targetCalendar}",
+    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Vous avez déplacé le pense-bête {todo} de la liste {sourceCalendar} à la liste {targetCalendar}",
     "Calendar, contacts and tasks" : "Agenda, contacts et tâches",
     "A <strong>calendar</strong> was modified" : "Un <strong>agenda</strong> a été modifié",
     "A calendar <strong>event</strong> was modified" : "Un <strong>événement</strong> de l'agenda a été modifié",
+    "A calendar <strong>to-do</strong> was modified" : "Un calendrier <strong>de tâches</strong> a été modifié",
     "Contact birthdays" : "Anniversaires des contacts",
     "Death of %s" : "Mort de %s",
+    "Untitled calendar" : "Calendrier sans titre",
     "Calendar:" : "Agenda:",
     "Date:" : "Date:",
     "Where:" : "Où :",
@@ -56,20 +73,25 @@ OC.L10N.register(
     "Where: %s" : "Où : %s",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Cancelled: %1$s" : "Annulé : %1$s",
-    "Invitation canceled" : "Invitation annulée",
+    "\"%1$s\" has been canceled" : "\"%1$s\" a été annulé(e)",
     "Re: %1$s" : "Re : %1$s",
-    "Invitation updated" : "Invitation mise à jour",
+    "%1$s has accepted your invitation" : "%1$s a accepté votre invitation",
+    "%1$s has tentatively accepted your invitation" : "%1$s a provisoirement accepté votre invitation",
+    "%1$s has declined your invitation" : "%1$s a décliné votre invitation",
+    "%1$s has responded to your invitation" : "%1$s a répondu à votre invitation",
+    "Invitation updated: %1$s" : "Invitation mise à jour : %1$s",
+    "%1$s updated the event \"%2$s\"" : "%1$s a mis à jour l'évènement %2$s",
     "Invitation: %1$s" : "Invitation : %1$s",
-    "Invitation" : "Invitation",
+    "%1$s would like to invite you to \"%2$s\"" : "%1$s souhaite vous inviter à \"%2$s\"",
+    "Organizer:" : "Organisateur :",
+    "Attendees:" : "Participants :",
     "Title:" : "Titre :",
     "Time:" : "Heure :",
     "Location:" : "Localisation :",
     "Link:" : "Lien :",
-    "Organizer:" : "Organisateur :",
-    "Attendees:" : "Participants :",
     "Accept" : "Accepter",
     "Decline" : "Refuser",
-    "More options …" : "Plus d'options …",
+    "More options …" : "Plus d'options…",
     "More options at %s" : "Plus d'options à %s",
     "Contacts" : "Contacts",
     "{actor} created address book {addressbook}" : "{actor} a créé le carnet d'adresses {addressbook}",
@@ -96,6 +118,8 @@ OC.L10N.register(
     "{actor} updated contact {card} in address book {addressbook}" : "{actor} a mis à jour le contact {card} dans le carnet d'adresses {addressbook}",
     "You updated contact {card} in address book {addressbook}" : "Vous avez mis à jour le contact {card} dans le carnet d'adresses {addressbook}",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Un <strong>contact</strong> ou <strong>carnet d'adresses</strong> a été modifié",
+    "Accounts" : "Comptes",
+    "System address book which holds all accounts" : "Annuaire système qui regroupe tous les comptes",
     "File is not updatable: %1$s" : "Ce fichier ne peut pas être mis à jour : %1$s",
     "Could not write to final file, canceled by hook" : "Impossible d'écrire dans le fichier final, annulé par le hook",
     "Could not write file contents" : "Impossible d'écrire le contenu du fichier",
@@ -143,7 +167,11 @@ OC.L10N.register(
     "Friday" : "Vendredi",
     "Saturday" : "Samedi",
     "Sunday" : "Dimanche",
+    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Définir automatiquement le statut \"Ne pas déranger\" en dehors des heures de disponibilité pour désactiver toutes les notifications.",
     "Save" : "Enregistrer",
+    "Failed to load availability" : "Impossible de charger la disponibilité",
+    "Saved availability" : "Disponibilité sauvegardée",
+    "Failed to save availability" : "Impossible de sauvegarder la disponibilité",
     "Calendar server" : "Serveur de calendrier",
     "Send invitations to attendees" : "Envoyer des invitations aux participants",
     "Automatically generate a birthday calendar" : "Générer automatiquement un agenda d'anniversaire",
@@ -155,13 +183,11 @@ OC.L10N.register(
     "Reminders are always sent to organizers and attendees." : "Des rappels sont toujours envoyés aux organisateurs et aux participants.",
     "Enable notifications for events via push" : "Activer les notifications push pour les évènements",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer aussi {calendarappstoreopen}l'application Calendrier{linkclose}, ou {calendardocopen}connecter à votre PC & téléphone pour synchroniser ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Merci de vérifier d'avoir correctement configuré {emailopen}le serveur de courriel{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Merci de vérifier d'avoir correctement configuré {emailopen}le serveur de messagerie{linkclose}.",
     "There was an error updating your attendance status." : "Une erreur s'est produite lors de la mise à jour de votre statut de présence.",
     "Please contact the organizer directly." : "Merci de contacter l'organisateur directement.",
     "Are you accepting the invitation?" : "Acceptez-vous l'invitation ?",
     "Tentative" : "Provisoire",
-    "Number of guests" : "Nombre d'invités",
-    "Comment" : "Commentaire",
     "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès.",
     "Todos" : "Tâches",
     "{actor} created todo {todo} in list {calendar}" : "{actor} a créé la tâche {todo} dans la liste {calendar}",
@@ -174,6 +200,9 @@ OC.L10N.register(
     "You solved todo {todo} in list {calendar}" : "Vous avez terminé la tâche {todo} de la liste {calendar}",
     "{actor} reopened todo {todo} in list {calendar}" : "{actor} a réouvert la tâche {todo} dans la liste {calendar}",
     "You reopened todo {todo} in list {calendar}" : "Vous avez réouvert la tâche {todo} dans la liste {calendar}",
-    "A calendar <strong>todo</strong> was modified" : "Une <strong>liste de tâches</strong> de l'agenda a été modifiée"
+    "A calendar <strong>todo</strong> was modified" : "Une <strong>liste de tâches</strong> de l'agenda a été modifiée",
+    "Invitation canceled" : "Invitation annulée",
+    "Invitation updated" : "Invitation mise à jour",
+    "Invitation" : "Invitation"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
