@@ -125,6 +125,7 @@ OC.L10N.register(
     "Due on %s by %s" : "Scade il %s per %s",
     "Due on %s" : "Scade il %s",
     "Migrated calendar (%1$s)" : "Calendario migrato (%1$s)",
+    "Calendars including events, details and attendees" : "Calendari inclusi eventi, dettagli e partecipanti",
     "Contacts and groups" : "Contatti e gruppi",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "Terminatore WebDAV",
@@ -150,6 +151,8 @@ OC.L10N.register(
     "Hence they will not be available immediately after enabling but will show up after some time." : "Per cui non saranno disponibili immediatamente dopo l'abilitazione, ma saranno mostrati dopo qualche istante.",
     "Send notifications for events" : "Invia notifiche per eventi",
     "Notifications are sent via background jobs, so these must occur often enough." : "Le notifiche saranno inviate tramite operazioni in background, per cui tali operazioni devono essere eseguite abbastanza spesso.",
+    "Send reminder notifications to calendar sharees as well" : "Invia notifiche di promemoria anche ai partecipanti al calendario",
+    "Reminders are always sent to organizers and attendees." : "I promemoria vengono sempre inviati agli organizzatori e ai partecipanti.",
     "Enable notifications for events via push" : "Abilita notifiche per eventi tramite push",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installa anche {calendarappstoreopen}l'applicazione Calendario{linkclose}, o {calendardocopen}connetti il tuo desktop e mobile per la sincronizzazione ↗{linkclose}.",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assicurati di configurare correttamente {emailopen}il server di posta{linkclose}.",
