@@ -28,15 +28,15 @@ OC.L10N.register(
     "Bad Signature" : "壞的簽名",
     "Missing Signature" : "缺少簽名",
     "one-time password for server-side-encryption" : "用於伺服器端加密的一次性密碼",
+    "Encryption password" : "加密密碼",
+    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "管理啟用了伺服器端加密 您的檔案已使用密碼 <strong>%s</strong> 加密。",
+    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "管理員啟用了伺服器端加密。您的檔案已使用密碼 \"%s\" 加密。",
+    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password." : "請登錄到網絡界面，轉到您個人設置的“安全”部分，並通過在“舊登錄密碼”字段中輸入此密碼和您當前的登錄密碼來更新您的登入密碼。",
     "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法解密這個檔案，也許這是分享的檔案。請讓檔案所有者與您重新共享檔案。",
     "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法檢視這個檔案，或許這是分享的檔案。請讓檔案所有者與您重新共享檔案。",
     "Default encryption module" : "默認加密模組",
     "Default encryption module for server-side encryption" : "伺服器端的默認加密模組",
-    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "為了使用此加密模組，您需要啟用伺服器端\n管理員設置中的加密設定。 啟用後，該模組將加密您的所有之後傳輸的檔案。 此加密方式使用AES 256密鑰。\n該模組不會觸及已存在的檔案，只會加密新處理的檔案\n啟用伺服器端加密後。 也不可能\n再次停用加密，然後切換回未加密的系統。\n在決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。",
-    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password \"%s\".\n\nPlease login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.\n\n" : "嗨，\n\n系管理員啟用了伺服器端的加密功能，您的檔案將會使用密碼 \"%s\" 加密\n\n請從網頁登入，到 \"basic encryption module\" 設置您的個人設定並透過更新加密密碼，將這個組密碼設定在 \"old log-in password\" 以及您的目前登入密碼\n",
-    "The share will expire on %s." : "這個分享將會於 %s 過期。",
-    "Cheers!" : "太棒了！",
-    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "嗨，請看這裡，<br><br>系管理員啟用了伺服器端的加密功能，您的檔案將會使用密碼<strong> '%s' </strong>加密，請從網頁登入，到 'basic encryption module' 設置您的個人設定並透過更新加密密碼，將這個組密碼設定在 'old log-in password'  以及您的目前登入密碼<br><br>",
+    "In order to use this encryption module you need to enable server-side encryption in the admin settings. Once enabled this module will encrypt all your files transparently. The encryption is based on AES 256 keys.\nThe module will not touch existing files, only new files will be encrypted after server-side encryption was enabled. It is also not possible to disable the encryption again and switch back to an unencrypted system.\nPlease read the documentation to know all implications before you decide to enable server-side encryption." : "您需要在管理員設置中啟用服務器端加密才能使用此加密模塊您需要在管理員設置中啟用服務器端加密。啟用後，此模塊將透明地加密您的所有文件。加密基於 AES 256 密鑰。\n該模塊不會觸及現有文件，啟用伺服器端加密後只會對新檔案進行加密。也不可能再次禁用加密並切換回未加密的系統。\n在您決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。一旦啟用，此模塊將透明地加密您的所有文件。加密基於 AES 256 密鑰。\n該模塊不會觸及現有文件，啟伺服器端加密後只會對新文件進行加密。也不可能再次禁用加密並切換回未加密的系統。\n在您決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。",
     "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "已啟用加密應用，但是你的加密密鑰沒有初始化。請重新登出並登入系統一次。",
     "Encrypt the home storage" : "加密主要存儲空間",
     "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "請啟用這個功能以用來加密主要儲存空間的檔案，否則只有再外部儲存的檔案會加密",
@@ -61,8 +61,10 @@ OC.L10N.register(
     "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "啟用這個選項將會允許您因忘記密碼但需要存取您的加密檔案",
     "Enabled" : "已啓用",
     "Disabled" : "已停用",
-    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法解密這個檔案，也許這是分享的檔案。請詢問檔案所有人重新分享檔案給您。",
-    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "無法檢視這個檔案，或許這是分享的檔案，請詢問這個檔案的擁有者並請他重新分享給您。",
-    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "嗨，請看這裡，\n\n系管理員啟用了伺服器端的加密功能，您的檔案將會使用密碼 '%s' 加密\n\n請從網頁登入，到 'basic encryption module' 設置您的個人設定並透過更新加密密碼，將這個組密碼設定在 'old log-in password'  以及您的目前登入密碼\n"
+    "In order to use this encryption module you need to enable server-side\n\t\tencryption in the admin settings. Once enabled this module will encrypt\n\t\tall your files transparently. The encryption is based on AES 256 keys.\n\t\tThe module won't touch existing files, only new files will be encrypted\n\t\tafter server-side encryption was enabled. It is also not possible to\n\t\tdisable the encryption again and switch back to a unencrypted system.\n\t\tPlease read the documentation to know all implications before you decide\n\t\tto enable server-side encryption." : "為了使用此加密模組，您需要啟用伺服器端\n管理員設置中的加密設定。啟用後，該模組將加密您的所有之後傳輸的檔案。此加密方式使用AES 256密鑰。\n該模組不會觸及已存在的檔案，只會加密新處理的檔案\n啟用伺服器端加密後。也不可能\n再次停用加密，然後切換回未加密的系統。\n在決定啟用伺服器端加密之前，請閱讀文檔以了解所有含義。",
+    "Hey there,\n\nThe administration enabled server-side-encryption. Your files were encrypted using the password \"%s\".\n\nPlease login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.\n\n" : "嗨，\n\n系管理員啟用了伺服器端的加密功能，您的檔案已使用密碼 \"%s\" 加密。\n\n請使用網頁介面登入，到您個人設定中的「基本加密模組」，並在「舊登入密碼」欄位輸入此密碼與您目前的登入密碼來更新加密密碼。\n",
+    "The share will expire on %s." : "這個分享將會於 %s 過期。",
+    "Cheers!" : "太棒了！",
+    "Hey there,<br><br>The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"Basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"Old log-in password\" field and your current login-password.<br><br>" : "嗨，<br><br>管理員啟用了伺服器端加密的功能，您的檔案已使用密碼<strong>%s</strong>加密。<br><br>請使用網頁界面 登入，到您個人設定中的「基本加密模組」，並在「舊登入密碼」欄位輸入此密碼與您目前的登入密碼來更新加密密碼。<br><br>"
 },
 "nplurals=1; plural=0;");
