@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "リモート共有のパスワード",
     "Cancel" : "キャンセル",
     "Add remote share" : "リモート共有を追加",
-    "Copy" : "コピー",
-    "Copied!" : "コピーしました！",
-    "Not supported!" : "サポートされていません！",
-    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
-    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
     "Invalid Federated Cloud ID" : "無効なクラウド共有ID",
     "Server to server sharing is not enabled on this server" : "このサーバーでは、サーバー間の共有が有効ではありません",
     "Couldn't establish a federated share." : "クラウド共有を接続できませんでした。",
@@ -25,15 +20,11 @@ OC.L10N.register(
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s の共有に失敗しました。%2$s が見つかりませんでした。おそらくサーバーに接続できないか、自己証明書を使用しています。",
     "Could not find share" : "共有が見つかりませんでした",
     "Federated sharing" : "連携共有",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "%4$s (%1$s)からリモート共有として \"%3$s\" を受け取りました(%5$s(%2$s)の代理として)",
     "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user} からリモート共有として {share} を受け取りました。({behalf} の代理として)",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "  %4$s (%1$s)からリモート共有として \"%3$s\" を受け取りました",
     "You received {share} as a remote share from {user}" : "{user} から {file} のリモート共有が届いています",
     "Accept" : "承諾",
     "Decline" : "拒否",
     "Federated Cloud Sharing" : "統合されたクラウド共有",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "#Nextcloud の「クラウド共有ID」で私と共有できます。こちらを見てください。%s",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud の「クラウド共有ID」で私と共有できます。",
     "Sharing" : "共有中",
     "Federated file sharing" : "連携共有",
     "Provide federated file sharing across servers" : "サーバー間でフェデレーションファイル共有を提供する",
@@ -46,13 +37,24 @@ OC.L10N.register(
     "Allow users to publish their data to a global and public address book" : "公開アドレス帳をグローバルに公開することをユーザーに許可する",
     "Unable to update federated files sharing config" : "クラウド共有設定を更新できませんでした",
     "Federated Cloud" : "クラウド共有",
-    "Open documentation" : "ドキュメントを開く",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud サーバーまたはその他の Open Cloud Mesh (OCM) 互換のサーバーとサービスを使用しているユーザーであれば、共有ダイアログに Federated Cloud ID を入力するだけで誰とでも共有できます。例: person@cloud.example.com",
     "Your Federated Cloud ID:" : "あなたのクラウド共有ID：",
     "Share it so your friends can share files with you:" : "友達があなたとファイルを共有できるよう、シェアしましょう:",
+    "Twitter" : "Twitter",
     "Add to your website" : "ウェブサイトに追加",
     "Share with me via Nextcloud" : "Nextcloud 経由で共有",
     "HTML Code:" : "HTMLコード:",
-    "Adjust how people can share between servers." : "サーバー間でどうやって共有するかを調整します。"
+    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud の「クラウド共有ID」で私と共有できます。",
+    "Copy to clipboard" : "クリップボードにコピー",
+    "Clipboard is not available" : "クリップボードは利用できません",
+    "Copied!" : "コピーしました！",
+    "Copy" : "コピー",
+    "Not supported!" : "サポートされていません！",
+    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
+    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "%4$s (%1$s)からリモート共有として \"%3$s\" を受け取りました(%5$s(%2$s)の代理として)",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "  %4$s (%1$s)からリモート共有として \"%3$s\" を受け取りました",
+    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "#Nextcloud の「クラウド共有ID」で私と共有できます。こちらを見てください。%s",
+    "Open documentation" : "ドキュメントを開く"
 },
 "nplurals=1; plural=0;");
