@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "Nuotolinio viešinio slaptažodis",
     "Cancel" : "Atsisakyti",
     "Add remote share" : "Pridėti nuotolinį viešinį",
-    "Copy" : "Kopijuoti",
-    "Copied!" : "Nukopijuota!",
-    "Not supported!" : "Nepalaikoma!",
-    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
-    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
     "Invalid Federated Cloud ID" : "Neteisingas federacinės debesijos ID",
     "Server to server sharing is not enabled on this server" : "Dalinimasis tarp serverių yra neleidžiamas šiame serveryje",
     "Couldn't establish a federated share." : "Nepavyko užmegzti federacinio viešinio.",
@@ -28,7 +23,6 @@ OC.L10N.register(
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
     "Federated Cloud Sharing" : "Bendrinimas federacinėje debesijoje",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "Bendrinti su manimi per mano #Nextcloud federacinės debesijos ID",
     "Sharing" : "Duomenų bendrinimas",
     "Federated file sharing" : "Federacinis failų bendrinimas",
     "Allow users on this server to receive shares from other servers" : "Leisti naudotojams šiame serveryje gauti viešinius iš kitų serverių",
@@ -37,10 +31,19 @@ OC.L10N.register(
     "Search global and public address book for users" : "Ieškoti naudotojų visuotinėje ir viešoje adresų knygoje",
     "Allow users to publish their data to a global and public address book" : "Leisti naudotojams paskelbti savo duomenis visuotinėje ir viešoje adresų knygoje",
     "Federated Cloud" : "Federacinė debesija",
-    "Open documentation" : "Atverti dokumentaciją",
     "Your Federated Cloud ID:" : "Jūsų federacinės debesijos ID:",
     "Share it so your friends can share files with you:" : "Pasidalinkite juo, kad jūsų draugai galėtų bendrinti failus kartu su jumis:",
+    "Facebook" : "„Facebook“",
+    "Twitter" : "Twitter",
     "HTML Code:" : "HTML kodas:",
-    "Adjust how people can share between servers." : "Derinkite kaip žmonės gali bendrinti tarp serverių."
+    "Share with me through my #Nextcloud Federated Cloud ID" : "Bendrinti su manimi per mano #Nextcloud federacinės debesijos ID",
+    "Copy to clipboard" : "Kopijuoti į iškarpinę",
+    "Clipboard is not available" : "Iškarpinė neprieinama",
+    "Copied!" : "Nukopijuota!",
+    "Copy" : "Kopijuoti",
+    "Not supported!" : "Nepalaikoma!",
+    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
+    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
+    "Open documentation" : "Atverti dokumentaciją"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
