@@ -1,13 +1,13 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente",
-    "Storage invalid" : "Almacenamiento no válido",
-    "Unknown error" : "Error desconocido",
     "File could not be found" : "El archivo no se ha encontrado",
     "Move or copy" : "Mover o copiar",
     "Download" : "Descargar",
     "Delete" : "Eliminar",
+    "Tags" : "Etiquetas",
+    "Show list view" : "Mostrar vista de lista",
+    "Show grid view" : "Mostrar vista de cuadrícula",
     "Home" : "Inicio",
     "Close" : "Cerrar",
     "Favorites" : "Favoritos",
@@ -21,6 +21,7 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
     "Not enough free space" : "No hay espacio libre suficiente",
     "An unknown error has occurred" : "Ha ocurrido un error desconocido",
+    "File could not be uploaded" : "No se ha podido subir el archivo",
     "Uploading …" : "Subiendo …",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Subir este archivo no es compatible",
@@ -29,8 +30,10 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Error al reunir los trozos, código de estado {status}",
     "Actions" : "Acciones",
     "Rename" : "Renombrar",
+    "Move" : "Mover",
     "Copy" : "Copiar",
     "Choose target folder" : "Elegir carpeta de destino",
+    "Edit locally" : "Editar localmente",
     "Open" : "Abrir",
     "Delete file" : "Eliminar archivo",
     "Delete folder" : "Eliminar carpeta",
@@ -39,11 +42,15 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "No se ha podido cargar información para el archivo \"{file}\"",
     "Files" : "Archivos",
     "Details" : "Detalles",
-    "Select" : "Seleccionar",
+    "Please select tag(s) to add to the selection" : "Seleccione la(s) etiqueta(s) para añadir a la selección",
+    "Apply tag(s) to selection" : "Aplicar etiqueta(s) a la selección",
+    "Select directory \"{dirName}\"" : "Seleccione el directorio \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Seleccione el archivo \"{fileName}\"",
     "Pending" : "Pendiente",
     "Unable to determine date" : "No se ha podido determinar la fecha",
     "This operation is forbidden" : "Esta operación está prohibida",
     "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contacte con el administrador",
+    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente",
     "Could not move \"{file}\", target exists" : "No se pudo mover \"{file}\", ya existe",
     "Could not move \"{file}\"" : "No se pudo mover \"{file}\"",
     "copy" : "copiar",
@@ -51,6 +58,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "No se ha podido copiar \"{file}\"",
     "Copied {origin} inside {destination}" : "Se ha copiado {origin} dentro de {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Se han copiado {origin} y {nbfiles} otros archivos dentro de {destination}",
+    "Failed to redirect to client" : "Fallo al redirigir al cliente",
     "{newName} already exists" : "{newName} ya existe",
     "Could not rename \"{fileName}\", it does not exist any more" : "No se pudo renombrar \"{fileName}\", ya no existe",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elija un nombre diferente.",
@@ -65,40 +73,44 @@ OC.L10N.register(
     "Name" : "Nombre",
     "Size" : "Tamaño",
     "Modified" : "Modificado",
-    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
-    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
+    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
+    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
     "{dirs} and {files}" : "{dirs} y {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos"],
-    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí",
-    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
-    "New" : "Nuevo",
+    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
+    "You do not have permission to upload or create files here" : "No tienes permiso para subir o crear archivos aquí",
+    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos","Subiendo %n archivos"],
+    "New file/folder menu" : "Menú de carpeta/archivo nuevo",
     "Select file range" : "Seleccionar el rango de archivos",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} usados de {quota}",
     "{used} used" : "{used} usados",
     "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
     "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
     "\"/\" is not allowed inside a file name." : "\"/\" no se permite en un nombre de archivo.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" no es un tipo de archivo permitido",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El espacio de {owner} está lleno, ¡no se subirán ni se sincronizarán más archivos!",
-    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "¡La carpeta de grupo  \"{mountPoint}\" está llena, los archivos ya no pueden ser actualizados o sincronizados!.",
-    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "¡El almacenamiento externo  \"{mountPoint}\" está lleno, los archivos ya no pueden ser actualizados o sincronizados!.",
-    "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno, ¡no se subirán ni se sincronizarán más archivos!",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "El almacenamiento de {owner} está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta de grupo \"{mountPoint}\" está llena. ¡No se puede actualizar o sincronizar ningún archivo más!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "El almacenamiento externo \"{mountPoint}\" está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Tu almacenamiento está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
     "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%).",
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
-    "_matches '{filter}'_::_match '{filter}'_" : ["coincidencias '{filter}'","coincidencia '{filter}'"],
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coinciden \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
     "View in folder" : "Ver en carpeta",
-    "Copied!" : "¡Copiado!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "Path" : "Ruta",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
+    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Favorited" : "Agregado a favoritos",
     "Favorite" : "Favorito",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un solo archivo o carpeta cada vez",
     "New folder" : "Nueva carpeta",
+    "Create new folder" : "Crear nueva carpeta",
     "Upload file" : "Subir archivo",
     "Recent" : "Reciente",
+    "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}",
     "Not favorited" : "Quitado como favorito",
     "Remove from favorites" : "Quitar de favoritos",
     "Add to favorites" : "Añadir a favoritos",
@@ -130,7 +142,13 @@ OC.L10N.register(
     "{user} deleted an encrypted file in {file}" : "{user} ha borrado un archivo cifrado en {file}",
     "You restored {file}" : "Has restaurado {file}",
     "{user} restored {file}" : "{user} restauró {file}",
+    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Has renombrado {oldfile} (oculto) a {newfile} (oculto)",
+    "You renamed {oldfile} (hidden) to {newfile}" : "Has renombrado {oldfile} (oculto) a {newfile}",
+    "You renamed {oldfile} to {newfile} (hidden)" : "Has renombrado {oldfile} a {newfile} (oculto)",
     "You renamed {oldfile} to {newfile}" : "Has renombrado {oldfile} a {newfile}",
+    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renombró {oldfile} (oculto) a {newfile} (oculto)",
+    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renombró {oldfile} (oculto) a {newfile}",
+    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renombró {oldfile} a {newfile} (oculto)",
     "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile} a {newfile}",
     "You moved {oldfile} to {newfile}" : "Has movido {oldfile} a {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
@@ -138,7 +156,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
     "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>cambiado</strong>",
     "All files" : "Todos los archivos",
-    "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Subida (máx. %s)",
     "Accept" : "Aceptar",
     "Reject" : "Rechazar",
@@ -152,37 +169,77 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
     "in %s" : "en %s",
     "File Management" : "Gestión de archivos",
+    "Reload current directory" : "Recargar directorio actual",
+    "Go to the \"{dir}\" directory" : "Ir al directorio \"{dir}\"",
+    "Select the row for {displayName}" : "Seleccione la fila para {displayName}",
+    "Open folder {name}" : "Abrir carpeta {name}",
+    "Download file {name}" : "Descargar archivo {name}",
+    "\"{displayName}\" action executed successfully" : "la acción \"{displayName}\" se ejecutó exitósamente",
+    "\"{displayName}\" action failed" : "la acción \"{displayName}\" falló",
+    "Total rows summary" : "Resumen de filas totales",
+    "Select all" : "Seleccionar todo",
+    "Unselect all" : "Deseleccionar todos",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" fallo en algunos elementos",
+    "\"{displayName}\" batch action executed successfully" : "la acción en lotes \"{displayName}\" se ejecutó exitósamente",
+    "ascending" : "ascendente",
+    "descending" : "descendente",
+    "Sort list by {column} ({direction})" : "Ordenar lista por {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista no se renderiza completa por razones de rendimiento. Los archivos serán renderizados mientras ud. navegue por la lista.",
+    "Storage informations" : "Informaciones de almacenamiento",
+    "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
+    "{relative}% used" : "{relative}% utilizado",
+    "Could not refresh storage stats" : "No fue posible refrescar las estadísticas de almacenamiento",
     "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
     "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
     "Change" : "Cambiar",
     "New owner" : "Nuevo propietario",
-    "Search users" : "Buscar usuarios",
     "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
     "Transfer" : "Transferir",
     "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
     "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
+    "Unknown error" : "Error desconocido",
     "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
-    "Cannot transfer ownership of a file or folder you don't own" : "No se puede transferir la propiedad de un archivo o carpeta que no te pertenece",
-    "Tags" : "Etiquetas",
+    "Cannot transfer ownership of a file or folder you do not own" : "No puedes transferir la propiedad de un archivo o directorio del cual no eres propietario",
+    "Select file or folder to link to" : "Selecciona archivo o carpeta a enlazar",
+    "Loading current folder" : "Cargando carpeta actual",
+    "No files in here" : "Aquí no hay archivos",
+    "No files or folders have been deleted yet" : "No se han borrado archivos o carpetas todavía",
+    "Go to the previous folder" : "Ir a la carpeta anterior",
+    "Go back" : "Ir atrás",
+    "Open the files app settings" : "Abrir la configuración de la app Archivos",
+    "Files settings" : "Configuración de archivos",
+    "File cannot be accessed" : "El archivo no puede ser accesado",
+    "You might not have have permissions to view it, ask the sender to share it" : "Puede que no tenga permisos para verlo, solicite al remitente que lo comparta",
+    "Show hidden files" : "Mostrar archivos ocultos",
+    "Crop image previews" : "Recortar la previsualización de las imágenes",
+    "Additional settings" : "Configuración adicional",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copiar al portapapeles",
+    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
+    "Clipboard is not available" : "El portapapeles no está disponible",
+    "WebDAV URL copied to clipboard" : "El URL Webdav URL fue copiado al portapapeles",
     "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
     "Error while loading the file data" : "Error al cargar los datos del archivo",
-    "%s used" : "usado %s",
-    "%s%% of %s used" : "%s%% de %s usado",
-    "%1$s of %2$s used" : "%1$s de %2$s usados",
-    "Settings" : "Ajustes",
-    "Show hidden files" : "Mostrar archivos ocultos",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
+    "Pick a template for {name}" : "Elija una plantilla para {name}",
+    "Create" : "Crear",
+    "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
+    "Creating file" : "Creando el archivo",
+    "Blank" : "Vacío",
+    "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
+    "Delete permanently" : "Eliminar de forma definitiva",
+    "Set up templates folder" : "Configura una carpeta para plantillas",
+    "Templates" : "Plantillas",
+    "Create new templates folder" : "Crear nueva carpeta de plantillas",
+    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
+    "Toggle %1$s sublist" : "Alternar %1$s sublista",
     "Toggle grid view" : "Alternar vista de cuadrícula",
-    "No files in here" : "Aquí no hay archivos",
     "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
     "No entries found in this folder" : "No hay entradas en esta carpeta",
-    "Select all" : "Seleccionar todo",
     "Upload too large" : "Subida demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
-    "Deleted files" : "Archivos eliminados",
     "Shares" : "Archivos compartidos",
     "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido conmigo",
@@ -191,17 +248,19 @@ OC.L10N.register(
     "Pending shares" : "Recursos compartidos pendientes",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo archivo.txt",
-    "Unshare" : "Dejar de compartir",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El espacio de {owner} está casi lleno en un ({usedSpacePercent}%)",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%)",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Tu espacio está casi lleno, ({usedSpacePercent}%)",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong> o <strong>renombrado</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
-    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaciones sobre la creación y cambios en tus <strong>archivos favoritos</strong> <em>(solo transmisión)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
-    "Cannot transfter ownership of a file or folder you don't own" : "No se puede transferir la propiedad de un archivo o carpeta que no te pertenece",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Usa esta dirección para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">acceder a tus archivos vía WebDAV</a>"
+    "Storage invalid" : "Almacenamiento no válido",
+    "Select" : "Seleccionar",
+    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí",
+    "New" : "Nuevo",
+    "Copied!" : "¡Copiado!",
+    "Unlimited" : "Ilimitado",
+    "Search users" : "Buscar usuarios",
+    "Cannot transfer ownership of a file or folder you don't own" : "No se puede transferir la propiedad de un archivo o carpeta que no te pertenece",
+    "Cancel" : "Cancelar",
+    "%s used" : "usado %s",
+    "%s%%" : "%s%%",
+    "%1$s of %2$s used" : "%1$s de %2$s usados",
+    "Settings" : "Ajustes",
+    "Deleted files" : "Archivos eliminados"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
