@@ -1,13 +1,11 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
-    "Storage invalid" : "El almacenamiento es inválido",
-    "Unknown error" : "Se presentó un error desconocido",
     "File could not be found" : "No fue posible encontrar el archivo",
     "Move or copy" : "Mover o copiar",
     "Download" : "Descargar",
     "Delete" : "Borrar",
+    "Tags" : "Etiquetas",
     "Home" : "Inicio",
     "Close" : "Cerrar",
     "Favorites" : "Favoritos",
@@ -24,6 +22,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Se presentó un error al ensamblar los bloques, código de estatus {status}",
     "Actions" : "Acciones",
     "Rename" : "Renombrar",
+    "Move" : "Mover",
     "Copy" : "Copiar",
     "Delete file" : "Borrar archivo",
     "Delete folder" : "Borrar carpeta",
@@ -35,6 +34,7 @@ OC.L10N.register(
     "Unable to determine date" : "No fue posible determinar la fecha",
     "This operation is forbidden" : "Esta operación está prohibida",
     "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
+    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
     "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
     "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
     "Could not copy \"{file}\", target exists" : "No se pudo copiar \"{file}\", el destino ya existe",
@@ -58,7 +58,6 @@ OC.L10N.register(
     "{dirs} and {files}" : "{dirs} y {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
     "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos","Cargando %n archivos"],
-    "New" : "Nuevo",
     "{used} of {quota} used" : "{used} de {quota} usados",
     "{used} used" : "{used} usados",
     "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido. ",
@@ -66,13 +65,13 @@ OC.L10N.register(
     "\"/\" is not allowed inside a file name." : "No se permite el uso del caracter \"/\" en el nombre del archivo.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" es un tipo de archivo no permitido",
     "View in folder" : "Ver en la carpeta",
-    "Copied!" : "¡Copiado!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Favorited" : "Marcado como favorito",
     "Favorite" : "Favorito",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "New folder" : "Carpeta nueva",
+    "Create new folder" : "Crear nueva carpeta",
     "Upload file" : "Cargar archivo",
     "Recent" : "Reciente",
     "Not favorited" : "No es un favorito",
@@ -113,35 +112,42 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de tus <strong>favoritos</strong>",
     "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong>",
     "All files" : "Todos los archivos",
-    "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Cargar (max. %s)",
     "Accept" : "Aceptar",
     "in %s" : "en %s",
+    "Select all" : "Seleccionar todo",
     "Change" : "Cambiar",
-    "Tags" : "Etiquetas",
-    "Cancel" : "Cancelar",
-    "Create" : "Crear",
-    "%s used" : "%s usado",
-    "%1$s of %2$s used" : "%1$s de %2$s usados",
-    "Settings" : "Configuraciones ",
-    "Show hidden files" : "Mostrar archivos ocultos",
-    "WebDAV" : "WebDAV",
+    "Unknown error" : "Se presentó un error desconocido",
     "No files in here" : "No hay archivos aquí",
+    "Go back" : "Regresar",
+    "Show hidden files" : "Mostrar archivos ocultos",
+    "Additional settings" : "Configuraciones adicionales",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copiar al portapapeles",
+    "Create" : "Crear",
+    "Delete permanently" : "Borrar permanentemente",
     "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
-    "Select all" : "Seleccionar todo",
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
-    "Deleted files" : "Papelera",
     "Shares" : "Elementos compartidos",
     "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido con usted",
     "Shared by link" : "Compartido por liga",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
+    "Storage invalid" : "El almacenamiento es inválido",
     "Select" : "Seleccionar",
-    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí"
+    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
+    "New" : "Nuevo",
+    "Copied!" : "¡Copiado!",
+    "Unlimited" : "Ilimitado",
+    "Cancel" : "Cancelar",
+    "%s used" : "%s usado",
+    "%1$s of %2$s used" : "%1$s de %2$s usados",
+    "Settings" : "Configuraciones ",
+    "Deleted files" : "Papelera"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
