@@ -1,13 +1,11 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
-    "Storage invalid" : "A tároló érvénytelen",
-    "Unknown error" : "Ismeretlen hiba",
     "File could not be found" : "Fájl nem található",
     "Move or copy" : "Áthelyezés vagy másolás",
     "Download" : "Letöltés",
     "Delete" : "Törlés",
+    "Tags" : "Címkék",
     "Show list view" : "Listanézet megjelenítése",
     "Show grid view" : "Rácsnézet megjelenítése",
     "Home" : "Saját mappa",
@@ -35,6 +33,7 @@ OC.L10N.register(
     "Move" : "Áthelyezés",
     "Copy" : "Másolás",
     "Choose target folder" : "Válasszon célmappát",
+    "Edit locally" : "Szerkesztés helyileg",
     "Open" : "Megnyitás",
     "Delete file" : "Fájl törlése",
     "Delete folder" : "Mappa törlése",
@@ -51,6 +50,7 @@ OC.L10N.register(
     "Unable to determine date" : "Nem lehet meghatározni a dátumot",
     "This operation is forbidden" : "Ez a művelet tiltott",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ez a könyvtár nem érhető el, nézze meg a naplófájlokat vagy lépjen kapcsolatba az adminisztrátorral",
+    "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
     "Could not move \"{file}\", target exists" : "A(z) „{file}” nem helyezhető át, mert a cél már létezik",
     "Could not move \"{file}\"" : "A(z) „{file}” nem helyezhető át",
     "copy" : "másolat",
@@ -58,6 +58,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "A(z) „{file}” másolása sikertelen",
     "Copied {origin} inside {destination}" : "A(z) {origin} átmásolva ide: {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "A(z) {origin} és {nbfiles} egyéb fájl átmásolva ide: {destination}",
+    "Failed to redirect to client" : "Nem sikerült az átirányítás a klienshez",
     "{newName} already exists" : "A(z) {newName} már létezik",
     "Could not rename \"{fileName}\", it does not exist any more" : "A(z) „{fileName}” átnevetése sikertelen, mert már nem létezik",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "A(z) „{targetName}” név már használatban van a(z) „{dir}” mappában. Válasszon másik nevet.",
@@ -97,14 +98,15 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Tárhelye majdnem megtelt ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["megfelel ennek: „{filter}”","megfelel ennek: „{filter}”"],
     "View in folder" : "Megtekintés mappában",
-    "Copied!" : "Másolva!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Közvetlen hivatkozás másolása (csak azoknál a felhasználóknál működik, akiknek hozzáférése van a fájlhoz/mappához)",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "A közvetlen hivatkozás másolva (csak azon felhasználóknak működik, akik elérik ezt a fájlt/mappát)",
     "Path" : "Útvonal",
     "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
     "Favorited" : "Kedvenc",
     "Favorite" : "Kedvenc",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Közvetlen hivatkozás másolása (csak azoknál a felhasználóknál működik, akiknek hozzáférése van a fájlhoz/mappához)",
     "You can only favorite a single file or folder at a time" : "Egyszerre csak egy fájlt vagy mappát jelölhet meg kedvencként",
     "New folder" : "Új mappa",
+    "Create new folder" : "Új mappa létrehozása",
     "Upload file" : "Fájl feltöltése",
     "Recent" : "Legutóbbi",
     "Not favorited" : "Nincs a kedvencek között",
@@ -152,7 +154,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Egy fájl vagy mappa <strong>megváltozott</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Egy kedvenc fájl vagy mappa <strong> megváltozott</strong>",
     "All files" : "Az összes fájl",
-    "Unlimited" : "Korlátlan",
     "Upload (max. %s)" : "Feltöltés (legfeljebb %s)",
     "Accept" : "Elfogadás",
     "Reject" : "Elutasítás",
@@ -166,49 +167,76 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "A(z) {path} tulajdonjogának átruházása {user} részéről sikeres.",
     "in %s" : "itt:  %s",
     "File Management" : "Fájlkezelés",
+    "Reload current directory" : "Jelenlegi könyvtár újratöltése",
+    "Go to the \"{dir}\" directory" : "Ugrás a(z) „{dir}” könyvtárhoz",
+    "Select the row for {displayName}" : "A(z) {displayName} sorának kiválasztása",
+    "Open folder {name}" : "A(z) {name} mappa megnyitása",
+    "Download file {name}" : "A(z) {name} fájl letöltése",
+    "\"{displayName}\" action executed successfully" : "A(z) „{displayName}” művelet sikeresen végrehajtva",
+    "\"{displayName}\" action failed" : "A(z) „{displayName}” művelet sikertelen",
+    "Total rows summary" : "Összes sor összegzése",
+    "Select all" : "Összes kijelölése",
+    "Unselect all" : "Kijelölés megszüntetése",
+    "\"{displayName}\" failed on some elements " : "A(z) „{displayName}” sikertelen volt néhány elemen",
+    "\"{displayName}\" batch action executed successfully" : "A(z) „{displayName}” tömeges művelet sikeresen végrehajtva",
+    "ascending" : "növekvő",
+    "descending" : "csökkenő",
+    "Sort list by {column} ({direction})" : "Lista rendezése {column} alapján ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ez a lista teljesítménybeli okokból nincs teljes egészében megjelenítve. A fájlok a listában navigálás során jelennek meg, ",
+    "Storage informations" : "Tárhely-információk",
+    "{usedQuotaByte} used" : "{usedQuotaByte} felhasználva",
+    "{relative}% used" : "{relative}% felhasználva",
+    "Could not refresh storage stats" : "Nem sikerült frissíteni a tárhelystatisztikákat",
     "Transfer ownership of a file or folder" : "Fájl vagy mappa tulajdonjogának átruházása",
     "Choose file or folder to transfer" : "Válasszon egy fájlt vagy mappát az átruházáshoz",
     "Change" : "Módosítás",
     "New owner" : "Új tulajdonos",
-    "Search users" : "Fehasználók keresése",
     "Choose a file or folder to transfer" : "Válassz egy átruházandó fájlt vagy mappát",
     "Transfer" : "Átruházás",
     "Transfer {path} to {userid}" : "{path} átruházása {userid} számára",
     "Invalid path selected" : "Érvénytelen útvonal kiválasztva",
+    "Unknown error" : "Ismeretlen hiba",
     "Ownership transfer request sent" : "Tulajdonjog átruházási kérés elküldve",
     "Cannot transfer ownership of a file or folder you do not own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
-    "Tags" : "Címkék",
+    "Select file or folder to link to" : "Válassza ki a hivatkozandó fájlt vagy mappát",
+    "Loading current folder" : "Jelenlegi mappa betöltése",
+    "No files in here" : "Itt nincsenek fájlok",
+    "No files or folders have been deleted yet" : "Még nem lettek fájlok vagy mappák törölve",
+    "Go to the previous folder" : "Ugrás az előző mappához",
+    "Go back" : "Visszalépés",
+    "Open the files app settings" : "Nyissa meg a Fájlok lalkalmazás beállításait",
+    "Files settings" : "Fájlok beállításai",
+    "File cannot be accessed" : "A fájl nem érhető el",
+    "You might not have have permissions to view it, ask the sender to share it" : "Lehet, hogy nincs jogosultsága, hogy megtekintse, kérje meg a küldőt, hogy ossza meg",
+    "Show hidden files" : "Rejtett fájlok megjelenítése",
+    "Crop image previews" : "Kép előnézetek vágása",
+    "Additional settings" : "További beállítások",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Másolás a vágólapra",
+    "Use this address to access your Files via WebDAV" : "Ezzel a címmel férhet hozzá a Fájlokhoz a WebDAV-on keresztül",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ha engedélyezte a kétfaktoros hitelesítést, akkor kattintson ide, hogy létrehozzon egy új alkalmazásjelszót, és azt használja.",
+    "Clipboard is not available" : "A vágólap nem érhető el",
+    "WebDAV URL copied to clipboard" : "A WebDAV-cím a vágólapra másolva",
     "Unable to change the favourite state of the file" : "Nem lehet megváltoztatni a fájl kedvenc állapotát",
     "Error while loading the file data" : "Hiba történt a fájladatok betöltése közben",
     "Pick a template for {name}" : "Válassz sablont a(z) {name} fájlnak",
-    "Cancel" : "Mégse",
     "Create" : "Létrehozás",
     "Create a new file with the selected template" : "Új fájl létrehozása a kiválasztott sablonnal",
     "Creating file" : "Fájl létrehozása",
     "Blank" : "Üres",
     "Unable to create new file from template" : "Nem lehet új fájlt létrehozni a sablonból",
+    "Delete permanently" : "Végleges törlés",
     "Set up templates folder" : "Személyes sablonmappa beállítása",
     "Templates" : "Sablonok",
     "Unable to initialize the templates directory" : "A sablonkönyvtár előkészítése sikertelen",
-    "%s used" : "%s használt",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s / %2$s felhasználva",
-    "Files settings" : "Fájlok beállításai",
-    "Show hidden files" : "Rejtett fájlok megjelenítése",
-    "Crop image previews" : "Kép előnézetek vágása",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Ezzel a címmel férhet hozzá a Fájlokhoz a WebDAV-on keresztül",
     "Toggle %1$s sublist" : "%1$s allista be/ki",
     "Toggle grid view" : "Rácsnézet be/ki",
-    "No files in here" : "Itt nincsenek fájlok",
     "Upload some content or sync with your devices!" : "Töltsön fel néhány tartalmat, vagy szinkronizáljon az eszközeivel.",
     "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
-    "Select all" : "Összes kijelölése",
     "Upload too large" : "A feltöltés túl nagy",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltölteni próbált fájlok mérete meghaladja a kiszolgálón megengedett legnagyobb méretet.",
     "No favorites yet" : "Még nincsenek kedvencek",
     "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találja meg",
-    "Deleted files" : "Törölt fájlok",
     "Shares" : "Megosztások",
     "Shared with others" : "Megosztva másokkal",
     "Shared with you" : "Megosztva Önnel",
@@ -217,11 +245,19 @@ OC.L10N.register(
     "Pending shares" : "Függőben lévő megosztások",
     "Text file" : "Szövegfájl",
     "New text file.txt" : "Új szövegfájl.txt",
+    "Storage invalid" : "A tároló érvénytelen",
     "Select" : "Kiválasztás",
     "You don’t have permission to upload or create files here" : "Nincs jogosultsága fájlok ide feltöltéséhez vagy létrehozásához",
     "New" : "Új",
+    "Copied!" : "Másolva!",
+    "Unlimited" : "Korlátlan",
+    "Search users" : "Fehasználók keresése",
     "Cannot transfer ownership of a file or folder you don't own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
-    "%s%% of %s used" : "%s %% / %s felhasználva",
-    "Settings" : "Beállítások"
+    "Cancel" : "Mégse",
+    "%s used" : "%s használt",
+    "%s%%" : "%s%%",
+    "%1$s of %2$s used" : "%1$s / %2$s felhasználva",
+    "Settings" : "Beállítások",
+    "Deleted files" : "Törölt fájlok"
 },
 "nplurals=2; plural=(n != 1);");
