@@ -1,13 +1,13 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
-    "Storage invalid" : "Ógild geymsla",
-    "Unknown error" : "Óþekkt villa",
     "File could not be found" : "Skrá finnst ekki",
     "Move or copy" : "Færa eða afrita",
     "Download" : "Niðurhal",
     "Delete" : "Eyða",
+    "Tags" : "Merki",
+    "Show list view" : "Birta listasýn",
+    "Show grid view" : "Birta reitasýn",
     "Home" : "Heim",
     "Close" : "Loka",
     "Favorites" : "Eftirlæti",
@@ -21,27 +21,31 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "Markmappan \"{dir}\" er ekki lengur til",
     "Not enough free space" : "Ekki nægilegt pláss",
     "An unknown error has occurred" : "Óþekkt villa kom upp",
+    "File could not be uploaded" : "Gat ekki sent inn skrána",
     "Uploading …" : "Sendi inn …",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Innsending á þessu atriði er ekki studd",
     "Target folder does not exist any more" : "Markmappan er ekki lengur til",
+    "Operation is blocked by access control" : "Aðgerðin er hindruð af aðgangsstýringu",
     "Error when assembling chunks, status code {status}" : "Villa við að setja búta saman, stöðukóði {status}",
     "Actions" : "Aðgerðir",
     "Rename" : "Endurnefna",
+    "Move" : "Færa",
     "Copy" : "Afrita",
     "Choose target folder" : "Veldu úttaksmöppu",
     "Open" : "Opna",
     "Delete file" : "Eyða skrá",
     "Delete folder" : "Eyða möppu",
     "Disconnect storage" : "Aftengja geymslu",
+    "Leave this share" : "Leave this share",
     "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
     "Files" : "Skrár",
     "Details" : "Nánar",
-    "Select" : "Velja",
     "Pending" : "Í bið",
     "Unable to determine date" : "Tókst ekki að ákvarða dagsetningu",
     "This operation is forbidden" : "Þessi aðgerð er bönnuð",
     "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu atvikaskrár eða hafðu samband við kerfissjóra",
+    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
     "Could not move \"{file}\", target exists" : "Gat ekki fært \"{file}\", markskrá er til",
     "Could not move \"{file}\"" : "Gat ekki fært \"{file}\"",
     "copy" : "afrit",
@@ -65,9 +69,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n skrá","%n skrár"],
     "{dirs} and {files}" : "{dirs} og {files}",
     "_including %n hidden_::_including %n hidden_" : ["þar á meðal %n falin","þar á meðal %n faldar"],
-    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
     "_Uploading %n file_::_Uploading %n files_" : ["Sendi inn %n skrá","Sendi inn %n skrár"],
-    "New" : "Nýtt",
     "Select file range" : "Veldu skráasvið",
     "{used} of {quota} used" : "{used} af {quota} notað",
     "{used} used" : "{used} notað",
@@ -75,18 +77,15 @@ OC.L10N.register(
     "File name cannot be empty." : "Heiti skráar má ekki vera tómt",
     "\"/\" is not allowed inside a file name." : "\"/\" er er ekki leyfilegt innan í skráarheiti.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" er ógild skráartegund",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Geymslupláss {owner} er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
-    "_matches '{filter}'_::_match '{filter}'_" : ["samsvarar '{filter}'","samsvara '{filter}'"],
     "View in folder" : "Skoða í möppu",
-    "Copied!" : "Afritað!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Afrita beinan tengil (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
     "Path" : "Slóð",
     "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
     "Favorited" : "Sett í eftirlæti",
     "Favorite" : "Eftirlæti",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Afrita beinan tengil (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
     "You can only favorite a single file or folder at a time" : "Þú getur aðeins bætt einni skrá eða möppu í einu í eftilæti",
     "New folder" : "Ný mappa",
+    "Create new folder" : "Búa til nýja möppu",
     "Upload file" : "Senda inn skrá",
     "Recent" : "Nýlegt",
     "Not favorited" : "Ekki í eftirlætum",
@@ -127,7 +126,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Skrá var bætt við eða hún fjarlægð úr <strong>eftirlætum</strong>",
     "A file or folder has been <strong>changed</strong>" : "Skjali eða möppu hefur verið <strong>breytt</strong>",
     "All files" : "Allar skrár",
-    "Unlimited" : "Ótakmarkað",
     "Upload (max. %s)" : "Senda inn (hám. %s)",
     "Accept" : "Samþykkja",
     "Reject" : "Hafna",
@@ -135,36 +133,42 @@ OC.L10N.register(
     "Ownership transfer done" : "Millifærslu eignarhalds er lokið",
     "in %s" : "í %s",
     "File Management" : "Skráastjórnun",
+    "Select all" : "Velja allt",
     "Transfer ownership of a file or folder" : "Millifæra eignarhald skráar eða möppu",
     "Choose file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
     "Change" : "Breyta",
     "New owner" : "Nýr eigandi",
-    "Search users" : "Leita að notendum",
     "Choose a file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
     "Transfer" : "Færa",
     "Transfer {path} to {userid}" : "Færa {path} til {userid}",
     "Invalid path selected" : "Ógild slóð valin",
+    "Unknown error" : "Óþekkt villa",
     "Ownership transfer request sent" : "Beiðni um millifærslu eignarhalds send",
-    "Cannot transfer ownership of a file or folder you don't own" : "Ekki er hægt að millifæra eignarhald á skrá eða möppu sem þú átt ekki",
-    "Tags" : "Merki",
-    "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
-    "%s used" : "%s notað",
-    "%s%% of %s used" : "%s%% af %s notað",
-    "%1$s of %2$s used" : "%1$s af %2$s notað",
-    "Settings" : "Stillingar",
-    "Show hidden files" : "Sýna faldar skrár",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Notaðu þetta vistfang til að nálgast skrárnar þínar með WebDAV",
-    "Toggle grid view" : "Víxla reitasýn af/á",
     "No files in here" : "Engar skrár hér",
+    "Go back" : "Fara til baka",
+    "Show hidden files" : "Sýna faldar skrár",
+    "Crop image previews" : "Skera utan af forskoðun mynda",
+    "Additional settings" : "Valfrjálsar stillingar",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Afrita á klippispjald",
+    "Use this address to access your Files via WebDAV" : "Notaðu þetta vistfang til að nálgast skrárnar þínar með WebDAV",
+    "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
+    "Create" : "Búa til",
+    "Create a new file with the selected template" : "Búa til nýja skrá úr völdu sniðmáti",
+    "Creating file" : "Bý til skrá",
+    "Blank" : "Tóm",
+    "Unable to create new file from template" : "Tekst ekki að búa til nýja skrá út frá sniðmáti",
+    "Delete permanently" : "Eyða varanlega",
+    "Set up templates folder" : "Setja upp sniðmátamöppu",
+    "Templates" : "Sniðmát",
+    "Unable to initialize the templates directory" : "Tókst ekki að frumstilla sniðmátamöppuna",
+    "Toggle grid view" : "Víxla reitasýn af/á",
     "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
     "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
-    "Select all" : "Velja allt",
     "Upload too large" : "Innsend skrá er of stór",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
     "No favorites yet" : "Engin eftirlæti ennþá",
     "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
-    "Deleted files" : "Eyddar skrár",
     "Shares" : "Sameignir",
     "Shared with others" : "Deilt með öðrum",
     "Shared with you" : "Deilt með þér",
@@ -173,15 +177,18 @@ OC.L10N.register(
     "Pending shares" : "Sameignir í bið",
     "Text file" : "Textaskrá",
     "New text file.txt" : "Ný textaskrá.txt",
-    "Unshare" : "Hætta deilingu",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Geymslupláss {owner} er næstum fullt ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%)",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Skrá eða möppu hefur verið <strong>breytt</strong> eða verið <strong>endurnefnt</strong>",
-    "A new file or folder has been <strong>created</strong>" : "Skjal eða mappa hefur verið <strong>búin til</strong>",
-    "A file or folder has been <strong>deleted</strong>" : "Skjali eða möppu hefur verið  <strong>eytt</strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Takmarka tilkynningar um gerð og breytingar á <strong>eftirlætisskrám</strong> <em>(einungis streymi)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Skjal eða mappa hefur verið <strong>endurheimt</strong>",
-    "Cannot transfter ownership of a file or folder you don't own" : "Ekki er hægt að millifæra eignarhald á skrá eða möppu sem þú átt ekki",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Notaðu þetta vistfang til að <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">nálgast skrárnar þínar með WebDAV</a>"
+    "Storage invalid" : "Ógild geymsla",
+    "Select" : "Velja",
+    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
+    "New" : "Nýtt",
+    "Copied!" : "Afritað!",
+    "Unlimited" : "Ótakmarkað",
+    "Search users" : "Leita að notendum",
+    "Cannot transfer ownership of a file or folder you don't own" : "Ekki er hægt að millifæra eignarhald á skrá eða möppu sem þú átt ekki",
+    "Cancel" : "Hætta við",
+    "%s used" : "%s notað",
+    "%1$s of %2$s used" : "%1$s af %2$s notað",
+    "Settings" : "Stillingar",
+    "Deleted files" : "Eyddar skrár"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
