@@ -1,13 +1,11 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
-    "Storage invalid" : "Lagringsplass ugyldig",
-    "Unknown error" : "Ukjent feil",
     "File could not be found" : "Filen ble ikke funnet",
     "Move or copy" : "Flytt eller kopier",
     "Download" : "Last ned",
     "Delete" : "Slett",
+    "Tags" : "Merkelapper",
     "Show list view" : "Vis listevisning",
     "Show grid view" : "Vis rutenett-visning",
     "Home" : "Hjem",
@@ -22,7 +20,7 @@ OC.L10N.register(
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp {size1} men bare {size2} er ledig",
     "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
     "Not enough free space" : "Ikke nok ledig diskplass",
-    "An unknown error has occurred" : "En ukjent feil oppstod",
+    "An unknown error has occurred" : "En ukjent feil oppsto",
     "File could not be uploaded" : "Fil kunne ikke lastes opp",
     "Uploading …" : "Laster opp…",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
@@ -35,6 +33,7 @@ OC.L10N.register(
     "Move" : "Flytt",
     "Copy" : "Kopier",
     "Choose target folder" : "Velg målmappe",
+    "Edit locally" : "Rediger lokalt",
     "Open" : "Åpne",
     "Delete file" : "Slett fil",
     "Delete folder" : "Slett mappe",
@@ -43,12 +42,15 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
     "Files" : "Filer",
     "Details" : "Detaljer",
+    "Please select tag(s) to add to the selection" : "Velg merkelapper(er) for å legge til utvalget",
+    "Apply tag(s) to selection" : "Bruk merkelapp(er) på utvalget",
     "Select directory \"{dirName}\"" : "Velg mappe \"{dirName}\"",
     "Select file \"{fileName}\"" : "Velg fil \"{fileName}\"",
     "Pending" : "Venter",
     "Unable to determine date" : "Kan ikke fastslå datoen",
     "This operation is forbidden" : "Operasjonen er forbudt",
     "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
+    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
     "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
     "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
     "copy" : "kopier",
@@ -56,6 +58,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Klarte ikke å kopiere \"{file}\"",
     "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
+    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
     "{newName} already exists" : "{newName} finnes allerede",
     "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
@@ -78,31 +81,38 @@ OC.L10N.register(
     "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
     "New file/folder menu" : "Ny fil/mappe-meny",
     "Select file range" : "Velg filutvalg",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} av {quota} brukt",
     "{used} used" : "{used} brukt",
     "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
     "File name cannot be empty." : "Filnavn kan ikke være tomt.",
     "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagringen av {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppemappen \"{mountPoint}\" er full, filer kan ikke oppdateres eller synkroniseres lenger!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ekstern lagring \"{mountPoint}\" er full, filer kan ikke oppdateres eller synkroniseres lenger!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Lagringen din er full, filer kan ikke oppdateres eller synkroniseres lenger!",
     "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%).",
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppemappen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Den eksterne lagringsplassen \"{mountPoint}\" er nesten full ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Din lagringsplass er nesten full ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Treffer \"{filter}\"","Treff \"{filter}\""],
     "View in folder" : "Vis i mappe",
-    "Copied!" : "Kopiert!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte lenke (virker bare for brukere som har tilgang til denne filen/mappa)",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktelenke ble kopiert (fungerer bare for brukere som har tilgang til denne filen/mappen)",
     "Path" : "Sti",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
     "Favorited" : "Favorisert",
     "Favorite" : "Gjør til favoritt",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direktelenke (fungerer bare for brukere som har tilgang til denne filen/mappen)",
     "You can only favorite a single file or folder at a time" : "Du kan bare legge til en fil av gangen til favoritter",
     "New folder" : "Ny mappe",
+    "Create new folder" : "Opprett ny mappe",
     "Upload file" : "Last opp fil",
     "Recent" : "Nylig",
     "Not favorited" : "Ikke i favoritter",
     "Remove from favorites" : "Fjern fra favoritter",
     "Add to favorites" : "Legg til i favoritter",
-    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av merkelappene",
+    "An error occurred while trying to update the tags" : "En feil oppsto under oppdatering av merkelappene",
     "Added to favorites" : "Lagt til i favoritter",
     "Removed from favorites" : "Fjernet fra favoritter",
     "You added {file} to your favorites" : "Du la til {file} i dine favoritter",
@@ -144,7 +154,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "En fil eller mappe ble <strong>endret</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "En favoritt-fil eller mappe har blitt <strong>endret</strong>",
     "All files" : "Alle filer",
-    "Unlimited" : "Ubegrenset",
     "Upload (max. %s)" : "Opplasting (maks %s)",
     "Accept" : "Aksepter",
     "Reject" : "Avvis",
@@ -158,38 +167,54 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Eierskapsoverføring av {path} fra {user} er ferdig.",
     "in %s" : "om %s",
     "File Management" : "Filbehandling",
+    "Select all" : "Velg alle",
+    "Storage informations" : "Informasjon om lagring",
+    "{usedQuotaByte} used" : "{usedQuotaByte} brukt",
+    "{relative}% used" : "{relative}% brukt",
+    "Could not refresh storage stats" : "Kunne ikke oppdatere lagringsstatistikk",
     "Transfer ownership of a file or folder" : "Eierskapsoverføring av en fil eller mappe",
     "Choose file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
     "Change" : "Endre",
     "New owner" : "Ny eier",
-    "Search users" : "Søk etter brukere",
     "Choose a file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
     "Transfer" : "Overfør",
     "Transfer {path} to {userid}" : "Overfør {path} til {userid}",
     "Invalid path selected" : "Ugyldig angitt sti",
+    "Unknown error" : "Ukjent feil",
     "Ownership transfer request sent" : "Forespørsel om overføring av eierskap er sendt",
-    "Tags" : "Merkelapper",
-    "Unable to change the favourite state of the file" : "Kan ikke endre favorittstatus til filen",
-    "Error while loading the file data" : "Feil ved lasting av fildata",
-    "Cancel" : "Avbryt",
-    "Create" : "Opprett",
-    "Creating file" : "Oppretter fil",
-    "%s used" : "%s brukt",
-    "%1$s of %2$s used" : "%1$s av %2$s brukt",
+    "Cannot transfer ownership of a file or folder you do not own" : "Kan ikke overføre eierskap til en fil eller mappe du ikke eier",
+    "No files in here" : "Ingen filer",
+    "Go back" : "Gå tilbake",
+    "Open the files app settings" : "Åpne Filer-appens innstillinger",
     "Files settings" : "Filinnstillinger",
     "Show hidden files" : "Vis skjulte filer",
+    "Crop image previews" : "Beskjær forhåndsvisninger av bilder",
+    "Additional settings" : "Flere innstillinger",
     "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Kopiert til utklippstavlen",
     "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
+    "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
+    "WebDAV URL copied to clipboard" : "WebDAV-URL kopiert til utklippstavlen",
+    "Unable to change the favourite state of the file" : "Kan ikke endre favorittstatus til filen",
+    "Error while loading the file data" : "Feil ved lasting av fildata",
+    "Pick a template for {name}" : "Velg en mal for {name}",
+    "Create" : "Opprett",
+    "Create a new file with the selected template" : "Opprett en ny fil med den valgte malen",
+    "Creating file" : "Oppretter fil",
+    "Blank" : "Tom",
+    "Unable to create new file from template" : "Kan ikke opprette ny fil fra malen",
+    "Delete permanently" : "Slett for godt",
+    "Set up templates folder" : "Sett opp mal-mappen",
+    "Templates" : "Maler",
+    "Unable to initialize the templates directory" : "Kan ikke initialisere mal-mappen",
+    "Toggle %1$s sublist" : "Veksle %1$s underliste",
     "Toggle grid view" : "Veksle rutenett-visning",
-    "No files in here" : "Ingen filer",
     "Upload some content or sync with your devices!" : "Last opp innhold eller synkroniser med enhetene dine!",
     "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
-    "Select all" : "Velg alle",
     "Upload too large" : "Filen er for stor",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
     "No favorites yet" : "Ingen favoritter enda",
     "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
-    "Deleted files" : "Slettede filer",
     "Shares" : "Delinger",
     "Shared with others" : "Delt med andre",
     "Shared with you" : "Delt med deg",
@@ -198,11 +223,19 @@ OC.L10N.register(
     "Pending shares" : "Ventende delinger",
     "Text file" : "Tekstfil",
     "New text file.txt" : "Ny tekstfil.txt",
+    "Storage invalid" : "Lagringsplass ugyldig",
     "Select" : "Velg",
     "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
     "New" : "Ny",
+    "Copied!" : "Kopiert!",
+    "Unlimited" : "Ubegrenset",
+    "Search users" : "Søk etter brukere",
     "Cannot transfer ownership of a file or folder you don't own" : "Kan ikke overføre eierskap til en fil eller mappe du ikke eier",
-    "%s%% of %s used" : "%s%% av %s brukt",
-    "Settings" : "Innstillinger"
+    "Cancel" : "Avbryt",
+    "%s used" : "%s brukt",
+    "%s%%" : "%s%%",
+    "%1$s of %2$s used" : "%1$s av %2$s brukt",
+    "Settings" : "Innstillinger",
+    "Deleted files" : "Slettede filer"
 },
 "nplurals=2; plural=(n != 1);");
