@@ -1,17 +1,13 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Depozita përkohësisht nuk është në dispozicion",
-    "Storage invalid" : "Depozitë e pavlefshme",
-    "Unknown error" : "Gabim i panjohur",
-    "All files" : "Të gjithë skedarët",
-    "Recent" : "Të fundit",
-    "Favorites" : "Të parapëlqyera",
     "File could not be found" : "Skedari s’u gjet dot",
     "Download" : "Shkarkoje",
     "Delete" : "Fshije",
+    "Tags" : "Etiketë",
     "Home" : "Kreu",
     "Close" : "Mbylle",
+    "Favorites" : "Të parapëlqyera",
     "Could not create folder \"{dir}\"" : "S’u krijua dot dosja \"{dir}\"",
     "Upload cancelled." : "Ngarkimi u anulua.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "S’arrihet të ngarkohet {filename}, ngaqë është drejtori ose ka 0 bajte",
@@ -21,19 +17,19 @@ OC.L10N.register(
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} nga {totalSize} ({bitrate})",
     "Actions" : "Veprime",
     "Rename" : "Riemërtojeni",
+    "Move" : "Zhvendos",
     "Copy" : "Kopjo",
     "Delete file" : "Fshi skedarin",
     "Delete folder" : "Fshini dosjen",
     "Disconnect storage" : "Shkëpute depozitën",
-    "Unshare" : "Hiqe ndarjen",
     "Could not load info for file \"{file}\"" : "Nuk mund të ngarkohet informacioni për skedarin \"{file}\"",
     "Files" : "Skedar",
     "Details" : "Hollësi",
-    "Select" : "Përzgjidhe",
     "Pending" : "Në pritje",
     "Unable to determine date" : "S’arrihet të përcaktohet data",
     "This operation is forbidden" : "Ky veprim është i ndaluar",
     "This directory is unavailable, please check the logs or contact the administrator" : "Kjo drejtori nuk kapet, ju lutemi, kontrolloni regjistrat ose lidhuni me përgjegjësin",
+    "Storage is temporarily not available" : "Depozita përkohësisht nuk është në dispozicion",
     "Could not move \"{file}\", target exists" : "S’u lëviz dot \"{file}\", objektivi ekziston",
     "Could not move \"{file}\"" : "S’u lëviz dot \"{file}\"",
     "copy" : "kopjo",
@@ -53,26 +49,20 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n kartelë","%n skedar"],
     "{dirs} and {files}" : "{dirs} dhe {files}",
     "_including %n hidden_::_including %n hidden_" : ["Përfshirë %n të fshehura","Përfshirë %n të fshehura"],
-    "You don’t have permission to upload or create files here" : "S’keni leje për të ngarkuar apo krijuar kartela këtu",
     "_Uploading %n file_::_Uploading %n files_" : ["Po ngarkohet %n kartelë","Po ngarkohen %n skedar"],
-    "New" : "E re",
     "\"{name}\" is an invalid file name." : "\"{name}\" është emër i pavlefshëm kartele.",
     "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
     "\"{name}\" is not an allowed filetype" : "\"{name}\" nuk është një lloj skedari i lejuar",
-    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Depozita e {owner} është plot, kartelat s’mund të përditësohen ose sinkronizohet më!",
-    "Your storage is full, files can not be updated or synced anymore!" : "Depozita juaj është plot, kartelat s’mund të përditësohen ose sinkronizohet më!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Depozita e {owner} është thuasje plot ({usedSpacePercent}%)",
-    "Your storage is almost full ({usedSpacePercent}%)" : "Depozita juaj është thuajse plot ({usedSpacePercent}%)",
-    "_matches '{filter}'_::_match '{filter}'_" : ["ka përputhje me '{filter}'","ka përputhje me '{filter}'"],
     "View in folder" : "Shikoje në dosje",
-    "Copied!" : "E kopjuar!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopjo lidhjen e drejtpërdrejtë (funksionon vetëm për përdoruesit që kanë qasje në këtë skedar/dosje)",
     "Path" : "Rrugë",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajte"],
     "Favorited" : "U kalua e parapëlqyer",
     "Favorite" : "E parapëlqyer",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopjo lidhjen e drejtpërdrejtë (funksionon vetëm për përdoruesit që kanë qasje në këtë skedar/dosje)",
     "New folder" : "Dosje e re",
+    "Create new folder" : "Krijo një dosje të re",
     "Upload file" : "Ngarko skedar",
+    "Recent" : "Të fundit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
     "An error occurred while trying to update the tags" : "Ndodhi një gabim teksa provohej të përditësoheshin etiketat",
@@ -102,30 +92,28 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Ju lëvizët {oldfile} në {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} lëvizi {oldfile} në {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Një skedar është shtuar ose është hequr nga <strong>të preferuarat</strong> tuaja",
-    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Një skedar ose dosje është <strong>ndryshuar</strong> ose <strong>riemëruar</strong>",
-    "A new file or folder has been <strong>created</strong>" : "<strong>U krijua</strong> një kartelë ose dosje e re",
-    "A file or folder has been <strong>deleted</strong>" : "Një skedar ose dosje është <strong> fshirë </strong>",
-    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Kufizojini njoftimet mbi krijim dhe ndryshim kartelash vetëm për <strong>kartelat tuaja të parapëlqyera</strong> <em>(Vetëm te rrjedha)</em>",
-    "A file or folder has been <strong>restored</strong>" : "Një skedar ose dosje është <strong> rikthyer </strong>",
-    "Unlimited" : "E palimituar",
+    "A file or folder has been <strong>changed</strong>" : "<strong>U ndryshua</strong> një kartelë ose dosje",
+    "All files" : "Të gjithë skedarët",
     "Upload (max. %s)" : "Ngarkim (max. %s)",
     "Accept" : "Prano",
+    "in %s" : "në %s",
+    "Select all" : "Përzgjidhe krejt",
     "Change" : "Ndrysho",
-    "%s used" : "%s të përdorura",
-    "%1$s of %2$s used" : "%1$s e %2$s përdorur",
-    "Settings" : "Rregullime",
-    "Show hidden files" : "Shfaq kartela të fshehura",
-    "WebDAV" : "WebDAV",
+    "Unknown error" : "Gabim i panjohur",
     "No files in here" : "S’ka kartela këtu",
+    "Go back" : "Shko prapa",
+    "Show hidden files" : "Shfaq kartela të fshehura",
+    "Additional settings" : "Konfigurime shtesë",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Kopjo në dërrasë ",
+    "Create" : "Krijo",
+    "Delete permanently" : "Fshije përgjithmonë",
     "Upload some content or sync with your devices!" : "Ngarkoni ca lëndë ose bëni njëkohësim me pajisjet tuaja!",
     "No entries found in this folder" : "Në këtë dosje s’u gjetën zëra",
-    "Select all" : "Përzgjidhe krejt",
     "Upload too large" : "Ngarkim shumë i madh",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kartelat që po rrekeni të ngarkoni e tejkalojnë madhësinë maksimale për ngarkime kartelash në këtë shërbyes.",
     "No favorites yet" : "Asnjë preferencë akoma",
     "Files and folders you mark as favorite will show up here" : "Këtu do të duken kartelat dhe dosjet që i shënoni si të parapëlqyera",
-    "Tags" : "Etiketë",
-    "Deleted files" : "Skedar të fshirë",
     "Shares" : "Shpërndarjet",
     "Shared with others" : "E ndarë me të tjerët",
     "Shared with you" : "E ndarë me ju",
@@ -133,13 +121,16 @@ OC.L10N.register(
     "Deleted shares" : "Fshi shpërndarjet",
     "Text file" : "Kartelë tekst",
     "New text file.txt" : "Kartelë e re file.txt",
-    "File handling" : "Trajtim kartele",
-    "Maximum upload size" : "Madhësi maksimale ngarkimi",
-    "max. possible: " : "maks. i mundshëm: ",
-    "Save" : "Ruaje",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Me PHP-FPM mund të duhen 5 minuta që ndryshimet të hyjnë në fuqi.",
-    "Missing permissions to edit from here." : "Mungojnë lejet për përpunim që nga këtu.",
-    "Cancel upload" : "Anulo ngarkimin",
-    "%s of %s used" : "%s nga %s është përdorur"
+    "Storage invalid" : "Depozitë e pavlefshme",
+    "Select" : "Përzgjidhe",
+    "You don’t have permission to upload or create files here" : "S’keni leje për të ngarkuar apo krijuar kartela këtu",
+    "New" : "E re",
+    "Copied!" : "E kopjuar!",
+    "Unlimited" : "E palimituar",
+    "Cancel" : "Anullo",
+    "%s used" : "%s të përdorura",
+    "%1$s of %2$s used" : "%1$s e %2$s përdorur",
+    "Settings" : "Rregullime",
+    "Deleted files" : "Skedar të fshirë"
 },
 "nplurals=2; plural=(n != 1);");
