@@ -40,6 +40,7 @@ OC.L10N.register(
     "_{years} year ago_::_{years} years ago_" : ["{years} χρόνο πριν","{years} χρόνια πριν"],
     "Enable squared photos view" : "Ενεργοποίηση προβολής τετραγωνικών φωτογραφιών",
     "Select the default location for your media" : "Επιλέξτε την προεπιλεγμένη τοποθεσία για τα πολυμέσα σας",
+    "Invalid location selected" : "Επιλέχθηκε μη έγκυρη τοποθεσία",
     "View" : "Προβολή",
     "Delete album" : "Διαγραφή άλμπουμ",
     "Download selected files" : "Λήψη επιλεγμένων αρχείων",
@@ -56,6 +57,7 @@ OC.L10N.register(
     "This folder does not exist" : "Αυτός ο φάκελος δεν υπάρχει",
     "Loading folders …" : "Φόρτωση φακέλων...",
     "No photos in here" : "Δεν υπάρχουν φωτογραφίες εδώ",
+    "Shared by" : "Διαμοιράστηκε από",
     "Shared albums" : "Κοινόχρηστα άλμπουμ",
     "No photos with this tag yet" : "Δεν υπάρχουν φωτογραφίες με αυτή την ετικέτα ακόμη",
     "No tags yet" : "Χωρίς ετικέτες ακόμη",
