@@ -48,6 +48,7 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "پاک کردن از راه دور شروع شد %1$s",
     "Remote wipe has finished on %1$s" : "پاک کردن از راه دور به پایان رسید%1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>پسورد</strong> و یا  <strong>پست الکترونیک</strong> شما ویراش شد.",
+    "Apps" : "برنامه ها",
     "Could not remove app." : "امکان حذف برنامه وجود ندارد.",
     "Could not update app." : "برنامه را نمی توان به روزرسانی کرد .",
     "Wrong password" : "رمز عبور اشتباه است",
@@ -69,6 +70,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "اگر این پست الکترونیک را دریافت کردید ، پیکربندی ایمیل درست است.",
     "Email could not be sent. Check your mail server log" : "پست الکترونیک قابل ارسال نیست. ورود به سیستم سرور پست الکترونیک خود را بررسی کنید",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ارسال پست الکترونیک با خطا مواجه شد، لطفاً تنظیمات خود را مورد بازبینی قرار دهید. (خطا:%s)",
+    "Users" : "کاربران",
     "Invalid user" : "کاربر نامعتبر",
     "Invalid mail address" : "آدرس ایمیل نامعتبر است",
     "Settings saved" : "تنظیمات ذخیره شد",
@@ -96,7 +98,6 @@ OC.L10N.register(
     "Go to %s" : "برو به %s",
     "Install Client" : "قسمت مشتری را نصب کنید",
     "Logged in user must be a subadmin" : "ورود به سیستم کاربر باید زیرمجموعه باشد",
-    "Apps" : "برنامه ها",
     "Settings" : "تنظیمات",
     "Personal" : "شخصی",
     "Administration" : "مدیریت",
@@ -231,9 +232,7 @@ OC.L10N.register(
     "Change password" : "تغییر گذر واژه",
     "Your profile picture" : "نگارهٔ نمایه‌تان",
     "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
-    "Choose profile picture from files" : "گزینش نگارهٔ نمایه از پرونده‌ها",
     "Remove profile picture" : "برداشتن نگارهٔ نمایه",
-    "png or jpg, max. 20 MB" : "png یا jpg. بیشینه ۲۰ م‌ب",
     "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
     "Cancel" : "منصرف شدن",
     "Details" : "جزییات",
@@ -271,6 +270,7 @@ OC.L10N.register(
     "Email" : "ایمیل",
     "Default language" : "زبان پیش فرض",
     "Add a new user" : "افزودن کاربر جدید",
+    "Avatar" : "آواتار",
     "Group admin for" : "مدیر گروه برای",
     "Quota" : "سهم",
     "User backend" : "پشتیبان کاربر",
@@ -320,20 +320,17 @@ OC.L10N.register(
     "Documentation" : "مستندسازی",
     "Forum" : "انجمن",
     "Login" : "ورود",
-    "Plain" : "ساده",
-    "NT LAN Manager" : "مدیر NT LAN",
     "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "شروع TLS",
     "Open documentation" : "بازکردن مستند",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "تنظیم این سرور برای این مهم است که بتواند ایمیل ارسال کند ، مانند تنظیم مجدد گذرواژه و اعلان ها.",
     "Send mode" : "حالت ارسال",
     "Encryption" : "رمزگذاری",
     "Sendmail mode" : "حالت Sendmail",
     "From address" : "آدرس فرستنده",
-    "Authentication method" : "روش احراز هویت",
-    "Authentication required" : "احراز هویت مورد نیاز است",
     "Server address" : "آدرس سرور",
     "Port" : "درگاه",
+    "Authentication method" : "روش احراز هویت",
+    "Authentication required" : "احراز هویت مورد نیاز است",
     "Credentials" : "اعتبارهای",
     "SMTP Username" : "نام کاربری SMTP",
     "SMTP Password" : "رمز عبور SMTP",
@@ -382,8 +379,10 @@ OC.L10N.register(
     "Migration in progress. Please wait until the migration is finished" : "مهاجرت در حال اجراست. لطفا تا اتمام مهاجرت صبر کنید",
     "Migration started …" : "مهاجرت شروع شد...",
     "Address" : "آدرس",
-    "Avatar" : "آواتار",
     "An error occured during the request. Unable to proceed." : "هنگام درخواست خطایی روی داد. امکان ادامه وجود ندارد",
+    "Plain" : "ساده",
+    "NT LAN Manager" : "مدیر NT LAN",
+    "STARTTLS" : "شروع TLS",
     "Please read carefully before activating server-side encryption: " : "لطفاً قبل از فعال کردن \"رمزگذاری سمت سرور\" با دقت مطالعه کنید:",
     "Enable encryption" : "فعال کردن رمزگذاری",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "شما باید کلیدهای رمزگذاری خود را از رمزگذاری قدیمی به (ownCloud <= 8.0) نسخه جدید منتقل کنید.لطفاً \"ماژول رمزگذاری پیش فرض\" را فعال کنید و \"مهاجرت به رمزگذاری occ \" را اجرا کنید.",
@@ -398,12 +397,14 @@ OC.L10N.register(
     "Upload new" : "بارگذاری جدید",
     "Select from Files" : "از میان پرونده ها انتخاب کنید",
     "Remove image" : "تصویر پاک شود",
+    "png or jpg, max. 20 MB" : "png یا jpg. بیشینه ۲۰ م‌ب",
     "Choose as profile picture" : "یک تصویر برای پروفایل انتخاب کنید",
     "You are using <strong>%s</strong>" : "شما با استفاده از <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "شما با استفاده از <strong>%1$s</strong> از <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
     "Your postal address" : "آدرس پستی شما",
     "It can take up to 24 hours before the account is displayed as verified." : "24 ساعت طول می کشد تا اعتبار حساب تأیید شود.",
     "Link https://…" : "پیوند https://…",
-    "Twitter handle @…" : "دسته توییتر @…"
+    "Twitter handle @…" : "دسته توییتر @…",
+    "Choose profile picture from files" : "گزینش نگارهٔ نمایه از پرونده‌ها"
 },
 "nplurals=2; plural=(n > 1);");
