@@ -11,10 +11,6 @@ OC.L10N.register(
     "So-so password" : "Mật khẩu tương tự",
     "Good password" : "Mật khẩu tốt",
     "Strong password" : "Mật khẩu mạnh",
-    "An error occurred while changing your language. Please reload the page and try again." : "Đã xảy ra lỗi trong khi thay đổi ngôn ngữ của bạn. Hãy tải lại trang và thử lại.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Đã xảy ra lỗi trong khi thay đổi ngôn ngữ của bạn. Hãy tải lại trang và thử lại.",
-    "Select a profile picture" : "Chọn một hình ảnh đại diện",
-    "Week starts on {fdow}" : "Tuần bắt đầu vào {fdow}",
     "Groups" : "Nhóm",
     "Group list is empty" : "Danh sách nhóm trống",
     "Unable to retrieve the group list" : "Không thể truy xuất danh sách nhóm",
@@ -35,7 +31,6 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} đã thay đổi địa chỉ email của bạn",
     "You changed your email address" : "Bạn đã thay đổi địa chỉ email",
     "Your email address was changed by an administrator" : "Địa chỉ email của bạn đã được thay đổi bởi quản trị viên",
-    "You created app password \"{token}\"" : "Bạn đã tạo ứng dụng mật khẩu \"{token}\"",
     "You deleted app password \"{token}\"" : "Bạn đã xóa ứng dụng mật khẩu \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Bạn đã đổi tên ứng dụng mật khẩu \"{token}\" thành \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "Bạn đã cấp quyền truy cập hệ thống tệp cho ứng dụng mật khẩu \"{token}\"",
@@ -46,23 +41,24 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Xóa từ xa đã được bắt đầu vào %1$s",
     "Remote wipe has finished on %1$s" : "Xóa từ xa đã kết thúc vào %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>mật khẩu</strong> hoặc <strong>email</strong> đã được sửa đổi",
-    "Couldn't remove app." : "Không thể xóa ứng dụng",
-    "Couldn't update app." : "Không thể cập nhật ứng dụng",
+    "Apps" : "Ứng dụng",
     "Wrong password" : "Mật khẩu không chính xác",
     "Saved" : "Đã lưu",
     "No user supplied" : "Không có người dùng cung cấp",
     "Authentication error" : "Lỗi xác thực",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Vui lòng cung cấp mật khẩu khôi phục quản trị viên; nếu không, tất cả dữ liệu người dùng sẽ bị mất.",
     "Wrong admin recovery password. Please check the password and try again." : "Sai mật khẩu khôi phục quản trị viên. Vui lòng kiểm tra mật khẩu và thử lại.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Trang quản trị không hỗ trợ thay đổi mật khẩu, nhưng khóa mã hóa của người dùng đã được cập nhật.",
     "Federated Cloud Sharing" : "Federated Cloud Sharing",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL đang sử dụng đã lâu không cập nhật %1$s phiên bản (%2$s). Vui lòng cập nhật hệ điều hành hoặc các tính năng như %3$s sẽ không hoạt động đáng tin cậy.",
+    "Administrator documentation" : "Tài liệu quản trị viên",
+    "User documentation" : "Tài liệu người dùng",
     "Invalid SMTP password." : "Mật khẩu SMTT không chính xác.",
     "Email setting test" : "Kiểm tra cài đặt email",
     "Well done, %s!" : "Làm rất tốt, %s!",
     "If you received this email, the email configuration seems to be correct." : "Nếu bạn nhận được email này, cấu hình email có vẻ đúng.",
     "Email could not be sent. Check your mail server log" : "Email không thể gửi được. Kiểm tra nhật ký máy chủ email của bạn",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Một vấn đề xảy ra trong khi gửi email. Vui lòng sửa lại cài đặt của bạn. (Lỗi: %s)",
+    "Users" : "Người dùng",
     "Invalid mail address" : "Địa chỉ email không hợp lệ",
     "Settings saved" : "Cấu hình đã được lưu",
     "Unable to change full name" : "Họ và tên không thể thay đổi ",
@@ -89,10 +85,15 @@ OC.L10N.register(
     "Go to %s" : "Đi tới %s",
     "Install Client" : "Cài đặt máy khách",
     "Logged in user must be a subadmin" : "Người dùng đã đăng nhập phải là một subadmin",
-    "Apps" : "Ứng dụng",
     "Settings" : "Cài đặt",
     "Personal" : "Cá nhân",
+    "Additional settings" : "Cài đặt bổ sung",
+    "Overview" : "Tổng quan",
+    "Basic settings" : "Thiết lập cơ bản",
     "Sharing" : "Chia sẻ",
+    "Calendar" : "Lịch",
+    "Personal info" : "Thông tin cá nhân",
+    "Email server" : "Máy chủ mail",
     "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
     "Background jobs" : "Các công việc trong nền",
     "Create" : "Tạo mới",
@@ -120,7 +121,6 @@ OC.L10N.register(
     "View in store" : "Xem tại cửa hàng",
     "Visit website" : "Truy cập trang web",
     "Report a bug" : "Báo cáo lỗi",
-    "User documentation" : "Tài liệu người dùng",
     "Admin documentation" : "Tài liệu quản trị",
     "Developer documentation" : "Tài liệu dành cho nhà phát triển",
     "This app is supported via your current Nextcloud subscription." : "Ứng dụng này được hỗ trợ thông qua thuê bao Nextcloud hiện tại của bạn.",
@@ -137,6 +137,12 @@ OC.L10N.register(
     "Rename" : "Đổi tên",
     "Revoke" : "Thu hồi",
     "Wipe device" : "Xóa thiết bị",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome cho Android",
     "This session" : "Phiên này",
     "Device" : "Thiết bị",
     "Last activity" : "Hoạt động cuối",
@@ -161,10 +167,19 @@ OC.L10N.register(
     "Copy" : "Sao chép",
     "Could not copy app password. Please copy it manually." : "Không thể sao chép ứng dụng mật khẩu. Vui lòng sao chép thủ công.",
     "Enable" : "Bật",
+    "Server-side encryption" : "Mã hoá phía máy chủ",
+    "Enable server-side encryption" : "Kích hoạt mã hoá phía máy chủ",
+    "This is the final warning: Do you really want to enable encryption?" : "Cảnh báo lần cuối: Bạn có thực sự muốn kích hoạt tính năng mã hoá?",
     "Remove group" : "Xóa nhóm",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Bạn sắp xóa nhóm {group}. Người dùng sẽ KHÔNG bị xóa.",
     "Please confirm the group removal " : "Vui lòng xác nhận xóa nhóm",
+    "Current password" : "Mật khẩu cũ",
+    "New password" : "Mật khẩu mới",
+    "Change password" : "Đổi mật khẩu",
+    "Cancel" : "Hủy",
+    "Details" : "Thông tin",
     "Your email address" : "Email của bạn",
+    "No email address set" : "Chưa thiết lập địa chỉ email",
     "Language" : "Ngôn ngữ",
     "Help translate" : "Hỗ trợ dịch thuật",
     "No language set" : "Không có ngôn ngữ",
@@ -177,7 +192,6 @@ OC.L10N.register(
     "Disable user" : "Vô hiệu hóa người dùng",
     "Enable user" : "Kích hoạt người dùng",
     "Resend welcome email" : "Gửi lại email chào mừng",
-    "Cancel" : "Hủy",
     "Welcome mail sent!" : "Thư chào mừng đã được gửi!",
     "{size} used" : "{size} đã sử dụng",
     "New user" : "Người dùng mới",
@@ -186,6 +200,7 @@ OC.L10N.register(
     "Email" : "Email",
     "Default language" : "Ngôn ngữ mặc định",
     "Add a new user" : "Thêm người dùng mới",
+    "Avatar" : "Hình đại diện",
     "Group admin for" : "Quản trị viên nhóm",
     "Quota" : "Hạn ngạch",
     "User backend" : "Trang cài đặt người dùng",
@@ -196,12 +211,6 @@ OC.L10N.register(
     "Common languages" : "Ngôn ngữ thông dụng",
     "Password change is disabled because the master key is disabled" : "Thay đổi mật khẩu bị vô hiệu hóa vì khóa chính bị vô hiệu hóa",
     "Your apps" : "Ứng dụng của bạn",
-    "Active apps" : "Ứng dụng kích hoạt",
-    "Disabled apps" : "Ứng dụng vô hiệu hóa",
-    "Updates" : "Cập nhật",
-    "App bundles" : "Gói ứng dụng",
-    "Featured apps" : "Các ứng dụng đề xuất",
-    "Details" : "Thông tin",
     "Changelog" : "Sổ cập nhập thay đổi",
     "Add group" : "Thêm nhóm",
     "Active users" : "Người dùng hoạt động",
@@ -212,54 +221,65 @@ OC.L10N.register(
     "Show last login" : "Hiển thị lần cuối đăng nhập",
     "Show user backend" : "Hiển thị cài đặt người dùng",
     "Show storage path" : "Hiển thị đường dẫn lưu trữ",
-    "Migration in progress. Please wait until the migration is finished" : "Chuyển đổi dữ liệu đang tiến hành. Vui lòng đợi cho đến khi quá trình di chuyển kết thúc",
-    "Migration started …" : "Chuyển đổi dữ liệu đã bắt đầu ...",
     "Not saved" : "Chưa được lưu",
     "Sending…" : "Đang gửi...",
     "Email sent" : "Email đã được gửi",
-    "Address" : "Địa chỉ",
-    "Avatar" : "Hình đại diện",
+    "Location" : "Vị trí",
+    "Profile picture" : "Ảnh đại diện",
     "About" : "Giới thiệu",
     "Full name" : "Tên đầy đủ",
     "Phone number" : "Số điện thoại",
     "Twitter" : "Twitter",
     "Website" : "Website",
+    "Active apps" : "Ứng dụng kích hoạt",
+    "Disabled apps" : "Ứng dụng vô hiệu hóa",
+    "Updates" : "Cập nhật",
+    "App bundles" : "Gói ứng dụng",
+    "Featured apps" : "Các ứng dụng đề xuất",
     "Hide" : "Ẩn",
     "Download and enable" : "Tải xuống và kích hoạt",
     "Enable untested app" : "Bật ứng dụng chưa được kiểm tra",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
     "Never" : "Không bao giờ",
-    "An error occured during the request. Unable to proceed." : "Đã xảy ra lỗi trong khi yêu cầu. Không thể tiến hành.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Ứng dụng đã được kích hoạt nhưng cần được cập nhật. Bạn sẽ được chuyển hướng đến trang cập nhật sau 5 giây.",
-    "Administrator documentation" : "Tài liệu quản trị viên",
     "Documentation" : "Tài liệu",
     "Forum" : "Diễn đàn",
     "Login" : "Đăng nhập",
     "Open documentation" : "Mở tài liệu",
     "Encryption" : "Mã hóa",
-    "Authentication required" : "Cần phải được xác thực",
+    "From address" : "Từ địa chỉ",
     "Server address" : "Địa chỉ máy chủ",
     "Port" : "Cổng",
+    "Authentication method" : "Phương thức xác thực",
+    "Authentication required" : "Cần phải được xác thực",
     "Credentials" : "Giấy chứng nhận",
     "SMTP Password" : "Mật khẩu SMTP",
     "Save" : "Lưu",
     "Send email" : "Gửi email",
+    "All checks passed." : "Tất cả các kiểm tra đã thoả điều kiện",
     "Version" : "Phiên bản",
-    "Enable encryption" : "Bật mã hóa",
     "Allow apps to use the Share API" : "Cho phép các ứng dụng sử dụng chia sẻ API",
     "Enforce expiration date" : "Buộc có ngày hết hạn",
     "Allow public uploads" : "Cho phép upload công cộng",
     "Allow resharing" : "Cho phép chia sẻ lại",
+    "Allow sharing with groups" : "Cho phép chia sẻ với các nhóm",
+    "An error occurred while changing your language. Please reload the page and try again." : "Đã xảy ra lỗi trong khi thay đổi ngôn ngữ của bạn. Hãy tải lại trang và thử lại.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Đã xảy ra lỗi trong khi thay đổi ngôn ngữ của bạn. Hãy tải lại trang và thử lại.",
+    "Select a profile picture" : "Chọn một hình ảnh đại diện",
+    "Week starts on {fdow}" : "Tuần bắt đầu vào {fdow}",
+    "You created app password \"{token}\"" : "Bạn đã tạo ứng dụng mật khẩu \"{token}\"",
+    "Couldn't remove app." : "Không thể xóa ứng dụng",
+    "Couldn't update app." : "Không thể cập nhật ứng dụng",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Trang quản trị không hỗ trợ thay đổi mật khẩu, nhưng khóa mã hóa của người dùng đã được cập nhật.",
+    "Migration in progress. Please wait until the migration is finished" : "Chuyển đổi dữ liệu đang tiến hành. Vui lòng đợi cho đến khi quá trình di chuyển kết thúc",
+    "Migration started …" : "Chuyển đổi dữ liệu đã bắt đầu ...",
+    "Address" : "Địa chỉ",
+    "An error occured during the request. Unable to proceed." : "Đã xảy ra lỗi trong khi yêu cầu. Không thể tiến hành.",
+    "Enable encryption" : "Bật mã hóa",
     "Upload new" : "Tải lên",
+    "Select from Files" : "Chọn từ tập tin",
     "Remove image" : "Xóa ",
-    "Current password" : "Mật khẩu cũ",
-    "New password" : "Mật khẩu mới",
-    "Change password" : "Đổi mật khẩu",
-    "You need to set your user email before being able to send test emails." : "Bạn cần cài đặt email người dùng trước khi có thể gửi email kiểm tra.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Việc thu hồi tín chỉ này có thể ngăn việc xóa thiết bị của bạn nếu thiết bị chưa bắt đầu xóa.",
-    "All languages" : "Tất cả ngôn ngữ",
-    "Everyone" : "Tất cả mọi người",
-    "App update" : "Cập nhật ứng dụng",
-    "days" : "ngày"
+    "png or jpg, max. 20 MB" : "png hoặc jpg, tối đa 20 MB",
+    "Choose as profile picture" : "Chọn làm ảnh đại diện"
 },
 "nplurals=1; plural=0;");
