@@ -2,7 +2,7 @@ OC.L10N.register(
     "settings",
     {
     "Private" : "私有",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "只对通过手机上 Talk 应用的电话号码整合功能匹配的人可见",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "只对通过手机上Talk应用的电话号码整合功能匹配的人可见",
     "Local" : "本地",
     "Only visible to people on this instance and guests" : "仅对该实例上的人及来宾可见",
     "Federated" : "联合云",
@@ -38,8 +38,6 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} 已更改您的电子邮件地址",
     "You changed your email address" : "您已更改您的电子邮件地址",
     "Your email address was changed by an administrator" : "您的电子邮件地址已被管理员更改",
-    "You created app password \"{token}\"" : "您创建了应用密码 \"{token}\"",
-    "An administrator created app password \"{token}\"" : "管理员创建了应用密码 \"{token}\"",
     "You deleted app password \"{token}\"" : "您删除了应用密码 \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "您将应用密码 \"{token}\" 重命名为 \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "您将文件系统访问权限授予了应用密码 \"{token}\"",
@@ -50,6 +48,7 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "%1$s上的远程擦除已开始",
     "Remote wipe has finished on %1$s" : "%1$s上的远程擦除已完成",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "您的 <strong>密码</strong> 或 <strong>邮箱</strong> 已被更改",
+    "Apps" : "应用",
     "Could not remove app." : "无法移除应用。",
     "Could not update app." : "无法更新应用。",
     "Wrong password" : "密码错误",
@@ -82,6 +81,7 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "邮件无法发送。检查您的邮件服务器日志",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "在发送电子邮件时出现问题。请修正您的设置。（错误：%s）",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "您需要先前往%s设置电子邮箱，才能发送测试邮件。",
+    "Users" : "用户",
     "Invalid user" : "无效用户",
     "Invalid mail address" : "无效的电子邮件地址",
     "Settings saved" : "设置已保存",
@@ -113,7 +113,6 @@ OC.L10N.register(
     "Go to %s" : "访问 %s",
     "Install Client" : "安装客户端",
     "Logged in user must be a subadmin" : "当前登录用户必须为子管理员",
-    "Apps" : "应用",
     "Settings" : "设置",
     "Personal" : "个人",
     "Administration" : "管理",
@@ -203,8 +202,8 @@ OC.L10N.register(
     "iPad" : "iPad",
     "{productName} iOS app" : "{productName} iOS 应用",
     "{productName} Android app" : "{productName} 安卓应用",
-    "{productName} Talk for iOS" : "{productName} Talk for iOS",
-    "{productName} Talk for Android" : "{productName} Talk for Android ",
+    "{productName} Talk for iOS" : "{productName}iOS版通话应用",
+    "{productName} Talk for Android" : "{productName}Android版通话应用",
     "Sync client - {os}" : "同步客户端 - {os}",
     "This session" : "当前会话",
     "Device" : "设备",
@@ -268,9 +267,7 @@ OC.L10N.register(
     "Change password" : "修改密码",
     "Your profile picture" : "您的个人资料图片",
     "Upload profile picture" : "上传个人资料图片",
-    "Choose profile picture from files" : "从文件中选择个人资料图片",
     "Remove profile picture" : "移除个人资料图片",
-    "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
     "Picture provided by original account" : "初始账号提供的图片",
     "Cancel" : "取消",
     "Set as profile picture" : "设置为个人资料图片",
@@ -319,7 +316,6 @@ OC.L10N.register(
     "Enable Profile" : "编辑个人资料",
     "Unable to update profile enabled state" : "无法更新个人资料启用状态",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "系统将遵循个人资料的 “可见性” 和 “范围” 设置中限制更严格那个。例如，当 “可见性” 设置为 “显示给所有人”，而 “范围” 设置为 “私密” 时，系统将按照 “私密” 来设置您个人资料",
-    "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "无法更新 {displayId} 的可见性",
     "Your role" : "您的角色",
     "Your Twitter handle" : "您的 Twitter 账号",
@@ -337,6 +333,7 @@ OC.L10N.register(
     "Add user to group" : "添加用户到组",
     "Set user as admin for" : "设置用户为管理员",
     "Select user quota" : "选择用户容量限额",
+    "Toggle user actions menu" : "切换用户行动菜单",
     "Delete user" : "删除用户",
     "Wipe all devices" : "擦除所有设备",
     "Disable user" : "禁用用户",
@@ -350,7 +347,6 @@ OC.L10N.register(
     "Delete {userid}'s account" : "删除 {userid} 的账号",
     "Welcome mail sent!" : "欢迎邮件已经发送！",
     "Edit User" : "编辑用户",
-    "Toggle user actions menu" : "切换用户行动菜单",
     "{size} used" : "已使用 {size}",
     "New user" : "新建用户",
     "Will be autogenerated" : "将自动生成",
@@ -358,6 +354,7 @@ OC.L10N.register(
     "Email" : "电子邮件",
     "Default language" : "默认语言",
     "Add a new user" : "添加新用户",
+    "Avatar" : "头像",
     "Group admin for" : "分组管理员",
     "Quota" : "配额",
     "User backend" : "用户来源",
@@ -410,6 +407,7 @@ OC.L10N.register(
     "Phone number" : "电话号码",
     "Role" : "角色",
     "Twitter" : "Twitter",
+    "Fediverse (e.g. Mastodon)" : "联邦宇宙（例如Mastodon）",
     "Website" : "网站",
     "Profile visibility" : "个人资料可见性",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "不可用，因为包括文件共享和日历邀请在内的核心功能需要此属性",
@@ -431,23 +429,21 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "请求期间发生错误。无法继续。",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。5秒后将跳转到更新页面。",
     "Error: This app cannot be enabled because it makes the server unstable" : "错误:这个应用程序不能被启用，因为它使服务器不稳定 ",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "您的网络请求过多。如果出现错误，请稍后重试或与您的管理员联系。",
     "Documentation" : "文档",
     "Forum" : "论坛",
     "Login" : "登录",
-    "Plain" : "明文",
-    "NT LAN Manager" : "NT LAN 管理器",
     "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
     "Open documentation" : "打开文档",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "设置此服务器以能够发送电子邮件（例如密码重置和通知）非常重要。",
     "Send mode" : "发送模式",
     "Encryption" : "加密",
     "Sendmail mode" : "邮件发送模式",
     "From address" : "来自地址",
-    "Authentication method" : "认证方法",
-    "Authentication required" : "需要认证",
     "Server address" : "服务器地址",
     "Port" : "端口",
+    "Authentication method" : "认证方法",
+    "Authentication required" : "需要认证",
     "Credentials" : "证书",
     "SMTP Username" : "SMTP 用户名",
     "SMTP Password" : "SMTP 密码",
@@ -482,8 +478,6 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "限制用户只与他们组中的用户共享",
     "Exclude groups from sharing" : "在共享中排除组",
     "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取共享，但无法向他人共享。",
-    "Allow username autocompletion in share dialog" : "在分享对话框中允许用户名自动完成",
-    "Allow username autocompletion to users within the same groups" : "允许自动完成同一组内的用户的用户名",
     "Allow username autocompletion to users based on phone number integration" : "允许基于手机号码集成自动完成用户的用户名",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "如果启用了“同组”自动完成和“手机号码集成”，则匹配两者中的任何一个都足以显示用户",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "输入全名或电子邮箱地址时，允许自动完成（忽略缺少的通讯录匹配及同组要求）",
@@ -491,7 +485,7 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "这些内容将在公开链接上传页中当文件列表隐藏时显示。",
     "Default share permissions" : "默认共享权限",
     "Reasons to use Nextcloud in your organization" : "在您的组织中使用 Nextcloud 的原因",
-    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由 {communityopen}Nextcloud community{linkclose} 开发，{githubopen}源代码{linkclose} 基于 {licenseopen}AGPL{linkclose} 许可协议。",
+    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由{communityopen}Nextcloud社区{linkclose}开发，{githubopen}源代码{linkclose}基于 {licenseopen}AGPL{linkclose}许可协议。",
     "Like our Facebook page" : "点赞我们 facebook 页面！",
     "Follow us on Twitter" : "在 Twitter 上关注我们！",
     "Follow us on Mastodon" : "在Mastodon上关注我们",
@@ -500,19 +494,18 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud 的这个社区版本不受支持，即时通知不可用。",
     "Use a second factor besides your password to increase security for your account." : "使用除您密码之外的第二种方法来增强您账号的安全性。",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方应用程序连接到 Nextcloud，请确保在启用第二因素身份验证之前为每个应用程序创建和配置应用程序密码。",
-    "Migration in progress. Please wait until the migration is finished" : "正在进行迁移。请稍等，直到迁移完成",
-    "Migration started …" : "迁移开始...",
     "An error occurred while changing your language. Please reload the page and try again." : "修改您的语言时遇到错误。请重新载入页面后再试。",
     "An error occurred while changing your locale. Please reload the page and try again." : "修改您的地区时遇到错误。请重新载入页面后再试。",
     "Select a profile picture" : "选择个人头像",
     "Week starts on {fdow}" : "周开始于 {fdow}",
+    "You created app password \"{token}\"" : "您创建了应用密码 \"{token}\"",
+    "An administrator created app password \"{token}\"" : "管理员创建了应用密码 \"{token}\"",
     "Couldn't remove app." : "无法删除应用。",
     "Couldn't update app." : "无法更新应用。",
     "Backend doesn't support password change, but the user's encryption key was updated." : "后端不支持密码更改，但用户的加密密钥已更新。",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "不能确定 cURL 的 TLS 版本是否已过时，因为在HTTPS请求 https://nextcloud.com 时发生了错误。请检查 nextcloud 日志文件以了解详情。",
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "几乎超过了 OPcache 键的最大数量。为确保所有脚本可以保留在缓存中，建议在您的 PHP 设置中 <code>opcache.max_accelerated_files</code> 设置一个高于 <code>%s</code> 的值。",
     "Admin privileges" : "管理员特权",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果擦除操作还未开始，撤销此令牌可能会妨碍对您设备的擦除操作",
     "Unable to update biography" : "无法更新小传",
     "Unable to update full name" : "无法更新全名",
     "No full name set" : "未设置全名",
@@ -522,9 +515,13 @@ OC.L10N.register(
     "Change scope level of {accountProperty}" : "更改 {accountProperty} 的范围",
     "Unable to update federation scope of the primary {accountProperty}" : "无法更新主 {accountProperty} 的联盟范围",
     "Unable to update federation scope of additional {accountProperty}" : "无法更新附加 {accountProperty} 的联盟范围",
+    "Migration in progress. Please wait until the migration is finished" : "正在进行迁移。请稍等，直到迁移完成",
+    "Migration started …" : "迁移开始...",
     "Address" : "地址",
-    "Avatar" : "头像",
     "An error occured during the request. Unable to proceed." : "请求期间发生错误。 无法继续。",
+    "Plain" : "明文",
+    "NT LAN Manager" : "NT LAN 管理器",
+    "STARTTLS" : "STARTTLS",
     "Please read carefully before activating server-side encryption: " : "在激活服务器端加密之前，请仔细阅读：",
     "Enable encryption" : "启用加密",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您需要从旧版本（ownCloud <= 8.0）迁移您的加密密钥。请在应用中启用 \\\"Default encryption module\\\" 并运行 'occ encryption:migrate'",
@@ -539,11 +536,13 @@ OC.L10N.register(
     "Pick background job setting" : "选择后台任务设置",
     "Recommended" : "推荐",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 需要被系统用户 \"%s\" 执行。",
-    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "在输入全名或电子邮件地址时允许用户名自动完成 (忽略缺少的电话簿匹配和同属一个小组的匹配)",
+    "Allow username autocompletion in share dialog" : "在分享对话框中允许用户名自动完成",
+    "Allow username autocompletion to users within the same groups" : "允许自动完成同一组内的用户的用户名",
     "Change privacy level of profile picture" : "更改个人头像的隐私级别",
     "Upload new" : "上传",
     "Select from Files" : "选择文件",
     "Remove image" : "删除图片",
+    "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "请注意，头像可能需要24小时才能在所有地方更新完成。",
     "Choose as profile picture" : "选择个人头像",
     "You are using <strong>%s</strong>" : "您已经使用了 <strong>%s</strong> 存储空间",
@@ -555,6 +554,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "在账号显示为已验证之前最多可能需要 24 小时。",
     "Link https://…" : "链接 https://…",
     "Change privacy level of Twitter profile" : "更改推特资料的隐私权限",
-    "Twitter handle @…" : "Twitter 用户名 @…"
+    "Twitter handle @…" : "Twitter 用户名 @…",
+    "Choose profile picture from files" : "从文件中选择个人资料图片"
 },
 "nplurals=1; plural=0;");
