@@ -4,7 +4,7 @@ OC.L10N.register(
     "Tag name is empty" : "Имя метки пусто",
     "Update" : "Обновить",
     "Create" : "Создать",
-    "Select tag…" : "Выберите метку…",
+    "Select tag …" : "Выберите метку…",
     "System tag %1$s added by the system" : "Системная метка «%1$s» создана",
     "Added system tag {systemtag}" : "Создана системная метка «{systemtag}»",
     "Added system tag %1$s" : "Создана системная метка «%1$s»",
@@ -43,16 +43,27 @@ OC.L10N.register(
     "%s (invisible)" : "%s (невидимая)",
     "<strong>System tags</strong> for a file have been modified" : "<strong>Системные метки</strong> файла были изменены",
     "Tags" : "Метки",
+    "All tagged %s …" : "Все помеченные %s ...",
+    "tagged %s" : "помеченные %s",
     "Collaborative tags" : "Метки совместной работы",
     "Collaborative tagging functionality which shares tags among users." : "Совместная работа с метками файлов.",
     "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Совместная работа с метками файлов, предназначенная для групп пользователей. (Провайдерам с большим количеством клиентов рекомендуется отключить это приложение, так как метки являются общими).",
+    "Search or create collaborative tags" : "Поиск или создание совместных тегов",
+    "Collaborative tags …" : "Совместные теги ...",
+    "No tags to select, type to create a new tag" : "Нет тегов для выбора. Введите что-нибудь для создания нового тега",
+    "Failed to load tags" : "Не удалось загрузить метки",
+    "Failed to load selected tags" : "Не удалось загрузить выбранный тег",
+    "Failed to select tag" : "Не удалось выбрать тег",
+    "Failed to create tag" : "Не удалось создать тег",
+    "Failed to delete tag" : "Не удалось удалить тег",
+    "Failed to load last used tags" : "Не удалось загрузить последние использованные метки",
+    "Missing \"Content-Location\" header" : "Отсутствует заголовок «Content-Location»",
     "Tagged files" : "Помеченные файлы",
     "Select tags to filter by" : "Выберите метки для отбора",
     "No tags found" : "Меток не найдено",
     "Please select tags to filter by" : "Выберите метки для отбора",
     "No files found for the selected tags" : "Не найдено файлов с выбранными метками",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Совместные теги доступны для всех пользователей. Ограниченные теги видны пользователям, но не могут быть назначены ими. Невидимые теги предназначены для внутреннего использования, поскольку пользователи не могут их видеть или назначать.",
-    "Select tag …" : "Выберите метку…",
     "Create a new tag" : "Создать метку",
     "Name" : "Имя",
     "Public" : "Общая",
