@@ -4,7 +4,7 @@ OC.L10N.register(
     "Tag name is empty" : "Име ознаке је празно",
     "Update" : "Ажурирај",
     "Create" : "Направи",
-    "Select tag…" : "Одабери ознаку…",
+    "Select tag …" : "Одаберите ознаку …",
     "System tag %1$s added by the system" : "Систем додао системску ознаку %1$s",
     "Added system tag {systemtag}" : "Додата системска ознака {systemtag}",
     "Added system tag %1$s" : "Додата системска ознака %1$s",
@@ -43,16 +43,27 @@ OC.L10N.register(
     "%s (invisible)" : "%s (невидљива)",
     "<strong>System tags</strong> for a file have been modified" : "<strong>Системске ознаке</strong> за фајл су измењене",
     "Tags" : "Ознаке",
+    "All tagged %s …" : "Све означено %s …",
+    "tagged %s" : "означено %s",
     "Collaborative tags" : "Тимске ознаке",
     "Collaborative tagging functionality which shares tags among users." : "Могућност заједничког означавања којим се деле ознаке међу корисницима.",
     "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Могућност заједничког означавања којим се деле ознаке међу корисницима. Сјајно за тимове.\n\t(ако сте провајдер инсталације за одвојене кориснике/предузећа, саветује се да иксључите ову апликацију пошто су ознаке дељене.)",
+    "Search or create collaborative tags" : "Претражите или креирајте ознаке за сарадњу",
+    "Collaborative tags …" : "Ознаке сарадње...",
+    "No tags to select, type to create a new tag" : "Није изабрана ниједна ознака, куцајте да креирате нову ознаку",
+    "Failed to load tags" : "Грешка при учитавању ознака",
+    "Failed to load selected tags" : "Изабрана ознака није могла да се учита",
+    "Failed to select tag" : "Ознака није могла да се изабере",
+    "Failed to create tag" : "Ознака није могла да се креира",
+    "Failed to delete tag" : "Ознака није могла да се обрише",
+    "Failed to load last used tags" : "Последње коришћена ознака није могла да се учита",
+    "Missing \"Content-Location\" header" : "Недостаје Content-Location” заглавље",
     "Tagged files" : "Означени фајлови",
     "Select tags to filter by" : "Одаберите ознаке по којима да се филтрира",
     "No tags found" : "Нису нађене ознаке",
     "Please select tags to filter by" : "Одаберите ознаке по којима да се филтрира",
     "No files found for the selected tags" : "Ниједан фајл није нађен за одабране ознаке",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Заједниче ознаке су доступне свим корисницима. Заштићене ознаке су доступне свим корисницима, али их они не могу додељивати. Невидљиве ознаке су за интерну употребу, пошто их корисници не могу ни видети ни додељивати.",
-    "Select tag …" : "Одаберите ознаку …",
     "Create a new tag" : "Направи нову ознаку",
     "Name" : "Назив",
     "Public" : "Јавна",
