@@ -21,6 +21,8 @@ OC.L10N.register(
     "Could not write file to disk" : "Неможливо записати файл на диск",
     "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
     "No file uploaded" : "Файл не завантажено",
+    "Failed to clean up the old administration theming images folder" : "Не вдалося очистити каталог зображень старої адміністративної теми",
+    "Failed to clean up the old administration image folder" : "Не вдалося очистити старий каталог образу адміністрування",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ви уже використовуєте власну тему. Таким чином налаштування застосунку Оформлення може бути перезаписано.",
     "Theming" : "Оформлення",
     "Appearance and accessibility" : "Тема та вигляд",
@@ -47,6 +49,7 @@ OC.L10N.register(
     "Adjust the Nextcloud theme" : "Налаштуйте тему Nextcloud",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Оформлення дозволяє легко налаштувати зовнішній вигляд вашого сервера та підтримуваних клієнтів. Це будуть бачити всі користувачі.",
     "Advanced options" : "Розширені налаштування",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Встановіть розширення  ImageMagick PHP з підтримкою SVG-зображень, щоб автоматично генерувати іконки на основі завантаженого логотипа і кольору.",
     "Name" : "Ім’я",
     "Web link" : "Посилання",
     "a safe home for all your data" : "безпечна домівка для ваших даних",
@@ -66,6 +69,7 @@ OC.L10N.register(
     "Disable user theming" : "Вимкнути можливість користувачів змінювати оформлення",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "На додаток до встановлення оформлення вашої хмари користувачі також можуть змінювати тло та кольорову гаму. Ви можете встановити оформлення однаковим для всіх користувачів.",
     "Keyboard shortcuts" : "Скорочення",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "У деяких випадках комбінації клавіш можуть заважати роботі з інструментами доступності. Для того, щоб правильно зосередитися на інструменті, ви можете вимкнути всі комбінації клавіш тут. Це також вимкне всі доступні комбінації клавіш у програмах.",
     "Disable all keyboard shortcuts" : "Вимкнути всі комбінації клавіш",
     "Background" : "Тло",
     "Customization has been disabled by your administrator" : "Налаштування персоналізації вимкнено адміністатором.",
@@ -75,6 +79,7 @@ OC.L10N.register(
     "Custom background" : "Користувацьке тло",
     "Default background" : "Типове тло",
     "Change color" : "Змінити колір",
+    "No background" : "Без фону",
     "Select a background from your files" : "Виберіть зображення тла з ваших файлів",
     "Theme selection is enforced" : "Вибір теми виконується примусово",
     "Select a custom color" : "Виберіть власний колір",
