@@ -5,6 +5,7 @@
  * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Daniel Kesselberg <mail@danielkesselberg.de>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Julien Veyssier <eneiluj@posteo.net>
  * @author Julius Haertl <jus@bitgrid.net>
  * @author Julius Härtl <jus@bitgrid.net>
  * @author Michael Weimann <mail@michael-weimann.eu>
@@ -18,14 +19,13 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
  */
-
 namespace OCA\Theming;
 
 use OCP\App\AppPathNotFoundException;
@@ -34,39 +34,40 @@ use OCP\Files\IAppData;
 use OCP\Files\NotFoundException;
 use OCP\Files\SimpleFS\ISimpleFile;
 use OCP\IConfig;
-use ScssPhp\ScssPhp\Compiler;
+use OCP\IUserSession;
+use Mexitek\PHPColors\Color;
 
 class Util {
 
-	/** @var IConfig */
-	private $config;
+	private IConfig $config;
+	private IAppManager $appManager;
+	private IAppData $appData;
+	private ImageManager $imageManager;
 
-	/** @var IAppManager */
-	private $appManager;
-
-	/** @var IAppData */
-	private $appData;
-
-	/**
-	 * Util constructor.
-	 *
-	 * @param IConfig $config
-	 * @param IAppManager $appManager
-	 * @param IAppData $appData
-	 */
-	public function __construct(IConfig $config, IAppManager $appManager, IAppData $appData) {
+	public function __construct(IConfig $config, IAppManager $appManager, IAppData $appData, ImageManager $imageManager) {
 		$this->config = $config;
 		$this->appManager = $appManager;
 		$this->appData = $appData;
+		$this->imageManager = $imageManager;
 	}
 
 	/**
+	 * Should we invert the text on this background color?
 	 * @param string $color rgb color value
 	 * @return bool
 	 */
-	public function invertTextColor($color) {
+	public function invertTextColor(string $color): bool {
+		return $this->isBrightColor($color);
+	}
+
+	/**
+	 * Is this color too bright ?
+	 * @param string $color rgb color value
+	 * @return bool
+	 */
+	public function isBrightColor(string $color): bool {
 		$l = $this->calculateLuma($color);
-		if ($l>0.6) {
+		if ($l > 0.6) {
 			return true;
 		} else {
 			return false;
@@ -76,54 +77,84 @@ class Util {
 	/**
 	 * get color for on-page elements:
 	 * theme color by default, grey if theme color is to bright
-	 * @param $color
+	 * @param string $color
+	 * @param bool $brightBackground
 	 * @return string
 	 */
-	public function elementColor($color) {
-		$l = $this->calculateLuminance($color);
-		if ($l>0.8) {
+	public function elementColor($color, bool $brightBackground = true) {
+		$luminance = $this->calculateLuminance($color);
+
+		if ($brightBackground && $luminance > 0.8) {
+			// If the color is too bright in bright mode, we fall back to a darker gray
 			return '#aaaaaa';
 		}
+
+		if (!$brightBackground && $luminance < 0.2) {
+			// If the color is too dark in dark mode, we fall back to a brighter gray
+			return '#8c8c8c';
+		}
+
 		return $color;
 	}
 
+	public function mix(string $color1, string $color2, int $factor): string {
+		$color = new Color($color1);
+		return '#' . $color->mix($color2, $factor);
+	}
+
+	public function lighten(string $color, int $factor): string {
+		$color = new Color($color);
+		return '#' . $color->lighten($factor);
+	}
+
+	public function darken(string $color, int $factor): string {
+		$color = new Color($color);
+		return '#' . $color->darken($factor);
+	}
+
 	/**
-	 * @param string $color rgb color value
-	 * @return float
+	 * Convert RGB to HSL
+	 *
+	 * Copied from cssphp, copyright Leaf Corcoran, licensed under MIT
+	 *
+	 * @param int $red
+	 * @param int $green
+	 * @param int $blue
+	 *
+	 * @return float[]
 	 */
-	public function calculateLuminance($color) {
-		list($red, $green, $blue) = $this->hexToRGB($color);
-		$compiler = new Compiler();
-		$hsl = $compiler->toHSL($red, $green, $blue);
-		return $hsl[3]/100;
+	public function toHSL(int $red, int $green, int $blue): array {
+		$color = new Color(Color::rgbToHex(['R' => $red, 'G' => $green, 'B' => $blue]));
+		return array_values($color->getHsl());
 	}
 
 	/**
 	 * @param string $color rgb color value
 	 * @return float
 	 */
-	public function calculateLuma($color) {
-		list($red, $green, $blue) = $this->hexToRGB($color);
-		return (0.2126 * $red  + 0.7152 * $green + 0.0722 * $blue) / 255;
+	public function calculateLuminance(string $color): float {
+		[$red, $green, $blue] = $this->hexToRGB($color);
+		$hsl = $this->toHSL($red, $green, $blue);
+		return $hsl[2];
+	}
+
+	/**
+	 * @param string $color rgb color value
+	 * @return float
+	 */
+	public function calculateLuma(string $color): float {
+		[$red, $green, $blue] = $this->hexToRGB($color);
+		return (0.2126 * $red + 0.7152 * $green + 0.0722 * $blue) / 255;
 	}
 
 	/**
 	 * @param string $color rgb color value
 	 * @return int[]
+	 * @psalm-return array{0: int, 1: int, 2: int}
 	 */
-	public function hexToRGB($color) {
-		$hex = preg_replace("/[^0-9A-Fa-f]/", '', $color);
-		if (strlen($hex) === 3) {
-			$hex = $hex[0] . $hex[0] . $hex[1] . $hex[1] . $hex[2] . $hex[2];
-		}
-		if (strlen($hex) !== 6) {
-			return 0;
-		}
-		return [
-			hexdec(substr($hex, 0, 2)),
-			hexdec(substr($hex, 2, 2)),
-			hexdec(substr($hex, 4, 2))
-		];
+	public function hexToRGB(string $color): array {
+		$color = new Color($color);
+		return array_values($color->getRgb());
 	}
 
 	/**
@@ -160,9 +191,7 @@ class Util {
 			$logoFile = null;
 			try {
 				$folder = $this->appData->getFolder('images');
-				if ($folder !== null) {
-					return $folder->getFile('logo');
-				}
+				return $folder->getFile('logo');
 			} catch (NotFoundException $e) {
 			}
 		}
@@ -240,14 +269,28 @@ class Util {
 	}
 
 	public function isBackgroundThemed() {
-		$backgroundLogo = $this->config->getAppValue('theming', 'backgroundMime',false);
+		$backgroundLogo = $this->config->getAppValue('theming', 'backgroundMime', '');
+		return $backgroundLogo !== '' && $backgroundLogo !== 'backgroundColor';
+	}
 
-		$backgroundExists = true;
-		try {
-			$this->appData->getFolder('images')->getFile('background');
-		} catch (\Exception $e) {
-			$backgroundExists = false;
+	public function isLogoThemed() {
+		return $this->imageManager->hasImage('logo')
+			|| $this->imageManager->hasImage('logoheader');
+	}
+
+	public function getCacheBuster(): string {
+		$userSession = \OC::$server->get(IUserSession::class);
+		$userId = '';
+		$user = $userSession->getUser();
+		if (!is_null($user)) {
+			$userId = $user->getUID();
 		}
-		return $backgroundLogo && $backgroundLogo !== 'backgroundColor' && $backgroundExists;
+		$userCacheBuster = '';
+		if ($userId) {
+			$userCacheBusterValue = (int)$this->config->getUserValue($userId, 'theming', 'userCacheBuster', '0');
+			$userCacheBuster = $userId . '_' . $userCacheBusterValue;
+		}
+		$systemCacheBuster = $this->config->getAppValue('theming', 'cachebuster', '0');
+		return substr(sha1($userCacheBuster . $systemCacheBuster), 0, 8);
 	}
 }
