@@ -7,16 +7,25 @@ OC.L10N.register(
     "Out sick" : "Болею",
     "Vacationing" : "В отпуске",
     "Working remotely" : "Удалённая работа",
+    "In a call" : "В звонке",
     "User status" : "Статус пользователя",
-    "Clear status message after" : "Очистить сообщение о состоянии через",
-    "What's your status?" : "Укажите свой статус",
+    "View profile" : "Открыть профиль",
+    "Clear status after" : "Удалить статус через",
+    "What is your status?" : "Какой у вас статус?",
+    "Previously set" : "Установлено ранее",
+    "Reset status" : "Сбросить статус",
     "Set status" : "Установить статус",
     "Online status" : "Статус работы в сети",
     "Status message" : "Описание статуса",
+    "Your status was set automatically" : "Ваш статус был установлен автоматически",
     "Clear status message" : "Удалить описание статуса",
     "Set status message" : "Установить описание статуса",
+    "Reset status to \"{icon} {message}\"" : "Сбросить статус на \"{icon} {message}\"",
+    "Reset status to \"{message}\"" : "Сбросить статус на \"{message}\"",
+    "Reset status to \"{icon}\"" : "Сбросить статус на \"{icon}\"",
     "There was an error saving the status" : "Не удалось сохранить статус",
     "There was an error clearing the status" : "Не удалось убрать статус",
+    "There was an error reverting the status" : "Произошла ошибка при сбросе статуса",
     "No recent status changes" : "Недавние изменения статуса отсуствуют ",
     "Away" : "Отошёл",
     "Do not disturb" : "Не беспокоить",
@@ -33,6 +42,6 @@ OC.L10N.register(
     "4 hours" : "4 часа",
     "Mute all notifications" : "Отключить все уведомления",
     "Appear offline" : "Возможно, не в сети",
-    "Clear status after" : "Удалить статус через"
+    "Clear status message after" : "Очистить сообщение о состоянии через"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
