@@ -36,32 +36,30 @@ OC.L10N.register(
     "Operation %s does not exist" : "Операција %s не постоји",
     "Operation %s is invalid" : "Операција %s није исправна",
     "At least one check needs to be provided" : "Треба да се зада бар једна провера",
+    "The provided operation data is too long" : "Наведени операциони подаци су сувише дугачки",
     "Invalid check provided" : "Задата неисправна потврда",
     "Check %s does not exist" : "Проверите да ли %s постоји",
     "Check %s is invalid" : "Проверите да ли је %s исправно",
     "Check %s is not allowed with this entity" : "Провера %s није дозвољена са овим ентитетом",
+    "The provided check value is too long" : "Наведена вредност за проверу је сувише дугачка",
     "Check #%s does not exist" : "Проверите да ли #%s постоји",
     "Check %s is invalid or does not exist" : "Проверите да ли је %s неисправно или не постоји",
     "Flow" : "Ток",
     "Nextcloud workflow engine" : "Некстклаудов мотор радног тока",
     "Select a filter" : "Одаберите филтер",
     "Select a comparator" : "Одаберите компаратор",
+    "Remove filter" : "Уклони филтер",
     "Select a file type" : "Одаберите тип фајла",
     "e.g. httpd/unix-directory" : "нпр. httpd/unix-directory",
     "Folder" : "Фасцикла",
     "Images" : "Слике",
     "Office documents" : "Канцеларијски документи",
     "PDF documents" : "PDF документи",
+    "Custom MIME type" : "Прилагођени MIME тип",
     "Custom mimetype" : "Произвољни MIME тип",
-    "Select a tag" : "Одаберите ознаку",
-    "No results" : "Нема резултата",
-    "%s (invisible)" : "%s (невидљив)",
-    "%s (restricted)" : "%s (ограничен)",
     "Please enter a valid time span" : "Унесите исправан временски распон",
     "Select a request URL" : "Одабери адресу захтева",
-    "Predefined URLs" : "Предефинисане адресе",
     "Files WebDAV" : "WebDAV фајлови",
-    "Others" : "Остали",
     "Custom URL" : "Произвољна адреса",
     "Select a user agent" : "Одаберите агента захтева",
     "Android client" : "Андроид клијент",
@@ -73,6 +71,7 @@ OC.L10N.register(
     "Add new flow" : "Додај нови ток",
     "When" : "Када",
     "and" : "и",
+    "Add a new filter" : "Додај нови филтер",
     "Cancel" : "Откажи",
     "Delete" : "Обриши",
     "The configuration is invalid" : "Конфигурација је неисправна",
@@ -81,7 +80,7 @@ OC.L10N.register(
     "Available flows" : "Доступни токови",
     "For details on how to write your own flow, check out the development documentation." : "За детаље како написати сопствени ток, погледајте програмерску документацију.",
     "More flows" : "Још токова",
-    "Browse the app store" : "Прегледајте продавницу апликација",
+    "Browse the App Store" : "Прегледајте Продавницу апликација",
     "Show less" : "Прикажи мање",
     "Show more" : "Прикажи више",
     "Configured flows" : "Подешени токови",
@@ -113,24 +112,11 @@ OC.L10N.register(
     "User group membership" : "Припадност групи",
     "is member of" : "је члан групе",
     "is not member of" : "није члан групе",
-    "Example: {placeholder}" : "Пример: {placeholder}",
-    "Select tag…" : "Одаберите ознаку…",
-    "Start" : "Почетак",
-    "End" : "Крај",
-    "Select timezone…" : "Одаберите временску зону…",
-    "Sync clients" : "Синхронизовани клијенти",
-    "Short rule description" : "Кратки опис правила",
-    "Add rule" : "Додај правило",
-    "Reset" : "Ресетуј",
-    "Saving…" : "Чувам…",
-    "Group list is empty" : "Списак група је празан",
-    "Unable to retrieve the group list" : "Не могу да добавим списак група",
-    "Saved" : "Снимљено",
-    "Saving failed:" : "Снимање није успело:",
-    "Add rule group" : "Додај групу правила",
-    "Tag management" : "Управљање ознакама",
-    "Files workflow engine" : "Мотор за радни ток фајлова",
-    "Open documentation" : "Отвори документацију",
-    "Loading…" : "Учитавање…"
+    "Select a tag" : "Одаберите ознаку",
+    "No results" : "Нема резултата",
+    "%s (invisible)" : "%s (невидљив)",
+    "%s (restricted)" : "%s (ограничен)",
+    "Predefined URLs" : "Предефинисане адресе",
+    "Others" : "Остали"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
