@@ -40,14 +40,13 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "일부 링크 공유가 삭제됨",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "보안 버그로 인하여 일부 링크 공유를 삭제했습니다. 링크를 눌러서 더 많은 정보를 볼 수 있습니다.",
     "The user limit of this instance is reached." : "이 인스턴스의 사용자수 한계에 도달함.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "사용자수 제한을 해제하기 위해 구독키를 입력하세요. 기업용 Nextcloud에 대해 자세히 알고 싶다면, 저희 웹사이트를 방문하세요.",
+    "Learn more ↗" : "더 알아보기 ↗",
     "Preparing update" : "업데이트 준비 중",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "수리 단계:",
     "Repair info:" : "수리 정보:",
     "Repair warning:" : "수리 경고:",
     "Repair error:" : "수리 오류:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "config.php에서 자동 업데이트가 비활성화되어 있기 때문에 명령줄 업데이트를 사용하십시오.",
     "Turned on maintenance mode" : "유지 보수 모드 켜짐",
     "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
     "Maintenance mode is kept active" : "유지 보수 모드가 켜져 있음",
@@ -70,16 +69,17 @@ OC.L10N.register(
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP에서 시스템 환경 변수를 올바르게 조회할 수 없는 것 같습니다. getenv(\"PATH\") 시험 결과 빈 값이 반환되었습니다.",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "PHP 설정과 관련된 {linkstart}문서 ↗{linkend}를 참조하시어 이 서버의 PHP 설정을 확인하십시오. 특히 php-fpm을 사용할 경우 관련성이 높습니다.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "읽기 전용 설정이 활성화되었습니다. 이 상태에서는 웹 인터페이스를 통하여 일부 설정을 변경할 수 없습니다. 또한 매 업데이트마다 파일을 쓸 수 있는 상태로 변경해야 합니다.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "당신의 이메일 서버 설정은 입력되지 않았거나 검증되지 않았습니다. {mailSettingsStart}기본 설정{mailSettingsEnd}으로 이동해 설정을 완료하십시오. 이후 양식 아래 “이메일 발송” 버튼을 눌러 설정을 검증하십시오.",
+    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "이메일 서버 설정이 입력되지 않았거나 검증되지 않았습니다. {mailSettingsStart}기본 설정{mailSettingsEnd}으로 이동해 설정을 완료하십시오. 서버 정보를 입력한 후 양식 아래 “이메일 발송” 버튼을 눌러 설정을 검증하십시오.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "데이터베이스가 \"READ COMMITTED\" 트랜잭션 격리 수준에서 실행되고 있지 않습니다. 여러 작업이 동시에 실행될 때 문제가 발생할 수 있습니다.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP의 \"fileinfo\" 모듈이 없습니다. 올바른 MIME 형식 감지를 위해서 이 모듈을 활성화하는 것을 추천합니다.",
+    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "주로 사용할 URL이 config.php 파일의 \"overwrite.cli.url\" 옵션에 올바르게 설정되어 있는지 확인하십시오. 제안: \"{suggestedOverwriteCliURL}\". 설정이 잘못되었을 경우 cron을 통한 URL 생성에 문제가 생길 수 있습니다. (제안된 URL이 이 Nextcloud에 접근하는 주된 URL이 아닐 수 있습니다. 따라서, 해당 사항을 직접 재확인하는 것이 좋습니다.)",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "당신의 설치에서 기본 국가 번호가 설정되지 않았습니다. 프로필 설정에서 국가 번호 없이 전화번호를 사용하기 위해서 이 설정이 필요합니다. 국가 번호 없이 전화번호를 사용하게 하려면, 지역의 {linkstart}ISO 3166-1 코드↗{linkend}를 참조하여 설정 파일에 \"default_phone_region\"을 추가하십시오.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "CLI로 cron 작업을 실행시킬 수 없었습니다. 다음 오류가 발생했습니다:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "마지막 백그라운드 작업이 {relativeTime}에 수행되었습니다. 무엇인가 잘못된 것 같습니다. {linkstart}백그라운드 작업 설정을 확인하십시오 ↗{linkend}.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "이 빌드는 공식적으로 지원하지 않는 Nextcloud 커뮤니티 빌드입니다. 이 인스턴스의 크기를 고려하면, 성능과 신뢰성, 확장성 등을 보장할 수 없습니다. 무료 서비스의 과부하를 방지하기 위해 푸시 알림은 제한됩니다. Nextcloud Enterprise의 혜택에 대해서는 {linkstart}https://nextcloud.com/enterprise{linkend}를 참조하십시오.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "서버가 인터넷에 연결되지 않아 다수의 종단점에 도달할 수 없습니다. 이로 인해 외부 저장소 마운트, 서드파티 앱 업데이트와 설치에 대한 알림 수신 등의 기능을 사용할 수 없을 것입니다. 원격 파일 접근과 알림 이메일 전송 또한 작동하지 않을 것입니다. 서버를 인터넷과 연결하여 모든 기능을 사용하십시오.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "매모리 캐시가 설정되지 않았습니다. 성능 향상을 위해 가능하면 memcache를 설정하십시오. 더 많은 정보는 {linkstart}문서 ↗{linkend}를 참조하십시오.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "현재 PHP {version}(으)로 실행중입니다. PHP 버전을 업그레이드 하여 지원중인 {linkstart} PHP 그룹의 성능 및 보안 업데이트 ↗{linkend} 혜택을 누리십시오.",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23이 PHP 7.3를 지원하는 마지막 릴리즈입니다. Nextcloud 24은 PHP 7.4 이상이 필요합니다.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "역방향 프록시 헤더 설정이 올바르지 않거나 신뢰하는 프록시를 통해 Nextcloud에 접근하고 있을 수 있습니다. 만약 Nextcloud를 신뢰하는 프록시를 통해 접근하고 있지 않다면 이는 보안 문제이며 공격자가 Nextcloud에 보이는 IP 주소를 속이고 있을 수 있습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">문서</a>를 참고하십시오.",
     "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP의 OPcache 모듈이 올바르게 설정되지 않았습니다. 추가적인 정보가 필요할 경우 {linkstart}문서 ↗{linkend}를 참조하십시오.",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP 함수 \"set_time_limit\"을 사용할 수 없습니다. 스크립트가 실행 중간에 중지되어 설치를 깨트릴 수도 있습니다. 이 함수를 활성화하는 것을 추천합니다.",
@@ -123,16 +123,20 @@ OC.L10N.register(
     "Continue to {productName}" : "{productName}으로 계속하기",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["업데이트가 성공했습니다. %n초 후 {productName}(으)로 이동합니다."],
     "More apps" : "더 많은 앱",
+    "_{count} notification_::_{count} notifications_" : ["{count}개의 알림"],
     "Log in" : "로그인",
     "Logging in …" : "로그인 중 …",
     "Server side authentication failed!" : "서버 인증 실패!",
     "Please contact your administrator." : "관리자에게 문의하십시오.",
     "An internal error occurred." : "내부 오류가 발생했습니다.",
     "Please try again or contact your administrator." : "다시 시도하거나 관리자에게 연락하십시오.",
+    "Account name or email" : "계정 이름 또는 이메일",
     "Password" : "암호",
+    "Log in to {productName}" : "{productName}에 로그인",
     "Wrong username or password." : "사용자 이름이나 암호가 잘못되었습니다.",
     "User disabled" : "사용자 비활성화됨",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "사용 중인 IP에서 여러 번의 잘못된 로그인 시도를 감지했습니다. 30초 후에 다시 로그인할 수 있습니다.",
+    "Log in with a device" : "기기로 로그인",
     "Username or email" : "사용자 이름 또는 이메일",
     "Your account is not setup for passwordless login." : "당신의 계정은 비밀번호 없이 로그인하도록 설정되지 않았습니다.",
     "Browser not supported" : "브라우저를 지원하지 않습니다.",
@@ -140,8 +144,6 @@ OC.L10N.register(
     "Your connection is not secure" : "당신의 연결이 안전하지 않습니다.",
     "Passwordless authentication is only available over a secure connection." : "비밀번호 없는 인증은 보안 연결에서만 사용할 수 있습니다.",
     "Reset password" : "암호 재설정",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "비밀번호 초기화 메시지가 이 계정의 이메일 주소로 발송되었습니다. 메일을 받지 못했다면, 스팸/정크 폴더를 확인하거나 로컬 관리자에게 문의하십시오.",
-    "If it is not there ask your local administrator." : "그곳에 없다면 로컬 관리자에게 문의하십시오.",
     "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
     "Password cannot be changed. Please contact your administrator." : "암호를 변경할 수 없습니다. 관리자에게 문의하십시오.",
     "Back to login" : "로그인으로 돌아가기",
@@ -163,24 +165,25 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "파일 연락처 달력과 통합되는 간단한 이메일 앱",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "당신의 브라우저와 모바일 앱 속의  채팅, 영상 통화, 화면 공유, 온라인 미팅 그리고 웹 회의",
     "Forgot password?" : "암호를 잊으셨습니까?",
-    "Log in with a device" : "기기로 로그인",
     "Back" : "뒤로",
     "Login form is disabled." : "로그인 양식이 비활성화 되었습니다.",
-    "Edit Profile" : "프로파일 수정",
-    "The headline and about sections will show up here" : "머리말과 about section이 여기에 보일것입니다.",
+    "Edit Profile" : "프로필 수정",
+    "The headline and about sections will show up here" : "표제와 기타 정보가 여기에 보일 것입니다",
+    "You have not added any info yet" : "아직 아무 정보도 추가하지 않았습니다",
+    "{user} has not added any info yet" : "사용자 {user}이(가) 아직 아무 정보도 추가하지 않았습니다.",
     "Reset search" : "검색 초기화",
     "Start search" : "검색 시작",
     "Search for {name} only" : "{name}(으)로만 검색",
-    "No results for {query}" : "{query}에 대한 결과가 없음",
-    "Press enter to start searching" : "엔터를 눌러 검색 시작",
     "Start typing to search" : "검색어 입력",
     "Loading more results …" : "더 많은 결과 불러오는 중...",
     "Load more results" : "더 많은 결과 불러오기",
     "Search" : "검색",
+    "No results for {query}" : "{query}에 대한 결과가 없음",
     "An error occurred while searching for {type}" : "{type} 탐색중 오류 발생",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["{minSearchLength}개 이상의 문자를 입럭하시오"],
+    "Open settings menu" : "설정 메뉴 열기",
+    "Settings menu" : "설정 메뉴",
     "Search {types} …" : "{types} 검색 ...",
-    "Settings" : "설정",
     "Could not load your contacts" : "연락처를 불러올 수 없음",
     "Search contacts …" : "연락처 검색…",
     "No contacts found" : "연락처를 찾을 수 없음",
@@ -222,6 +225,7 @@ OC.L10N.register(
     "Show list view" : "리스트 보기",
     "Show grid view" : "모눈 보기",
     "Pending" : "보류 중",
+    "Home" : "홈",
     "Copy to {folder}" : "{folder}에 복사",
     "Move to {folder}" : "{folder}(으)로 이동",
     "Saving …" : "저장 중 …",
@@ -263,11 +267,10 @@ OC.L10N.register(
     "Admin" : "관리자",
     "Help" : "도움말",
     "Access forbidden" : "접근 금지됨",
-    "Profile not found" : "프로파일 찾을 수 없음",
-    "The profile does not exist." : "프로파일이 존재하지 않습니다.",
+    "Profile not found" : "프로필 찾을 수 없음",
+    "The profile does not exist." : "프로필이 존재하지 않습니다.",
     "Back to %s" : "%s(으)로 돌아가기",
-    "File not found" : "파일을 찾을 수 없음",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "서버에서 문서를 찾을 수 없습니다. 공유가 삭제되었거나 만료되었습니까?",
+    "Page not found" : "페이지를 찾을 수 없음",
     "Too many requests" : "너무 많은 요청",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "이 네트워크에 너무 요청이 많습니다. 나중에 다시 시도하십시오. 이것이 오류일 경우 관리자에게 문의하십시오.",
     "Error" : "오류",
@@ -318,10 +321,7 @@ OC.L10N.register(
     "Skip to main content" : "주 내용으로 이동",
     "Skip to navigation of app" : "앱 탐색으로 이동",
     "Get your own free account" : "무료 계정 등록",
-    "%s's homepage" : "%s의 홈페이지",
-    "Contacts" : "연락처",
-    "Contacts menu" : "연락처 메뉴",
-    "Open settings menu" : "설정 메뉴 열기",
+    "Go to %s" : "%s로 이동",
     "Confirm your password" : "암호 확인",
     "Connect to your account" : "내 계정에 연결",
     "Please log in before granting %1$s access to your %2$s account." : "%1$s에서 내 %2$s 계정에 접근하는 것을 허용하려면 로그인해야 합니다.",
@@ -341,7 +341,6 @@ OC.L10N.register(
     "Email address" : "이메일 주소",
     "Password sent!" : "암호가 발송되었습니다",
     "You are not authorized to request a password for this share" : "이 공유의 비밀번호를 요청할 권한이 없습니다.",
-    "Go to %s" : "%s로 이동",
     "Two-factor authentication" : "2단계 인증",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "현재 계정에 향상된 보안이 켜져 있습니다. 2단계 인증 방식을 선택하십시오:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "2단계 인증 방식을 불러올 수 없습니다. 관리자에게 문의하십시오.",
@@ -367,6 +366,7 @@ OC.L10N.register(
     "Detailed logs" : "자세한 로그",
     "Update needed" : "업데이트 필요",
     "Please use the command line updater because you have a big instance with more than 50 users." : "현재 인스턴스에 50명 이상의 사용자가 있기 때문에 명령행 업데이터를 사용하십시오.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "config.php에서 자동 업데이트가 비활성화되어 있기 때문에 명령줄 업데이트를 사용하십시오.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "도움말을 보려면 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">문서</a>를 참조하십시오.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "웹 UI를 통한 업데이트 시 요청 시간이 초과되어 데이터가 손실될 수 있는 위험성을 알고 있으며, 내 데이터를 백업해 두었고 실패한 경우 복원할 수 있는 방법을 알고 있습니다.",
     "Upgrade via web on my own risk" : "그래도 웹으로 업데이트하기",
@@ -374,25 +374,25 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "이 %s 인스턴스는 현재 점검 모드입니다. 시간이 걸릴 수도 있습니다.",
     "This page will refresh itself when the instance is available again." : "인스턴스를 다시 사용할 수 있을 때 페이지를 자동으로 새로 고칩니다.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오.",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "이 Nextcloud 커뮤니티 릴리즈는 지원되지 않으며 즉각적인 알림을 사용할 수 없습니다.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: 테이블 %s 확인 중",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "웹 서버에서 인터넷에 연결할 수 없습니다. 여러 종단점에 접근할 수 없습니다. 외부 저장소 마운트, 업데이트 알림, 추가 앱 설치 등 기능이 작동하지 않을 것입니다. 원격으로 파일에 접근하거나 알림 이메일을 보내지 못할 수도 있습니다. 모든 기능을 사용하려면 이 서버를 인터넷에 연결하십시오.",
-    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20이 PHP 7.2를 지원하는 마지막 릴리즈입니다. Nextcloud 21은 PHP 7.3 이상이 필요합니다.",
-    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPcache 모듈이 로드되지 않았습니다. {linkstart}더 나은 성능을 위해 ↗{linkend} 이를 PHP에 로드하는 것이 권장됩니다.",
-    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache 모듈이 바르게 설정되지 않았습니다.  {linkstart}더 나은 성능을 위해 ↗{linkend} 다음의 설정을 <code>php.ini</code>에서 사용하십시오:",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "다른 데이터 베이스로 마이그레션하기 위해서 다음 명령을 사용하세요: ''occ db:convert-type', 또는 다음 {linkstart}문서를 참조하세요 ↗{linkend}.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "데이터 디렉터리와 파일을 인터넷에서 접근할 수 있는 것 같습니다. .htaccess 파일을 사용할 수 없습니다. 웹 서버 설정을 변경하여 데이터 디렉터리에 접근할 수 없도록 하거나, 데이터 디렉터리를 웹 서버 문서 디렉터리 밖으로 옮기는 것을 추천합니다.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "이 빌드는 공식적으로 지원하지 않는 Nextcloud 커뮤니티 빌드입니다. 이 인스턴스의 크기를 고려하면, 성능과 신뢰성, 확장성 등을 보장할 수 없습니다. 무료 서비스의 과부하를 방지하기 위해 푸시 알림은 제한됩니다. Nextcloud Enterprise의 혜택에 대해서는 https://nextcloud.com/enterprise를 참조하십시오.",
+    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23이 PHP 7.3를 지원하는 마지막 릴리즈입니다. Nextcloud 24은 PHP 7.4 이상이 필요합니다.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP 헤더가 \"{expected}\"을(를) 포함하고 있지 않습니다. 잠재적인 정보 유출 및 보안 위협이 될 수 있으므로 설정을 변경하는 것을 추천합니다.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "비밀번호 초기화 메시지가 이 계정의 이메일 주소로 발송되었습니다. 메일을 받지 못했다면, 스팸/정크 폴더를 확인하거나 로컬 관리자에게 문의하십시오.",
+    "If it is not there ask your local administrator." : "그곳에 없다면 로컬 관리자에게 문의하십시오.",
     "Collaboratively edit office documents." : "오피스 문서를 함께 편집하세요.",
     "Local document editing back-end used by the Collabora Online app." : "Collabora Online 앱을 로컬 문서 수정 백엔드로 사용 함.",
+    "Settings" : "설정",
     "restricted" : "제한됨",
     "invisible" : "보이지 않음",
+    "File not found" : "파일을 찾을 수 없음",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "서버에서 문서를 찾을 수 없습니다. 공유가 삭제되었거나 만료되었습니까?",
     "More" : "더 보기",
     "More apps menu" : "더 많은 앱 메뉴",
-    "Settings menu" : "설정 메뉴",
-    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 시도하십시오",
+    "Contacts" : "연락처",
+    "Contacts menu" : "연락처 메뉴",
     "Setup two-factor authentication" : "2단계 인증 설정",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "이 Nextcloud 커뮤니티 릴리즈는 지원되지 않으며 즉각적인 알림을 사용할 수 없습니다.",
-    "You haven't added any info yet" : "아직 아무 정보도 추가하지 않았습니다.",
-    "{user} hasn't added any info yet" : "{user} 아직 아무정보도 추가하지 않았습니다."
+    "Press enter to start searching" : "엔터를 눌러 검색 시작"
 },
 "nplurals=1; plural=0;");
