@@ -44,7 +44,6 @@ OC.L10N.register(
     "Repair info:" : "Pataisymo informacija:",
     "Repair warning:" : "Taisymo įspėjimas:",
     "Repair error:" : "Taisymo klaida:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Automatinis atnaujinimas išjungtas config.php faile. Naudokite komandinės eilutės atnaujinimo įrankį.",
     "Turned on maintenance mode" : "Įjungta techninės priežiūros veiksena",
     "Turned off maintenance mode" : "Išjungta techninės priežiūros veiksena",
     "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
@@ -94,6 +93,7 @@ OC.L10N.register(
     "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
     "User disabled" : "Naudotojas išjungtas",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
+    "Log in with a device" : "Prisijungti naudojant įrenginį",
     "Username or email" : "Naudotojas arba el. paštas",
     "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
     "Browser not supported" : "Naršyklė nepalaikoma",
@@ -115,7 +115,6 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
     "Forgot password?" : "Pamiršote slaptažodį?",
-    "Log in with a device" : "Prisijungti naudojant įrenginį",
     "Back" : "Atgal",
     "Edit Profile" : "Taisyti profilį",
     "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
@@ -123,15 +122,16 @@ OC.L10N.register(
     "{user} has not added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos",
     "Reset search" : "Atstatyti paiešką",
     "Search for {name} only" : "Ieškoti tik {name}",
-    "No results for {query}" : "{query} negrąžino jokių rezultatų",
     "Start typing to search" : "Norėdami atlikti paiešką, pradėkite rašyti",
     "Loading more results …" : "Įkeliama daugiau rezultatų…",
     "Load more results" : "Įkelti daugiau rezultatų",
     "Search" : "Ieškoti",
+    "No results for {query}" : "{query} negrąžino jokių rezultatų",
     "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
+    "Open settings menu" : "Atverti nustatymų meniu",
+    "Settings menu" : "Nustatymų meniu",
     "Search {types} …" : "Ieškoti {types}…",
-    "Settings" : "Nustatymai",
     "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
     "Search contacts …" : "Ieškoti adresatų…",
     "No contacts found" : "Adresatų nerasta",
@@ -173,6 +173,7 @@ OC.L10N.register(
     "Show list view" : "Rodyti sąrašo rodinį",
     "Show grid view" : "Rodyti tinklelio rodinį",
     "Pending" : "Vykdoma",
+    "Home" : "Namai",
     "Copy to {folder}" : "Kopijuoti į {folder}",
     "Move to {folder}" : "Perkelti į {folder}",
     "Saving …" : "Įrašoma …",
@@ -266,7 +267,7 @@ OC.L10N.register(
     "Skip to main content" : "Pereiti į pagrindinį turinį",
     "Skip to navigation of app" : "Pereiti į programėlės naršymą",
     "Get your own free account" : "Gaukite nemokamą asmeninę paskyrą",
-    "Open settings menu" : "Atverti nustatymų meniu",
+    "Go to %s" : "Pereiti į %s",
     "Confirm your password" : "Patvirtinkite savo slaptažodį",
     "Connect to your account" : "Prisijunkite prie paskyros",
     "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
@@ -283,7 +284,6 @@ OC.L10N.register(
     "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
     "Email address" : "El. pašto adresas",
     "Password sent!" : "Slaptažodis išsiųstas!",
-    "Go to %s" : "Pereiti į %s",
     "Two-factor authentication" : "Dviejų faktorių tapatybės nustatymas",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nepavyko įkelti bent vieno iš jūsų įjungtų dviejų faktorių tapatybės nustatymo metodų. Susisiekite su savo administratoriumi.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Susisiekite su savo administratoriumi dėl pagalbos. ",
@@ -306,6 +306,7 @@ OC.L10N.register(
     "Detailed logs" : "Išsamūs žurnalai",
     "Update needed" : "Reikalingas atnaujinimas",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Naudokite komandų eilutės atnaujinimo programą, nes turite didelį egzempliorių su daugiau nei 50 naudotojų.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Automatinis atnaujinimas išjungtas config.php faile. Naudokite komandinės eilutės atnaujinimo įrankį.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Prireikus pagalbos, žiūrėkite  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Suprantu, kad atnaujinimui naudodamas vartotojo aplinką, rizikuoju, kad sistemos darbas sutriks ir prisijungę vartotojai gali netekti duomenų, turiu atsarginę duomenų kopiją ir žinau, kaip atstatyti duomenis nesėkmės atveju.",
     "Upgrade via web on my own risk" : "Atnaujinti per interneto naršyklę prisiimant riziką",
@@ -314,6 +315,7 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Tikrinama lentelė %s",
+    "Settings" : "Nustatymai",
     "restricted" : "apribota",
     "invisible" : "nematoma",
     "File not found" : "Failas nerastas",
@@ -321,7 +323,6 @@ OC.L10N.register(
     "More" : "Daugiau",
     "More apps menu" : "Daugiau programėlių meniu",
     "Contacts" : "Adresatai",
-    "Contacts menu" : "Adresatų meniu",
-    "Settings menu" : "Nustatymų meniu"
+    "Contacts menu" : "Adresatų meniu"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
