@@ -37,14 +37,13 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Carchi ligòngiu de cumpartzidura tuo nch'est istadu bogadu",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro un'errore de seguresa nch'amus dèpidu bogare carchi ligòngiu de cumpartzidura. Càstia su ligòngiu pro àteras informatziones.",
     "The user limit of this instance is reached." : "S'est lòmpidu su lìmite de utèntzia pro custa istàntzia.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Inserta sa crae de sutascritzione pro crèschere su lìmite de utèntzia. Pro àteras informatziones de Nextcloud Enterprise bae a su situ web nostru. ",
+    "Learn more ↗" : "Àteras informatziones ↗",
     "Preparing update" : "Aprontende s'agiornamentu",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Passu de s'acontzu:",
     "Repair info:" : "Informatziones de s'acontzu:",
     "Repair warning:" : "Avisu de s'acontzu:",
     "Repair error:" : "Errore in s'acontzu:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Imprea s'atualizadore a lìnia de cummandu ca s'agiornamentu automàticu est disativadu in sa config.php.",
     "Turned on maintenance mode" : "Furriadu a modalidade de mantenidura",
     "Turned off maintenance mode" : "Modalidade de mantenidura disativada",
     "Maintenance mode is kept active" : "Sa modalidade de mantenidura abarrat ativa",
@@ -130,6 +129,7 @@ OC.L10N.register(
     "Wrong username or password." : "Nùmene utente o crae isballiada.",
     "User disabled" : "Utèntzia disativada",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
+    "Log in with a device" : "Autentica·ti cun unu dispositivu",
     "Username or email" : "Nùmene utente o indiritzu de posta",
     "Your account is not setup for passwordless login." : "Su contu tuo no est fatu pro autenticatziones chene crae.",
     "Browser not supported" : "Navigadore non suportadu",
@@ -137,8 +137,6 @@ OC.L10N.register(
     "Your connection is not secure" : "Sa connessione tua no est segura",
     "Passwordless authentication is only available over a secure connection." : "S'autenticatzione chene crae est a disponimentu isceti cun connessiones seguras.",
     "Reset password" : "Riprìstina sa crae",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Est istadu imbiadu unu messàgiu pro su risprìstinu de sa crae a s'indiritzu de posta eletrònica de custu contu. Si non ddu retzis, controlla in is cartellas de s'àliga o pide agiudu a s'amministratzione.",
-    "If it is not there ask your local administrator." : "Si no est in cue, dimanda a s'amministratzione locale tua.",
     "Couldn't send reset email. Please contact your administrator." : "No at fatu a ripristinare sa posta eletrònica. Cuntata s'amministratzione.",
     "Password cannot be changed. Please contact your administrator." : "Sa crae non faghet a dda cambiare. Cuntata s'amministratzione.",
     "Back to login" : "Torra a s'autenticatzione",
@@ -160,20 +158,19 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicatzione de posta eletrònica simpre e integrada bene cun Archìvios, Cuntatos e Calendàriu.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tzarradas, video mutidas, cumpartzidura de s'ischermu, reuniones in lìnia e vìdeo-cunferèntzias – in su navigadore tuo e cun aplicatziones mòbiles.",
     "Forgot password?" : "Crae iscaressida?",
-    "Log in with a device" : "Autentica·ti cun unu dispositivu",
     "Back" : "A coa",
     "Login form is disabled." : "Su mòdulu de atzessu est disativadu.",
     "Reset search" : "Riprìstina chirca",
     "Search for {name} only" : "Chirca pro {name} ebbia",
-    "No results for {query}" : "Perunu resurtadu pro {query}",
     "Start typing to search" : "Cumintza a iscrìere pro chircare",
     "Loading more results …" : "Carrighende àteros resurtados ...",
     "Load more results" : "Càrriga àteros resurtados",
     "Search" : "Chirca",
+    "No results for {query}" : "Perunu resurtadu pro {query}",
     "An error occurred while searching for {type}" : "B'at àpidu un'errore in sa chirca de {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Inserta {longàriaMinChirca} o prus caràteres pro chircare","Inserta·nche {minSearchLength} o prus caràteres pro chircare"],
+    "Settings menu" : "Menu de is impostatziones",
     "Search {types} …" : "Chirca {types} …",
-    "Settings" : "Cunfiguratziones",
     "Could not load your contacts" : "No at fatu a carrigare is cuntatos",
     "Search contacts …" : "Chirca cuntatos ...",
     "No contacts found" : "Perunu cuntatu agatadu",
@@ -213,6 +210,7 @@ OC.L10N.register(
     "({count} selected)" : "({count} seletzionadu)",
     "Error loading file exists template" : "Errore in su carrigamentu de su modellu de archìviu",
     "Pending" : "In suspesu",
+    "Home" : "Pàgina printzipale",
     "Copy to {folder}" : "Còpia in {folder}",
     "Move to {folder}" : "Tràmuda a {folder}",
     "Saving …" : "Sarvende …",
@@ -255,8 +253,7 @@ OC.L10N.register(
     "Help" : "Agiudu",
     "Access forbidden" : "Atzessu proibidu",
     "Back to %s" : "A coa a %s",
-    "File not found" : "Archìviu no agatadu",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Su documentu non s'est agatadu in su serbidore. Mancari sa cumpartzidura nch'est istada cantzellada o est iscadida?",
+    "Page not found" : "Pàgina no agatada",
     "Too many requests" : "Tropu dimandas",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tropu rechestas sunt arribadas dae sa rete tua. Torra a proare prus a tardu o cuntata s'amministradore tuo chi ddoe at un'errore.",
     "Error" : "Errore",
@@ -306,8 +303,7 @@ OC.L10N.register(
     "Skip to main content" : "Brinca a su cuntenutu printzipale",
     "Skip to navigation of app" : "Brinca a sa navigatzione de s'aplicatzione",
     "Get your own free account" : "Otene su contu tuo a gratis",
-    "Contacts" : "Cuntatos",
-    "Contacts menu" : "Menu de cuntatos",
+    "Go to %s" : "Bae a %s",
     "Confirm your password" : "Cunfirma sa crae",
     "Connect to your account" : "Connete·ti a su contu tuo",
     "Please log in before granting %1$s access to your %2$s account." : "Faghe s'atzessu prima de permìtere a %1$s de intrare a su %2$s contu tuo.",
@@ -322,7 +318,6 @@ OC.L10N.register(
     "You can close this window." : "Podes serrare custa ventana",
     "This share is password-protected" : "Custa cumpartzidura est amparada dae una crae",
     "Email address" : "Indiritzu de posta eletrònica",
-    "Go to %s" : "Bae a %s",
     "Two-factor authentication" : "Autenticatzione a duos fatores",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Su megioru de seguresa est ativadu in su contu tuo. Sèbera unu segundu fatore pro s'autenticatzione:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No at fatu a carriggare a su mancu unu de is mètodos de autenticatzione a duos fatores ativados. Cuntata s'amministratzione.",
@@ -348,6 +343,7 @@ OC.L10N.register(
     "Detailed logs" : "Registros detalliados",
     "Update needed" : "Tocat de agiornare",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Imprea s'atualizadore a lìnia de cummandu ca tenes un'istàntzia manna cun prus de 50 utentes.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Imprea s'atualizadore a lìnia de cummandu ca s'agiornamentu automàticu est disativadu in sa config.php.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pro agiudos, càstia sa  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatzione</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Giai dd'isco ca chi sigu cun s'agiornamentu via internet UI ddoe at s'arriscu chi sa rechesta arribet a una pasada e podet causare sa pèrdida de is datos, ma tèngio una còpia de seguresa e isco comente recuperare s'istàntzia in casu de errore.",
     "Upgrade via web on my own risk" : "Agiorna via web suta responsabilidade mia",
@@ -356,22 +352,20 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Custa pàgina s'at a atualizare cando s'istàntzia at a èssere torra a disponimentu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Cuntata s'amministratzione de sistema si custu messàgiu abarrat o torrat a cumpàrrere",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Controllende sa tàula %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Custu serbidore no tenet una connessione internet chi funtzionet: no si podet lòmpere a is puntos finales mùltiplos. Bolet nàrrere ca propiedades comente sa crèschida de sa memòria de foras, is notìficas subra de agiornamentos o installatzione de aplicatziones de sa de tres partes no ant a funtzionare. Atzèdere dae remotu a is archìvios o imbiare una notìfica de posta eletrònica diant no pòdere funtzionare.  Ativa una connessione dae custu serbidore a Internet pro pòdere impreare totu custas propiedades.",
-    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 est s'ùrtima versione chi suportat PHP 7.2. Nextcloud 21 rechedet a su mancu PHP 7.3.",
-    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Su mòdulu PHP OPcache no est carrigadu. {linkstart}Pro un'esecutzione mègius, est cussigiadu ↗{linkend}  a ddu carrigare intro de s'installatzione PHP.",
-    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "Su OPcache PHP no est cunfiguradu bene. {linkstart}Pro un'esecutzione mègius est cussigiadu ↗{linkend} a impreare is impostatzione in fatu in su <code>php.ini</code>:",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "In calicuna colunna de sa base de datos mancat una conversione a big int. Cambiare is genias de is colunnas in tàulas mannas podet pigare unu pagu de tempus, tando no sunt istètias cambiadas de manera automàtica. Impreende 'occ db:convert-filecache-bigint' si podent fàghere a manu is càmbios prevèdidos. S'operatzione depet èssere fata cun s'istàntzia foras de lìnia. Pro àteros detàllios leghe {linkstart}pàgina de sa documentatzione subra de custu ↗{linkend}.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Pro andare a un'àtera base de datos, imprea custa lìnia de commandu: 'occ db:convert-type', o càstia sa {linkstart}documentatzione ↗{linkend}.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Est probàbile chi sa cartella de datos e is archìvios tuos siant atzessìbiles dae internet. S'archìviu .htaccess no est funtzionende. Est cussigiadu meda a cunfigurare su serbidore internet, de manera chi sa cartella de datos no siat prus atzessìbile, o a dda tramudare a foras de s'archìviu de orìgine de su serbidore internet.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no cuntenet \"{expected}\". Custu est un'arriscu possìbile de seguresa o privadesa, tando est cussigiadu a arrangiare cust'impostatzione de cunsighèntzia.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Est istadu imbiadu unu messàgiu pro su risprìstinu de sa crae a s'indiritzu de posta eletrònica de custu contu. Si non ddu retzis, controlla in is cartellas de s'àliga o pide agiudu a s'amministratzione.",
+    "If it is not there ask your local administrator." : "Si no est in cue, dimanda a s'amministratzione locale tua.",
     "Collaboratively edit office documents." : "Modìfica archìvios de testu in collaboratzione.",
     "Local document editing back-end used by the Collabora Online app." : "Su motore de modìfica de is documentos locales impreadu dae s'aplicatzione Collabora Online.",
+    "Settings" : "Cunfiguratziones",
     "restricted" : "limitadu",
     "invisible" : "invisìbile",
+    "File not found" : "Archìviu no agatadu",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Su documentu non s'est agatadu in su serbidore. Mancari sa cumpartzidura nch'est istada cantzellada o est iscadida?",
     "More" : "Àteru",
     "More apps menu" : "Àteros menu de aplicatziones",
-    "Settings menu" : "Menu de is impostatziones",
-    "The password is wrong. Try again." : "Sa crae est isballiada. Torra a proare.",
+    "Contacts" : "Cuntatos",
+    "Contacts menu" : "Menu de cuntatos",
     "Setup two-factor authentication" : "Cunfigura s'autenticatzione a duos fatores"
 },
 "nplurals=2; plural=(n != 1);");
