@@ -25,26 +25,28 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
+    "Files" : "Archivos",
     "today" : "hoy",
     "tomorrow" : "mañana",
     "yesterday" : "ayer",
-    "_in %n day_::_in %n days_" : ["en %n día","en %n días"],
-    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días"],
+    "_in %n day_::_in %n days_" : ["en %n día","en %n días","en %n días"],
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
     "next month" : "próximo mes",
     "last month" : "mes pasado",
-    "_in %n month_::_in %n months_" : ["en %n mes","en %n meses"],
-    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
+    "_in %n month_::_in %n months_" : ["en %n mes","en %n meses","en %n meses"],
+    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses","Hace %n meses"],
     "next year" : "próximo año",
     "last year" : "año pasado",
-    "_in %n year_::_in %n years_" : ["en %n año","en %n años"],
-    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años"],
-    "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas"],
-    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
-    "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos"],
-    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
+    "_in %n year_::_in %n years_" : ["en %n año","en %n años","en %n años"],
+    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años","hace %n años"],
+    "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas","en %n horas"],
+    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas","Hace %n horas"],
+    "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos","en %n minutos"],
+    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos","Hace %n minutos"],
     "in a few seconds" : "en algunos segundos",
     "seconds ago" : "hace segundos",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Por favor hablíitalo en tus configuraciones de aplicación o contacta a tu administrador.  ",
+    "File already exists" : "El archivo ya existe",
     "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
     "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
     "File name is too long" : "El nombre del archivo es demasiado largo",
@@ -59,12 +61,15 @@ OC.L10N.register(
     "Settings" : "Configuraciones",
     "Log out" : "Cerrar sesión",
     "Users" : "Usuarios",
+    "Email" : "Correo electrónico",
+    "Phone" : "Teléfono fijo",
+    "Twitter" : "Twitter",
+    "Website" : "Sitio web",
+    "Address" : "Dirección",
+    "Profile picture" : "Foto de perfil",
+    "About" : "Acerca de",
     "Unknown user" : "Ususario desconocido",
     "Additional settings" : "Configuraciones adicionales",
-    "%s enter the database username and name." : "%s ingresa el usuario y nombre de la base de datos",
-    "%s enter the database username." : "%s ingresa el nombre de usuario de la base de datos.",
-    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
-    "%s you may not use dots in the database name" : "%s no puedes utilizar puntos en el nombre de la base de datos",
     "You need to enter details of an existing account." : "Necesitas ingresar los detalles de una cuenta existente.",
     "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
     "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
@@ -80,7 +85,9 @@ OC.L10N.register(
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
     "Open »%s«" : "Abrir »%s«",
     "You are not allowed to share %s" : "No tienes permitido compartir %s",
+    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
     "Expiration date is in the past" : "La fecha de expiración se encuentra en el pasado",
+    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
     "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
     "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
@@ -129,13 +136,12 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Dic.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
-    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
     "The username is already being used" : "Ese usuario ya está en uso",
     "Could not create user" : "No fue posible crear el usuario",
+    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
+    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
+    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
     "User disabled" : "Usuario deshabilitado",
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
@@ -144,33 +150,15 @@ OC.L10N.register(
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "La ficha ha expirado. Por favor recarga la página.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "No cuentas con controladores de base de datos (sqlite, mysql o postgresql) instalados. ",
-    "Cannot write into \"config\" directory" : "No fue posible escribir en el directorio \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio config. Por favor ve %s",
-    "Cannot write into \"apps\" directory" : "No fue posible escribir en el directorio \"apps\"",
-    "Cannot create \"data\" directory" : "No fue posible crear el directorio \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Por lo general los permisos se pueden corregir al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s.",
-    "Setting locale to %s failed" : "Se presentó una falla al establecer la regionalización a  %s",
-    "Please install one of these locales on your system and restart your webserver." : "Por favor instala uno de las siguientes configuraciones locales en tu sistema y reinicia tu servidor web",
     "PHP module %s not installed." : "El módulo de PHP %s no está instalado. ",
     "Please ask your server administrator to install the module." : "Por favor solicita a tu adminsitrador la instalación del módulo. ",
     "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está establecido como \"%s\" en lugar del valor esperado de \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corregir este tema, establece <code>mbstring.func_overload</code> a <code>0</code> en tu archivo php.ini",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s está instalado. ",
-    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, por favor actualiza la versión de su libxml2 y reinicia tu servidor web. ",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor solicita al administrador reiniciar el servidor web. ",
-    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
-    "Please upgrade your database version" : "Por favor actualiza tu versión de la base de datos",
-    "Your data directory is readable by other users" : "Tu direcctorio data puede ser leído por otros usuarios",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
-    "Your data directory must be an absolute path" : "Tu directorio data debe ser una ruta absoluta",
-    "Check the value of \"datadirectory\" in your configuration" : "Verifica el valor de \"datadirectory\" en tu configuración",
-    "Your data directory is invalid" : "Tu directorio de datos es inválido",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegurate de que exista una archivo llamado \".ocdata\" en la raíz del directorio de datos. ",
     "Could not obtain lock type %d on \"%s\"." : "No fue posible obtener el tipo de bloqueo %d en \"%s\". ",
     "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
@@ -178,13 +166,13 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Esto generalmente se resuelve dándole al servidor web acceso para escribir en el directorio config. ",
-    "Can't create or write into the data directory %s" : "No es posible crear o escribir en el directorio de datos %s",
-    "Invalid Federated Cloud ID" : "ID Inválido",
-    "Can’t increase permissions of %s" : "No es posible incrementar los privilegios de %s",
-    "Files can’t be shared with delete permissions" : "Los archivos no se pueden compartir con permisos de borrado",
-    "Files can’t be shared with create permissions" : "Los archivos no se pueden compartir con permisos de creación",
-    "Can’t set expiration date more than %s days in the future" : "No es posible establecer la fecha de expiración más allá de %s días en el futuro",
-    "Can't read file" : "No se puede leer el archivo"
+    "Full name" : "Nombre completo",
+    "%s enter the database username and name." : "%s ingresa el usuario y nombre de la base de datos",
+    "%s enter the database username." : "%s ingresa el nombre de usuario de la base de datos.",
+    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
+    "%s you may not use dots in the database name" : "%s no puedes utilizar puntos en el nombre de la base de datos",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s está instalado. ",
+    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, por favor actualiza la versión de su libxml2 y reinicia tu servidor web. "
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
