@@ -24,6 +24,7 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
+    "Files" : "Archivos",
     "today" : "hoy",
     "tomorrow" : "mañana",
     "yesterday" : "ayer",
@@ -66,7 +67,6 @@ OC.L10N.register(
     "Address" : "Dirección",
     "Profile picture" : "Foto de perfil",
     "About" : "Acerca",
-    "Full name" : "Nombre completo",
     "Unknown user" : "Ususario desconocido",
     "Additional settings" : "Configuraciones adicionales",
     "You need to enter details of an existing account." : "Necesitas ingresar los detalles de una cuenta existente.",
@@ -135,13 +135,12 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Dic.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
-    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
     "The username is already being used" : "Ese usuario ya está en uso",
     "Could not create user" : "No fue posible crear el usuario",
+    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
+    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
+    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
     "User disabled" : "Usuario deshabilitado",
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
@@ -154,8 +153,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Por favor solicita a tu adminsitrador la instalación del módulo. ",
     "PHP setting \"%s\" is not set to \"%s\"." : "El ajuste PHP \"%s\" no esta establecido a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "El cambiar este ajuste del archivo php.ini hará que Nextcloud corra de nuevo.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s está instalado. ",
-    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, por favor actualiza la versión de su libxml2 y reinicia tu servidor web. ",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Al parecer PHP está configurado para quitar los bloques de comentarios internos. Esto hará que varias aplicaciones principales sean inaccesibles. ",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Esto ha sido causado probablemente por un acelerador de caché como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "¿Los módulos de PHP han sido instalados, pero se siguen enlistando como faltantes?",
@@ -168,25 +165,13 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
+    "Full name" : "Nombre completo",
     "%s enter the database username and name." : "%s ingresa el usuario y nombre de la base de datos",
     "%s enter the database username." : "%s ingresa el nombre de usuario de la base de datos.",
     "%s enter the database name." : "%s ingresar el nombre de la base de datos",
     "%s you may not use dots in the database name" : "%s no puedes utilizar puntos en el nombre de la base de datos",
-    "Cannot write into \"config\" directory" : "No fue posible escribir en el directorio \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio config. Por favor ve %s",
-    "Cannot write into \"apps\" directory" : "No fue posible escribir en el directorio \"apps\"",
-    "Cannot create \"data\" directory" : "No fue posible crear el directorio \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Por lo general los permisos se pueden corregir al darle al servidor web acceso de escritura al directorio raíz. Por favor ve %s.",
-    "Setting locale to %s failed" : "Se presentó una falla al establecer la regionalización a  %s",
-    "Please install one of these locales on your system and restart your webserver." : "Por favor instala uno de las siguientes configuraciones locales en tu sistema y reinicia tu servidor web",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está establecido como \"%s\" en lugar del valor esperado de \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corregir este tema, establece <code>mbstring.func_overload</code> a <code>0</code> en tu archivo php.ini",
-    "PostgreSQL >= 9 required" : "Se requiere PostgreSQL >= 9",
-    "Please upgrade your database version" : "Por favor actualiza tu versión de la base de datos",
-    "Your data directory is readable by other users" : "Tu direcctorio data puede ser leído por otros usuarios",
-    "Your data directory must be an absolute path" : "Tu directorio data debe ser una ruta absoluta",
-    "Check the value of \"datadirectory\" in your configuration" : "Verifica el valor de \"datadirectory\" en tu configuración",
-    "Your data directory is invalid" : "Tu directorio de datos es inválido"
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s está instalado. ",
+    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, por favor actualiza la versión de su libxml2 y reinicia tu servidor web. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
