@@ -4,9 +4,10 @@ OC.L10N.register(
     "Cannot write into \"config\" directory!" : "Hakemistoon \"config\" kirjoittaminen ei onnistu!",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Jos haluat pitää config.php-tiedoston vain luku -muodossa, aseta valinnan \"config_is_read_only\" arvoksi true.",
     "See %s" : "Katso %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Sovelluksen %1$s tiedostoja ei korvattu oikein Varmista, että sen versio on yhteensopiva palvelimen kanssa.",
     "Sample configuration detected" : "Esimerkkimääritykset havaittu",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "On havaittu, että esimerkkimäärityksen on kopioitu. Se voi rikkoa asennuksesi, eikä sitä tueta. Lue ohjeet ennen kuin muutat config.php tiedostoa.",
+    "404" : "404",
+    "The page could not be found on the server." : "Sivua ei löytynyt palvelimelta.",
     "Email verification" : "Sähköpostin vahvistus",
     "Click the following button to confirm your email." : "Napsauta seuraavaa painiketta vahvistaaksesi sähköpostiosoitteesi.",
     "Click the following link to confirm your email." : "Napsauta seuraavaa linkkiä vahvistaaksesi sähköpostiosoitteesi.",
@@ -43,7 +44,9 @@ OC.L10N.register(
     "Unknown filetype" : "Tuntematon tiedostotyyppi",
     "Invalid image" : "Virheellinen kuva",
     "Avatar image is not square" : "Avatar-kuva ei ole neliö",
+    "Files" : "Tiedostot",
     "View profile" : "Näytä profiili",
+    "Local time: %s" : "Paikallinen aika: %s",
     "today" : "tänään",
     "tomorrow" : "huomenna",
     "yesterday" : "eilen",
@@ -81,6 +84,7 @@ OC.L10N.register(
     "Appearance and accessibility" : "Ulkoasu ja saavutettavuus",
     "Apps" : "Sovellukset",
     "Personal settings" : "Henkilökohtaiset asetukset",
+    "Administration settings" : "Ylläpitäjän asetukset",
     "Settings" : "Asetukset",
     "Log out" : "Kirjaudu ulos",
     "Users" : "Käyttäjät",
@@ -95,7 +99,7 @@ OC.L10N.register(
     "Address" : "Osoite",
     "Profile picture" : "Profiilikuva",
     "About" : "Tietoja",
-    "Full name" : "Koko nimi",
+    "Display name" : "Näyttönimi",
     "Headline" : "Otsikko",
     "Organisation" : "Organisaatio",
     "Role" : "Rooli",
@@ -131,6 +135,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s jakoi kohteen »%2$s« kanssasi.",
     "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
     "The requested share does not exist anymore" : "Pyydettyä jakoa ei ole enää olemassa",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Käyttäjää ei luotu, koska käyttäjäraja on tullut täyteen. Tarkista ilmoitukset saadaksesi lisätietoja.",
     "Could not find category \"%s\"" : "Luokkaa \"%s\" ei löytynyt",
     "Sunday" : "sunnuntai",
     "Monday" : "maanantai",
@@ -177,15 +182,14 @@ OC.L10N.register(
     "Oct." : "Loka",
     "Nov." : "Marras",
     "Dec." : "Joulu",
-    "The user limit has been reached and the user was not created." : "Käyttäjäraja on tullut täyteen, joten käyttäjää ei luotu.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-'\"",
+    "A valid password must be provided" : "Anna kelvollinen salasana",
+    "The username is already being used" : "Käyttäjätunnus on jo käytössä",
+    "Could not create user" : "Ei voitu luoda käyttäjää",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\", välilyönnit ja \"_.@-'\"",
     "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
     "Username contains whitespace at the beginning or at the end" : "Käyttäjätunnus sisältää tyhjätilaa joko alussa tai lopussa",
     "Username must not consist of dots only" : "Käyttäjänimi ei voi koostua vain pisteistä",
     "Username is invalid because files already exist for this user" : "Käyttäjänimi on virheellinen koska tiedostoja on olemassa tälle käyttäjälle",
-    "A valid password must be provided" : "Anna kelvollinen salasana",
-    "The username is already being used" : "Käyttäjätunnus on jo käytössä",
-    "Could not create user" : "Ei voitu luoda käyttäjää",
     "User disabled" : "Käyttäjä poistettu käytöstä",
     "Login canceled by app" : "Kirjautuminen peruttiin sovelluksen toimesta",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Sovellusta \"%1$s\" ei voi asentaa, koska seuraavat riippuvuudet eivät täyty: %2$s",
@@ -200,13 +204,12 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory." : "Ei voi kirjoittaa \"apps\"-hakemistoon",
     "Cannot create \"data\" directory." : "Ei voi luoda \"data\"-hakemistoa",
     "Your data directory is not writable." : "Datahakemistosi ei ole kirjoitettavissa.",
+    "Setting locale to %s failed." : "Maa-asetuston %s asettaminen epäonnistui.",
     "PHP module %s not installed." : "PHP-moduulia %s ei ole asennettu.",
     "Please ask your server administrator to install the module." : "Pyydä palvelimen ylläpitäjää asentamaan moduulin.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-asetusta \"%s\" ei ole asetettu arvoon \"%s\".",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> on asetettu arvoon <code>%s</code> odotetun arvon <code>0</code> sijaan.",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Korjaa ongelma asettamalla ominaisuuden <code>mbstring.func_overload</code> arvoksi <code>0</code> php.ini-tiedostossa.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vähintään libxml2 2.7.0 vaaditaan. %s on asennettu.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Päivitä libxml2:n versio ja käynnistä http-palvelin uudelleen.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tämä johtuu todennäköisesti välimuistista tai kiihdyttimestä kuten Zend OPcachesta tai eAcceleratorista.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduulit on asennettu, mutta ovatko ne vieläkin listattu puuttuviksi?",
     "Please ask your server administrator to restart the web server." : "Pyydä palvelimen ylläpitäjää käynnistämään web-palvelin uudelleen.",
@@ -223,23 +226,14 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tallennustilan yhteysvirhe. %s",
     "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
     "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Sovelluksen %1$s tiedostoja ei korvattu oikein Varmista, että sen versio on yhteensopiva palvelimen kanssa.",
+    "Full name" : "Koko nimi",
     "%s enter the database username and name." : "%s anna tietokannan käyttäjätunnus ja nimi.",
     "%s enter the database username." : "%s anna tietokannan käyttäjätunnus.",
     "%s enter the database name." : "%s anna tietokannan nimi.",
     "%s you may not use dots in the database name" : "%s et voi käyttää pisteitä tietokannan nimessä",
-    "Cannot read file" : "Tiedostoa ei voi lukea",
-    "Cannot write into \"config\" directory" : "Hakemistoon \"config\" kirjoittaminen ei onnistu",
-    "Cannot write into \"apps\" directory" : "Hakemistoon \"apps\" kirjoittaminen ei onnistu",
-    "Cannot create \"data\" directory" : "Hakemiston \"data\" luominen ei onnistu",
-    "Setting locale to %s failed" : "Maa-asetuksen %s asettaminen epäonnistui",
-    "Please install one of these locales on your system and restart your webserver." : "Asenna ainakin yksi kyseisistä maa-asetuksista järjestelmään ja käynnistä http-palvelin uudelleen.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload on asetettu arvoon \"%s\" odotetun arvon \"0\" sijaan",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Korjaa tämä ongelma asettamalla <code>mbstring.func_overload</code> arvoon <code>0</code> php.ini-tiedostossasi",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 vaaditaan",
-    "Please upgrade your database version" : "Päivitä tietokantasi versio",
-    "Your data directory is readable by other users" : "Data-hakemisto on muiden käyttäjien luettavissa",
-    "Your data directory must be an absolute path" : "Data-hakemiston tulee olla absoluuttinen polku",
-    "Check the value of \"datadirectory\" in your configuration" : "Tarkista \"datadirectory\"-arvo asetuksistasi",
-    "Your data directory is invalid" : "Datahakemistosi on virheellinen"
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-'\"",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vähintään libxml2 2.7.0 vaaditaan. %s on asennettu.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Päivitä libxml2:n versio ja käynnistä http-palvelin uudelleen."
 },
 "nplurals=2; plural=(n != 1);");
