@@ -2,7 +2,6 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Nuk shkruhet dot te drejtoria \"config\"!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Zakonisht kjo mund të ndreqet duke i akorduar shërbyesit web të drejta shkrimi mbi drejtorinë e formësimeve",
     "See %s" : "Shihni %s",
     "Sample configuration detected" : "U gjet formësim shembull",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "U pa se është kopjuar shembulli për formësime. Kjo mund të prishë instalimin tuaj dhe nuk mbulohet. Ju lutemi, lexoni dokumentimin, përpara se të kryeni ndryshime te config.php",
@@ -25,6 +24,7 @@ OC.L10N.register(
     "Unknown filetype" : "Lloj i panjohur skedari",
     "Invalid image" : "Figurë e pavlefshme",
     "Avatar image is not square" : "Imazhi avatar nuk është katror",
+    "Files" : "Skedarët",
     "today" : "sot",
     "yesterday" : "dje",
     "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
@@ -36,6 +36,7 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["%n minutë më parë","%n minuta më parë"],
     "seconds ago" : "sekonda më parë",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Moduli me ID: %s nuk ekziston. Ju lutem aktivizojeni atë në konfigurimet e aplikacionit tuaj ose kontaktoni administratorin tuaj.",
+    "File already exists" : "Skedari ekziston tashmë",
     "File name is a reserved word" : "Emri i kartelës është një emër i rezervuar",
     "File name contains at least one invalid character" : "Emri i kartelës përmban të paktën një shenjë të pavlefshme",
     "File name is too long" : "Emri i kartelës është shumë i gjatë",
@@ -50,12 +51,15 @@ OC.L10N.register(
     "Settings" : "Konfigurime",
     "Log out" : "Shkyçu",
     "Users" : "Përdorues",
+    "Email" : "Emaili",
+    "Phone" : "Telefon",
+    "Twitter" : "Twitter",
+    "Website" : "Faqe web-i",
+    "Address" : "Adresa",
+    "Profile picture" : "Foto profili",
+    "About" : "Rreth ",
     "Unknown user" : "Përdorues i panjohur",
     "Additional settings" : "Konfigurime shtesë",
-    "%s enter the database username and name." : "%s jepni emrin e bazës së të dhënave dhe emrin e përdoruesit për të.",
-    "%s enter the database username." : "%s jepni emrin e përdoruesit të bazës së të dhënave.",
-    "%s enter the database name." : "%s jepni emrin e bazës së të dhënave.",
-    "%s you may not use dots in the database name" : "%s s’mund të përdorni pika te emri i bazës së të dhënave",
     "You need to enter details of an existing account." : "Duhet të futni detajet e një llogarie ekzistuese.",
     "Oracle connection could not be established" : "S’u vendos dot lidhje me Oracle",
     "Oracle username and/or password not valid" : "Emër përdoruesi dhe/ose fjalëkalim Oracle-i i pavlefshëm",
@@ -66,17 +70,14 @@ OC.L10N.register(
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ju lutemi, hiqeni rregullimin open_basedir nga php.ini juaj ose hidhuni te PHP për 64-bit.",
     "Set an admin username." : "Caktoni një emër përdoruesi për përgjegjësin.",
     "Set an admin password." : "Caktoni një fjalëkalim për përgjegjësin.",
-    "Can't create or write into the data directory %s" : "S’e krijon ose s’shkruan dot te drejtoria e të dhënave %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Mekanizmi i shërbimit për ndarje %s duhet të sendërtojë ndërfaqen OCP\\Share_Backend",
     "Sharing backend %s not found" : "S’u gjet mekanizmi i shërbimit për ndarje %s",
     "Sharing backend for %s not found" : "S’u gjet mekanizmi i shërbimit për ndarje për %s",
     "Open »%s«" : "Hap»1 %s«",
     "You are not allowed to share %s" : "Nuk ju lejohet ta ndani %s me të tjerët",
-    "Can’t increase permissions of %s" : "Nuk mund të shtohen lejet e %s",
-    "Files can’t be shared with delete permissions" : "Skedarët nuk mund të ndahen me leje të fshira",
-    "Files can’t be shared with create permissions" : "matchSkedarët nuk mund të ndahen me leje të krijuara",
+    "Cannot increase permissions of %s" : "S’mund të shtohen lejet për %s",
     "Expiration date is in the past" : "Data e skadimit bie në të kaluarën",
-    "Can’t set expiration date more than %s days in the future" : "Nuk mund të caktohet data e skadimit më shumë se %s ditë në të ardhmen",
+    "Sharing %s failed, because this item is already shared with user %s" : "Ndarja e %s me të tjerët dështoi, ngaqë ky objekt është ndarë tashmë me përdoruesin %s",
     "Click the button below to open it." : "Kliko butonin më poshtë për të hapur atë.",
     "The requested share does not exist anymore" : "Ndarja e kërkuar nuk ekziston më",
     "Could not find category \"%s\"" : "S’u gjet kategori \"%s\"",
@@ -125,48 +126,28 @@ OC.L10N.register(
     "Oct." : "Tet.",
     "Nov." : "Nën.",
     "Dec." : "Dhj.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Në një emër përdoruesi lejohen vetëm shenjat vijuese: \"a-z\", \"A-Z\", \"0-9\", dhe \"_.@-\"",
+    "A valid password must be provided" : "Duhet dhënë një fjalëkalim i vlefshëm",
+    "The username is already being used" : "Emri i përdoruesit është tashmë i përdorur",
     "A valid username must be provided" : "Duhet dhënë një emër i vlefshëm përdoruesi",
     "Username contains whitespace at the beginning or at the end" : "Emri i përdoruesit përmban hapësirë në fillim ose në fund",
     "Username must not consist of dots only" : "Emri i përdoruesit nuk duhet të përbëhet vetëm nga pika",
-    "A valid password must be provided" : "Duhet dhënë një fjalëkalim i vlefshëm",
-    "The username is already being used" : "Emri i përdoruesit është tashmë i përdorur",
     "User disabled" : "Përdorues i çaktivizuar",
     "Login canceled by app" : "Hyrja u anulua nga aplikacioni",
     "a safe home for all your data" : "Një shtëpi e sigurt për të dhënat e tua",
     "File is currently busy, please try again later" : "Kartela tani është e zënë, ju lutemi, riprovoni më vonë.",
-    "Can't read file" : "S'lexohet dot kartela",
     "Application is not enabled" : "Aplikacioni s’është aktivizuar",
     "Authentication error" : "Gabim mirëfilltësimi",
     "Token expired. Please reload page." : "Token-i ka skaduar. Ju lutem ringarkoni faqen.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "S’ka baza të dhënash (sqlite, mysql, ose postgresql) të instaluara.",
-    "Cannot write into \"config\" directory" : "S’shkruhet dot te drejtoria \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Kjo zakonisht mund të rregullohet duke i dhënë serverit të web-it akses shkrimi tek direktoria config. Shih %s",
-    "Cannot write into \"apps\" directory" : "S’shkruhet dot te drejtoria \"apps\"",
-    "Cannot create \"data\" directory" : "Nuk mund të krijohet direktoria \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Kjo zakonisht mund të rregullohet duke i dhënë serverit të web-it akses shkrimi tek direktoria rrënjë. Shih %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Zakonisht lejet mund të rregullohen duke i dhënë serverit të web-it akses shkrimi tek direktoria rrënjë. Shih %s.",
-    "Setting locale to %s failed" : "Caktimi i gjuhës si %s dështoi",
-    "Please install one of these locales on your system and restart your webserver." : "Ju lutemi, instaloni te sistemi juaj një prej këtyre vendoreve dhe rinisni shërbyesin tuaj web.",
     "PHP module %s not installed." : "Moduli PHP %s s’është i instaluar.",
     "Please ask your server administrator to install the module." : "Ju lutemi, kërkojini përgjegjësit të shërbyesit ta instalojë modulin.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Rregullimi PHP \"%s\" s’është vënë si \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Përshtatja e këtij konfigurimi në php.ini do e bëjë Nextcloud të punoj përsëri",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload është caktuar si \"%s\", në vend të vlerës së pritshme \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Për ta ndrequr këtë problem, caktoni për <code>mbstring.func_overload</code> vlerën <code>0</code> te php.ini juaj",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Lypset të paktën libxml2 2.7.0. Hëpërhë e instaluar është %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Për të ndrequr këtë problem, përditësoni libxml2 dhe rinisni shërbyesin tuaj web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Me sa duket, PHP-ja është rregulluar që të heqë blloqe të brendshëm dokumentimi. Kjo do t’i nxjerrë nga funksionimi disa aplikacione bazë.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Kjo ka gjasa të jetë shkaktuar nga një fshehtinë/përshpejtues i tillë si Zend OPcache ose eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Modulet PHP janë instaluar, por tregohen ende sikur mungojnë?",
     "Please ask your server administrator to restart the web server." : "Ju lutemi, kërkojini përgjegjësit të shërbyesit tuaj të rinisë shërbyesin web.",
-    "PostgreSQL >= 9 required" : "Lypset PostgreSQL >= 9",
-    "Please upgrade your database version" : "Ju lutemi, përmirësoni bazën tuaj të të dhënave me një version më të ri.",
-    "Your data directory is readable by other users" : "Direktoria juaj e të dhënave është e lexueshme nga përdorues të tjerë",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ju lutemi, kalojani lejet në 0770, që kështu atë drejtori të mos mund ta shfaqin përdorues të tjerë.",
-    "Your data directory must be an absolute path" : "Direktoria juaj e të dhënave duhet të jetë një path absolut",
-    "Check the value of \"datadirectory\" in your configuration" : "Kontrolloni vlerën e \"datadirectory\" te formësimi juaj",
-    "Your data directory is invalid" : "Direktoria juaj e të dhënave është i pavlefshëm",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Sigurohu që ekziston një skedar i quajtur \".ocdata\" në rrënjën e direktorisë së të dhënave.",
     "Could not obtain lock type %d on \"%s\"." : "S’u mor dot lloj kyçjeje %d në \"%s\".",
     "Storage unauthorized. %s" : "Depozitë e paautorizuar. %s",
@@ -174,8 +155,13 @@ OC.L10N.register(
     "Storage connection error. %s" : "Gabim lidhje te depozita. %s",
     "Storage is temporarily not available" : "Hapsira ruajtëse nuk është në dispozicion përkohësisht",
     "Storage connection timeout. %s" : "Mbarim kohe lidhjeje për depozitën. %s",
-    "Following databases are supported: %s" : "Mbulohen bazat vijuese të të dhënave: %s",
-    "Following platforms are supported: %s" : "Mbulohen platformat vijuese: %s",
-    "Invalid Federated Cloud ID" : "ID Federated Cloud e pavlefshme"
+    "Full name" : "Emri i plotë",
+    "%s enter the database username and name." : "%s jepni emrin e bazës së të dhënave dhe emrin e përdoruesit për të.",
+    "%s enter the database username." : "%s jepni emrin e përdoruesit të bazës së të dhënave.",
+    "%s enter the database name." : "%s jepni emrin e bazës së të dhënave.",
+    "%s you may not use dots in the database name" : "%s s’mund të përdorni pika te emri i bazës së të dhënave",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Në një emër përdoruesi lejohen vetëm shenjat vijuese: \"a-z\", \"A-Z\", \"0-9\", dhe \"_.@-\"",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Lypset të paktën libxml2 2.7.0. Hëpërhë e instaluar është %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Për të ndrequr këtë problem, përditësoni libxml2 dhe rinisni shërbyesin tuaj web."
 },
 "nplurals=2; plural=(n != 1);");
