@@ -2,14 +2,19 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Не могу да уписујем у „config“ директоријум!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Ово се обично може средити давањем права веб серверу да пише у директоријум са подешавањима",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Ово обично може да се поправи тако што се веб серверу дозволи упис у config директоријум.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Али, ако радије желите да фајл config.php може само да се чита, онда у њему поставите опцију „config_is_read_only” на true.",
     "See %s" : "Погледајте %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Ово се обично може средити давањем права веб серверу да пише у директоријум са подешавањима.",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Фајлови апликације „%1$s“ нису правилно замењени. Проверите да ли је верзија компатибилна са сервером.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Не постоји апликација %1$s или њена верзија није компатибилна са овим сервером. Молимо вас да проверите директоријум са апликацијама.",
     "Sample configuration detected" : "Откривен је пример подешавања",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Откривено је да је прекопиран пример подешавања. Ово може покварити инсталацију и није подржано. Прочитајте документацију пре вршења промена у фајлу config.php",
+    "404" : "404",
+    "The page could not be found on the server." : "На серверу не може да се пронађе ова страница.",
+    "%s email verification" : "%s потврђивање и-мејла",
+    "Email verification" : "Потврђивање и-мејла",
+    "Click the following button to confirm your email." : "Кликните на наредно дугме да потврдите свој и-мејл.",
+    "Click the following link to confirm your email." : "Кликните на следећи линк да потврдите свој и-мејл.",
+    "Confirm your email" : "Потврдите свој и-мејл",
     "Other activities" : "Остале активности",
     "%1$s and %2$s" : "%1$s и %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
@@ -32,6 +37,7 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Подржане су следеће платформе: %s",
     "Server version %s or higher is required." : "Потребна је верзија сервера %s или виша.",
     "Server version %s or lower is required." : "Потребна је верзија сервера %s или нижа.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Пријављени корисник мора бити админ, под админ или да поседује специјално право да приступи овом подешавању",
     "Logged in user must be an admin or sub admin" : "Пријављени корисник мора бити администратор или подадминистратор",
     "Logged in user must be an admin" : "Пријављени корисник мора бити администратор",
     "Wiping of device %s has started" : "Започето брисање уређаја %s",
@@ -50,6 +56,9 @@ OC.L10N.register(
     "Unknown filetype" : "Непознат тип фајла",
     "Invalid image" : "Неисправна слика",
     "Avatar image is not square" : "Слика аватара није квадратна",
+    "Files" : "Фајлови",
+    "View profile" : "Погледај профил",
+    "Local time: %s" : "Локално време: %s",
     "today" : "данас",
     "tomorrow" : "сутра",
     "yesterday" : "јуче",
@@ -71,6 +80,10 @@ OC.L10N.register(
     "seconds ago" : "пре неколико секунди",
     "Empty file" : "Празан фајл",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул са идентификацијом: %s не постоји. Омогућите га у подешавањима апликација или контактирајте администратора.",
+    "File already exists" : "Фајл већ постоји",
+    "Invalid path" : "Неисправна путања",
+    "Failed to create file from template" : "Није успело креирање фајла из шаблона",
+    "Templates" : "Шаблони",
     "File name is a reserved word" : "Назив фајла је резервисана реч",
     "File name contains at least one invalid character" : "Назив фајла садржи бар један недозвољен знак",
     "File name is too long" : "Назив фајла је предугачак",
@@ -81,16 +94,36 @@ OC.L10N.register(
     "__language_name__" : "Српски",
     "This is an automatically sent email, please do not reply." : "Ово је аутоматски генерисана порука, не одговарајте на њу.",
     "Help" : "Помоћ",
+    "Appearance and accessibility" : "Изглед и приступачност",
     "Apps" : "Апликације",
+    "Personal settings" : "Лична подешавања",
+    "Administration settings" : "Административна подешавања",
     "Settings" : "Поставке",
     "Log out" : "Одјава",
     "Users" : "Корисници",
+    "Email" : "Е-пошта",
+    "Mail %s" : "Пошта %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Погледај %s на fediverse",
+    "Phone" : "Телефон",
+    "Call %s" : "Позив %s",
+    "Twitter" : "Твитер",
+    "View %s on Twitter" : "Погледај %s на Твитеру",
+    "Website" : "Веб страна",
+    "Visit %s" : "Посети %s",
+    "Address" : "Адреса",
+    "Profile picture" : "Слика профила",
+    "About" : "О програму",
+    "Display name" : "Име за приказ",
+    "Headline" : "Наслов",
+    "Organisation" : "Организација",
+    "Role" : "Улога",
     "Unknown user" : "Непознат корисник",
     "Additional settings" : "Додатне поставке",
-    "%s enter the database username and name." : "%s унеси корисничко име базе података и име.",
-    "%s enter the database username." : "%s унеси корисничко име базе података.",
-    "%s enter the database name." : "%s унеси име базе података.",
-    "%s you may not use dots in the database name" : "%s не можете користити тачке у имену базе података",
+    "Enter the database username and name for %s" : "Унесите корисничко име базе података и назив за %s",
+    "Enter the database username for %s" : "Унесите корисничко име базе података за %s",
+    "Enter the database name for %s" : "Унесите назив базе података за %s",
+    "You cannot use dots in the database name %s" : "У називу базе података не можете да користите тачке %s",
     "MySQL username and/or password not valid" : "MySQL корисничко име и/или лозинка нису исправни",
     "You need to enter details of an existing account." : "Потребно је да унесете детаље постојећег налога.",
     "Oracle connection could not be established" : "Веза са базом података Oracle не може бити успостављена",
@@ -102,7 +135,7 @@ OC.L10N.register(
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Уклоните open_basedir поставку из php.ini фајла или пређите на 64-битни PHP.",
     "Set an admin username." : "Поставите име за администратора.",
     "Set an admin password." : "Поставите лозинку за администратора.",
-    "Can't create or write into the data directory %s" : "Не могу креирати или уписивати у директоријум података %s",
+    "Cannot create or write into the data directory %s" : "Не може да се креира или уписује у директоријум са подацима %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Позадина дељења %s мора користити корисничко окружење OCP\\Share_Backend",
     "Sharing backend %s not found" : "Позадина за дељење %s није пронађена",
     "Sharing backend for %s not found" : "Позадина за дељење за %s није пронађена",
@@ -112,14 +145,18 @@ OC.L10N.register(
     "Open »%s«" : "Отвори „%s“",
     "%1$s via %2$s" : "%1$s преко %2$s",
     "You are not allowed to share %s" : "Није вам дозвољено да делите %s",
-    "Can’t increase permissions of %s" : "Не могу да повећам дозволе за %s",
-    "Files can’t be shared with delete permissions" : "Фајлови не могу бити дељени са дозволама за брисање",
-    "Files can’t be shared with create permissions" : "Фајлови не могу бити дељени са дозволама за креирање",
+    "Cannot increase permissions of %s" : "Не могу да повећам привилегије за %s",
+    "Files cannot be shared with delete permissions" : "Фајлови не могу да се деле са дозволама за брисање",
+    "Files cannot be shared with create permissions" : "Фајлови не могу да се деле са дозволама за креирање",
     "Expiration date is in the past" : "Датум истека је у прошлости",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Датум истека не може да се постави више од %n дан у будућност","Датум истека не може да се постави више од %n дана у будућност","Датум истека не може да се постави више од %n дана у будућност"],
+    "Sharing is only allowed with group members" : "Дељење је дозвољено само са члановима групе",
+    "Sharing %s failed, because this item is already shared with user %s" : "Дељење %s није успело зато што се ова ставка већ дели са корисником %s",
     "%1$s shared »%2$s« with you" : "%1$s је поделио „%2$s“ са Вама",
     "%1$s shared »%2$s« with you." : "%1$s је поделио „%2$s“ са Вама.",
     "Click the button below to open it." : "Кликните дугме испод да га отворите.",
     "The requested share does not exist anymore" : "Захтевано дељење више не постоји",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Корисник није креиран јер је достигнуто ограничење броја корисника. За више детаља, погледајте своја обавештења.",
     "Could not find category \"%s\"" : "Не могу да пронађем категорију „%s“.",
     "Sunday" : "Недеља",
     "Monday" : "Понедељак",
@@ -166,52 +203,54 @@ OC.L10N.register(
     "Oct." : "Окт.",
     "Nov." : "Нов.",
     "Dec." : "Дец.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "У корисничком имену су дозвољени само следећи карактери: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
+    "A valid password must be provided" : "Морате унети исправну лозинку",
+    "The username is already being used" : "Корисничко име се већ користи",
+    "Could not create user" : "Не могу да направим корисника",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "У корисничком имену су дозвољени само следећи карактери: „a-z”, „A-Z”, „0-9”, размаци и „_.@-'",
     "A valid username must be provided" : "Морате унети исправно корисничко име",
     "Username contains whitespace at the beginning or at the end" : "Корисничко име садржи белине на почетку или на крају",
     "Username must not consist of dots only" : "Корисничко име не могу бити само тачке",
     "Username is invalid because files already exist for this user" : "Корисничко име није исправно пошто већ постоје фајлови за овог корисника",
-    "A valid password must be provided" : "Морате унети исправну лозинку",
-    "The username is already being used" : "Корисничко име се већ користи",
-    "Could not create user" : "Не могу да направим корисника",
     "User disabled" : "Корисник онемогућен",
     "Login canceled by app" : "Пријава отказана од стране апликације",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликација „%1$s“ не може бити инсталирана јер следеће зависности нису испуњене: %2$s",
     "a safe home for all your data" : "сигурно место за све Ваше податке",
     "File is currently busy, please try again later" : "Фајл је тренутно заузет, покушајте поново касније",
-    "Can't read file" : "Не могу да читам фајл",
+    "Cannot download file" : "Фајл не може да се преузме",
     "Application is not enabled" : "Апликација није укључена",
     "Authentication error" : "Грешка при провери идентитета",
     "Token expired. Please reload page." : "Жетон је истекао. Поново учитајте страницу.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Нема драјвера базе података (скулајт, мајскул или постгрескул).",
-    "Cannot write into \"config\" directory" : "Не могу уписивати у директоријуму „config“",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ово се обично може средити давањем права писања веб серверу за директоријум са подешавањима. Погледајте %s",
-    "Cannot write into \"apps\" directory" : "Не могу уписивати у директоријуму „apps“",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Ово се обично може поправити давањем права уписа веб серверу директоријум апликација или искуључивањем продавнице апликација у фајлу config file.",
-    "Cannot create \"data\" directory" : "Не могу да направим \"data\" директоријум",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ово се обично може поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Привилегије се обично могу поправити тако што веб серверу дате право уписа за корени директоријуму. Видети %s",
-    "Setting locale to %s failed" : "Постављање локалитета на %s није успело",
-    "Please install one of these locales on your system and restart your webserver." : "Инсталирајте неки од ових локалитета на ваш систем и поново покрените веб сервер.",
+    "Cannot write into \"config\" directory." : "Не може да се упише у „config директоријум.",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у config директоријум. Погледајте %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
+    "Cannot write into \"apps\" directory." : "Не може да се упише у „apps” директоријум.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у apps директоријум или тако што се искључи Продавница апликација у config фајлу.",
+    "Cannot create \"data\" directory." : "Не може да се креира „data” директоријум.",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у корени директоријум. Погледајте %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Проблем са дозволама обично може да се поправи тако што се веб серверу дозволи право уписа у корени директоријум. Погледајте %s.",
+    "Your data directory is not writable." : "У ваш директоријум са подацима не може да се упише.",
+    "Setting locale to %s failed." : "Није успело постављање локалитета на %s.",
+    "Please install one of these locales on your system and restart your web server." : "Молимо вас да на свој систем инсталирате један од следећих локалитета и поново покренете свој веб сервер.",
     "PHP module %s not installed." : "PHP модул %s није инсталиран.",
     "Please ask your server administrator to install the module." : "Замолите администратора вашег сервера да инсталира тај модул.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставка „%s“ није постављена на „%s“.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Некстклауд ће прорадити поново када прилагодите ово подашавање у php.ini фајлу",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload је постављено на „%s“ уместо на очекивану вредност „0“",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Да би решили овај проблем поставите <code>mbstring.func_overload</code> на <code>0</code> у фајлу php.ini",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Потребан је бар libxml2 2.7.0. Тренутно је инсталиран %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Да поправите овај проблем, ажурирајте верзију библиотеке libxml2 и рестартујте веб сервер.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> је постављено на <code>%s</code> уместо на очекивану вредност <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Да бисте исправили овај проблем, поставите <code>mbstring.func_overload</code> на <code>0</code> у свом php.ini фајлу.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP је очигледно подешен да склања уметнуте doc блокове. То ће учинити неколико кључних апликација недоступним.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модули су инсталирани али се и даље воде као недостајући?",
     "Please ask your server administrator to restart the web server." : "Замолите вашег администратора сервера да поново покрене веб сервер.",
-    "PostgreSQL >= 9 required" : "Захтеван је ПостгреСкул >= 9",
-    "Please upgrade your database version" : "Надоградите ваше издање базе",
-    "Your data directory is readable by other users" : "Директоријум са подацима је читљив од стране других корисника система",
+    "The required %s config variable is not configured in the config.php file." : "У config.php фајлу није подешена потребна config променљива %s.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Молимо вас да замолите свог систем администратора да провери Некстклауд конфигурацију.",
+    "PostgreSQL >= 9 required." : "Потребан је PostgreSQL >= 9.",
+    "Please upgrade your database version." : "Молимо вас да ажурирате верзију базе података.",
+    "Your data directory is readable by other users." : "Ваш директоријум са подацима могу да читају остали корисници.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Промените дозволе у 0770 како директоријуми не би могли бити излистани од стране других корисника.",
-    "Your data directory must be an absolute path" : "Директоријум са подацима мора бити апсолутна путања",
-    "Check the value of \"datadirectory\" in your configuration" : "Проверите податак за \"datadirectory\" у вашој конфигурацији",
-    "Your data directory is invalid" : "Директоријум са подацима није исправан",
+    "Your data directory must be an absolute path." : "Ваш директоријум са подацима мора бити апсолутна путања.",
+    "Check the value of \"datadirectory\" in your configuration." : "Проверите вредност „datadirectory” у својој конфигурацији.",
+    "Your data directory is invalid." : "Ваш директоријум са подацима је неисправан.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Уверите се да фајл \".ocdata\" постоји у корену директоријума са подацима.",
     "Action \"%s\" not supported or implemented." : "Радња \"%s\" није подржана или имплементирана.",
     "Authentication failed, wrong token or provider ID given" : "Неуспела провера идентитета, добијен погрешан токен или ID провајдера",
@@ -224,9 +263,15 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка приликом повезивања на складиште. %s",
     "Storage is temporarily not available" : "Складиште привремено није  доступно",
     "Storage connection timeout. %s" : "Истекло је време за повезивање на складиште. %s",
-    "Following databases are supported: %s" : "Подржане су следеће базе података: %s",
-    "Following platforms are supported: %s" : "Подржане су следеће платформе: %s",
-    "Invalid Federated Cloud ID" : "Неисправан ИД Здруженог облака",
-    "Can’t set expiration date more than %s days in the future" : "Не могу да поставим датум истека више од %s дана у будућност"
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Фајлови апликације „%1$s“ нису правилно замењени. Проверите да ли је верзија компатибилна са сервером.",
+    "Full name" : "Пуно име",
+    "%s enter the database username and name." : "%s унеси корисничко име базе података и име.",
+    "%s enter the database username." : "%s унеси корисничко име базе података.",
+    "%s enter the database name." : "%s унеси име базе података.",
+    "%s you may not use dots in the database name" : "%s не можете користити тачке у имену базе података",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Достигнуто је ограничење броја корисника и корисник није креиран. За више детаља погледајте своја обавештења.",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "У корисничком имену су дозвољени само следећи карактери: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Потребан је бар libxml2 2.7.0. Тренутно је инсталиран %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Да поправите овај проблем, ажурирајте верзију библиотеке libxml2 и рестартујте веб сервер."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
