@@ -8,7 +8,7 @@
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <robin@icewind.nl>
- * @author Vincent Petry <pvince81@owncloud.com>
+ * @author Vincent Petry <vincent@nextcloud.com>
  *
  * @license AGPL-3.0
  *
@@ -25,12 +25,14 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 namespace OC\Files\Cache;
 
+use OC\DB\Exceptions\DbalException;
+use OC\Files\FileInfo;
 use OCP\Files\Cache\ICacheEntry;
 use OCP\Files\Cache\IUpdater;
 use OCP\Files\Storage\IStorage;
+use Psr\Log\LoggerInterface;
 
 /**
  * Update the cache and propagate changes
@@ -62,6 +64,8 @@ class Updater implements IUpdater {
 	 */
 	protected $cache;
 
+	private LoggerInterface $logger;
+
 	/**
 	 * @param \OC\Files\Storage\Storage $storage
 	 */
@@ -70,17 +74,18 @@ class Updater implements IUpdater {
 		$this->propagator = $storage->getPropagator();
 		$this->scanner = $storage->getScanner();
 		$this->cache = $storage->getCache();
+		$this->logger = \OC::$server->get(LoggerInterface::class);
 	}
 
 	/**
-	 * Disable updating the cache trough this updater
+	 * Disable updating the cache through this updater
 	 */
 	public function disable() {
 		$this->enabled = false;
 	}
 
 	/**
-	 * Re-enable the updating of the cache trough this updater
+	 * Re-enable the updating of the cache through this updater
 	 */
 	public function enable() {
 		$this->enabled = true;
@@ -187,7 +192,9 @@ class Updater implements IUpdater {
 		$sourceUpdater = $sourceStorage->getUpdater();
 		$sourcePropagator = $sourceStorage->getPropagator();
 
-		if ($sourceCache->inCache($source)) {
+		$sourceInfo = $sourceCache->get($source);
+
+		if ($sourceInfo !== false) {
 			if ($this->cache->inCache($target)) {
 				$this->cache->remove($target);
 			}
@@ -197,13 +204,17 @@ class Updater implements IUpdater {
 			} else {
 				$this->cache->moveFromCache($sourceCache, $source, $target);
 			}
-		}
 
-		if (pathinfo($source, PATHINFO_EXTENSION) !== pathinfo($target, PATHINFO_EXTENSION)) {
-			// handle mime type change
-			$mimeType = $this->storage->getMimeType($target);
-			$fileId = $this->cache->getId($target);
-			$this->cache->update($fileId, ['mimetype' => $mimeType]);
+			$sourceExtension = pathinfo($source, PATHINFO_EXTENSION);
+			$targetExtension = pathinfo($target, PATHINFO_EXTENSION);
+			$targetIsTrash = preg_match("/d\d+/", $targetExtension);
+
+			if ($sourceExtension !== $targetExtension && $sourceInfo->getMimeType() !== FileInfo::MIMETYPE_FOLDER && !$targetIsTrash) {
+				// handle mime type change
+				$mimeType = $this->storage->getMimeType($target);
+				$fileId = $this->cache->getId($target);
+				$this->cache->update($fileId, ['mimetype' => $mimeType]);
+			}
 		}
 
 		if ($sourceCache instanceof Cache) {
@@ -247,7 +258,14 @@ class Updater implements IUpdater {
 		if ($parentId != -1) {
 			$mtime = $this->storage->filemtime($parent);
 			if ($mtime !== false) {
-				$this->cache->update($parentId, ['storage_mtime' => $mtime]);
+				try {
+					$this->cache->update($parentId, ['storage_mtime' => $mtime]);
+				} catch (DbalException $e) {
+					// ignore the failure.
+					// with failures concurrent updates, someone else would have already done it.
+					// in the worst case the `storage_mtime` isn't updated, which should at most only trigger an extra rescan
+					$this->logger->warning("Error while updating parent storage_mtime, should be safe to ignore", ['exception' => $e]);
+				}
 			}
 		}
 	}
